@@ -2,5 +2,6 @@ var _ogre_material_manager_8h =
 [
     [ "Ogre::MaterialManager::Listener", "class_ogre_1_1_material_manager_1_1_listener.html", "class_ogre_1_1_material_manager_1_1_listener" ],
     [ "Ogre::MSN_DEFAULT", "group___materials.html#ga3b1bfc62cf049311f1452b86badeb566", null ],
-    [ "Ogre::MSN_SHADERGEN", "group___materials.html#ga6c915cd9f3cc09a3edfb2c0ca7a27952", null ]
+    [ "Ogre::MSN_SHADERGEN", "group___materials.html#ga6c915cd9f3cc09a3edfb2c0ca7a27952", null ],
+    [ "Ogre::MSN_SHADOWCASTER", "group___materials.html#ga859656e5b7b4955fef98b26cdb9ad453", null ]
 ];
\ No newline at end of file
