@@ -38,12 +38,12 @@ var _ogre_platform_8h =
     [ "OGRE_DEFAULT_LOCALE", "_ogre_platform_8h.html#a9841c02eaa22e4d4d5067cd6cfa9b38f", null ],
     [ "OGRE_BUILD_SUFFIX", "_ogre_platform_8h.html#a922bb8a4073c0e5b0b48acf831b90a64", null ],
     [ "DECL_MALLOC", "_ogre_platform_8h.html#aa1730b3ff27777dab53a340f23844db4", null ],
-    [ "uint32", "_ogre_platform_8h.html#a8f2f90fa4c83c075e3fae75456ae5ded", null ],
-    [ "uint16", "_ogre_platform_8h.html#a2a820cf8746c0f12999d2416c767f55d", null ],
-    [ "uint8", "_ogre_platform_8h.html#a135bdde033ee93f327917c6ff578d46c", null ],
-    [ "uint64", "_ogre_platform_8h.html#a60635457b0b97495b34737baa4fb3f64", null ],
-    [ "int32", "_ogre_platform_8h.html#a6e6e978d04d35e4351576d3f6f3e2364", null ],
-    [ "int16", "_ogre_platform_8h.html#a355345c182bde9095610b63a9fd69376", null ],
-    [ "int8", "_ogre_platform_8h.html#a6519f6582ca047f2c0ae0bb056bb9134", null ],
-    [ "int64", "_ogre_platform_8h.html#a400c2fa3db9a7c0c34de0635b01ab3b6", null ]
+    [ "Ogre::uint32", "namespace_ogre.html#a8f2f90fa4c83c075e3fae75456ae5ded", null ],
+    [ "Ogre::uint16", "namespace_ogre.html#a2a820cf8746c0f12999d2416c767f55d", null ],
+    [ "Ogre::uint8", "namespace_ogre.html#a135bdde033ee93f327917c6ff578d46c", null ],
+    [ "Ogre::uint64", "namespace_ogre.html#a60635457b0b97495b34737baa4fb3f64", null ],
+    [ "Ogre::int32", "namespace_ogre.html#a6e6e978d04d35e4351576d3f6f3e2364", null ],
+    [ "Ogre::int16", "namespace_ogre.html#a355345c182bde9095610b63a9fd69376", null ],
+    [ "Ogre::int8", "namespace_ogre.html#a6519f6582ca047f2c0ae0bb056bb9134", null ],
+    [ "Ogre::int64", "namespace_ogre.html#a400c2fa3db9a7c0c34de0635b01ab3b6", null ]
 ];
\ No newline at end of file
