@@ -1,5 +1,5 @@
 var _ogre_string_8h =
 [
     [ "OGRE_FORMAT_PRINTF", "_ogre_string_8h.html#ad9d270cedd658e327378cf66bd20f0e8", null ],
-    [ "_StringHash", "_ogre_string_8h.html#ga7b12ead713677ce5b77e1304e7cff37a", null ]
+    [ "Ogre::_StringHash", "group___general.html#ga7b12ead713677ce5b77e1304e7cff37a", null ]
 ];
\ No newline at end of file
