@@ -172,7 +172,7 @@ var _scripts =
         [ "material_scheme", "_compositor-_scripts.html#autotoc_md72", null ]
       ] ],
       [ "Passes", "_compositor-_scripts.html#Compositor-Passes", [
-        [ "render_quad & compute", "_compositor-_scripts.html#autotoc_md73", [
+        [ "render_quad &amp; compute", "_compositor-_scripts.html#autotoc_md73", [
           [ "material", "_compositor-_scripts.html#autotoc_md74", null ],
           [ "input", "_compositor-_scripts.html#autotoc_md75", null ],
           [ "identifier", "_compositor-_scripts.html#autotoc_md76", null ],
@@ -233,19 +233,19 @@ var _scripts =
         [ "Common Emitter Attributes", "_particle-_scripts.html#autotoc_md224", null ],
         [ "angle", "_particle-_scripts.html#autotoc_md225", null ],
         [ "colour", "_particle-_scripts.html#autotoc_md226", null ],
-        [ "colour_range_start & colour_range_end", "_particle-_scripts.html#autotoc_md227", null ],
+        [ "colour_range_start &amp; colour_range_end", "_particle-_scripts.html#autotoc_md227", null ],
         [ "direction", "_particle-_scripts.html#autotoc_md228", null ],
         [ "direction_position_reference", "_particle-_scripts.html#autotoc_md229", null ],
         [ "emission_rate", "_particle-_scripts.html#autotoc_md230", null ],
         [ "position", "_particle-_scripts.html#autotoc_md231", null ],
         [ "velocity", "_particle-_scripts.html#autotoc_md232", null ],
-        [ "velocity_min & velocity_max", "_particle-_scripts.html#autotoc_md233", null ],
+        [ "velocity_min &amp; velocity_max", "_particle-_scripts.html#autotoc_md233", null ],
         [ "time_to_live", "_particle-_scripts.html#autotoc_md234", null ],
-        [ "time_to_live_min & time_to_live_max", "_particle-_scripts.html#autotoc_md235", null ],
+        [ "time_to_live_min &amp; time_to_live_max", "_particle-_scripts.html#autotoc_md235", null ],
         [ "duration", "_particle-_scripts.html#autotoc_md236", null ],
-        [ "duration_min & duration_max", "_particle-_scripts.html#autotoc_md237", null ],
+        [ "duration_min &amp; duration_max", "_particle-_scripts.html#autotoc_md237", null ],
         [ "repeat_delay", "_particle-_scripts.html#autotoc_md238", null ],
-        [ "repeat_delay_min & repeat_delay_max", "_particle-_scripts.html#autotoc_md239", null ]
+        [ "repeat_delay_min &amp; repeat_delay_max", "_particle-_scripts.html#autotoc_md239", null ]
       ] ],
       [ "Standard Particle Emitters", "_particle-_scripts.html#Standard-Particle-Emitters", [
         [ "Point Emitter", "_particle-_scripts.html#Point-Emitter", null ],
