@@ -6,6 +6,8 @@ var annotated_dup =
         [ "CollisionWorld", "class_ogre_1_1_bullet_1_1_collision_world.html", "class_ogre_1_1_bullet_1_1_collision_world" ],
         [ "DebugDrawer", "class_ogre_1_1_bullet_1_1_debug_drawer.html", "class_ogre_1_1_bullet_1_1_debug_drawer" ],
         [ "DynamicsWorld", "class_ogre_1_1_bullet_1_1_dynamics_world.html", "class_ogre_1_1_bullet_1_1_dynamics_world" ],
+        [ "HeightFieldData", "struct_ogre_1_1_bullet_1_1_height_field_data.html", "struct_ogre_1_1_bullet_1_1_height_field_data" ],
+        [ "KinematicMotionSimple", "class_ogre_1_1_bullet_1_1_kinematic_motion_simple.html", "class_ogre_1_1_bullet_1_1_kinematic_motion_simple" ],
         [ "RayResultCallback", "struct_ogre_1_1_bullet_1_1_ray_result_callback.html", "struct_ogre_1_1_bullet_1_1_ray_result_callback" ],
         [ "RigidBodyState", "class_ogre_1_1_bullet_1_1_rigid_body_state.html", "class_ogre_1_1_bullet_1_1_rigid_body_state" ]
       ] ],
@@ -227,6 +229,7 @@ var annotated_dup =
       [ "Frustum", "class_ogre_1_1_frustum.html", "class_ogre_1_1_frustum" ],
       [ "GL3PlusRenderSystem", "class_ogre_1_1_g_l3_plus_render_system.html", "class_ogre_1_1_g_l3_plus_render_system" ],
       [ "GLES2RenderSystem", "class_ogre_1_1_g_l_e_s2_render_system.html", "class_ogre_1_1_g_l_e_s2_render_system" ],
+      [ "GlobalInstancingData", "struct_ogre_1_1_global_instancing_data.html", "struct_ogre_1_1_global_instancing_data" ],
       [ "GLRenderSystem", "class_ogre_1_1_g_l_render_system.html", "class_ogre_1_1_g_l_render_system" ],
       [ "GLSLangPlugin", "class_ogre_1_1_g_l_s_lang_plugin.html", "class_ogre_1_1_g_l_s_lang_plugin" ],
       [ "GLSLangProgram", "class_ogre_1_1_g_l_s_lang_program.html", "class_ogre_1_1_g_l_s_lang_program" ],
@@ -521,6 +524,7 @@ var annotated_dup =
       [ "ScriptCompilerListener", "class_ogre_1_1_script_compiler_listener.html", "class_ogre_1_1_script_compiler_listener" ],
       [ "ScriptCompilerManager", "class_ogre_1_1_script_compiler_manager.html", "class_ogre_1_1_script_compiler_manager" ],
       [ "ScriptLoader", "class_ogre_1_1_script_loader.html", "class_ogre_1_1_script_loader" ],
+      [ "ScriptProperty", "struct_ogre_1_1_script_property.html", "struct_ogre_1_1_script_property" ],
       [ "ScriptTranslator", "class_ogre_1_1_script_translator.html", "class_ogre_1_1_script_translator" ],
       [ "ScriptTranslatorManager", "class_ogre_1_1_script_translator_manager.html", "class_ogre_1_1_script_translator_manager" ],
       [ "Segment", "class_ogre_1_1_segment.html", "class_ogre_1_1_segment" ],
