@@ -3,5 +3,6 @@ var class_ogre_1_1_bullet_1_1_collision_world =
     [ "CollisionWorld", "class_ogre_1_1_bullet_1_1_collision_world.html#a1a0a90916e7a319c950c52c7f02bfc43", null ],
     [ "~CollisionWorld", "class_ogre_1_1_bullet_1_1_collision_world.html#a440552b57ebd041ca89164053ed24f8b", null ],
     [ "addCollisionObject", "class_ogre_1_1_bullet_1_1_collision_world.html#aa1b97dfab12428da4b447c0f3ae59967", null ],
-    [ "rayTest", "class_ogre_1_1_bullet_1_1_collision_world.html#a289c5df44c8ed32c6c519d57ad6a1b6f", null ]
+    [ "rayTest", "class_ogre_1_1_bullet_1_1_collision_world.html#a289c5df44c8ed32c6c519d57ad6a1b6f", null ],
+    [ "attachCollisionObject", "class_ogre_1_1_bullet_1_1_collision_world.html#aca5597475dc1e63e63956ba1e838e981", null ]
 ];
\ No newline at end of file
