@@ -12,5 +12,6 @@ var class_ogre_1_1_codec =
     [ "decode", "class_ogre_1_1_codec.html#aa09f02c08e53d8e58835a7a342e8be64", null ],
     [ "getType", "class_ogre_1_1_codec.html#ada1a5477ab6a563565f1b3599d7b806a", null ],
     [ "magicNumberMatch", "class_ogre_1_1_codec.html#a2e3a2fbc93450efac141578d33c4bbc0", null ],
-    [ "magicNumberToFileExt", "class_ogre_1_1_codec.html#af90756f690827353e18347d328bc5180", null ]
+    [ "magicNumberToFileExt", "class_ogre_1_1_codec.html#af90756f690827353e18347d328bc5180", null ],
+    [ "setParameter", "class_ogre_1_1_codec.html#a464e7b1ef3fae566425b2d7f4ed982db", null ]
 ];
\ No newline at end of file
