@@ -25,12 +25,6 @@ var class_ogre_1_1_d3_d11_render_system =
     [ "handleDeviceLost", "class_ogre_1_1_d3_d11_render_system.html#afcc899b2dbf8c5dfa081cedc0e1d508e", null ],
     [ "destroyRenderTarget", "class_ogre_1_1_d3_d11_render_system.html#a790d9dd369cdf93285f4b2a3002b6ab0", null ],
     [ "setStencilState", "class_ogre_1_1_d3_d11_render_system.html#a9b7bda3503f4251900d4393391c869ee", null ],
-    [ "_getBoundVertexProgram", "class_ogre_1_1_d3_d11_render_system.html#a20fa4cc5cfb17ac522e379520d2580d5", null ],
-    [ "_getBoundFragmentProgram", "class_ogre_1_1_d3_d11_render_system.html#a8dad8b3c529f369ef2dd2771ccc5a1ac", null ],
-    [ "_getBoundGeometryProgram", "class_ogre_1_1_d3_d11_render_system.html#a02faa57d6e9a67ba8b1cf6c8a4de9857", null ],
-    [ "_getBoundTessellationHullProgram", "class_ogre_1_1_d3_d11_render_system.html#a49f0569b7bd7276e497cf593f2078ca3", null ],
-    [ "_getBoundTessellationDomainProgram", "class_ogre_1_1_d3_d11_render_system.html#a63ba87a4312b419e48ba45fde288ada3", null ],
-    [ "_getBoundComputeProgram", "class_ogre_1_1_d3_d11_render_system.html#a429bda5fbb42b3426e8ec9ac5f08835b", null ],
     [ "_setTexture", "class_ogre_1_1_d3_d11_render_system.html#afb472cf1a180d18cf28258ab7b1aa700", null ],
     [ "_setSampler", "class_ogre_1_1_d3_d11_render_system.html#a49d1e995e5b6d9088ded6a4c74a3f51e", null ],
     [ "_setAlphaRejectSettings", "class_ogre_1_1_d3_d11_render_system.html#aa71e8588f6870ec5b4e0a29153436c5e", null ],
