@@ -3,5 +3,6 @@ var class_ogre_1_1_default_hardware_buffer =
     [ "DefaultHardwareBuffer", "class_ogre_1_1_default_hardware_buffer.html#af5bf169a8912f614a2e301993e66abee", null ],
     [ "~DefaultHardwareBuffer", "class_ogre_1_1_default_hardware_buffer.html#abf4158a560d35033133680dfb29e99f7", null ],
     [ "readData", "class_ogre_1_1_default_hardware_buffer.html#a3b7d53524bb4efc2aa1b9ebf608dcea2", null ],
-    [ "writeData", "class_ogre_1_1_default_hardware_buffer.html#a050c9b25ac465441a52837bb75ebc60f", null ]
+    [ "writeData", "class_ogre_1_1_default_hardware_buffer.html#a050c9b25ac465441a52837bb75ebc60f", null ],
+    [ "isSystemMemory", "class_ogre_1_1_default_hardware_buffer.html#aa2e1f53f6c37b0bb57bc38e4fe4d8fef", null ]
 ];
\ No newline at end of file
