@@ -4,5 +4,6 @@ var class_ogre_1_1_edge_list_builder =
     [ "addVertexData", "class_ogre_1_1_edge_list_builder.html#a9845e2f91660819164a627c661f5d107", null ],
     [ "addIndexData", "class_ogre_1_1_edge_list_builder.html#ae4af3550dfe4948680078a087377bfbf", null ],
     [ "build", "class_ogre_1_1_edge_list_builder.html#aa76568f1c0c49f3f9ff16dfb304f1571", null ],
-    [ "log", "class_ogre_1_1_edge_list_builder.html#a66aa1d48de5385be8233c8733af99186", null ]
+    [ "log", "class_ogre_1_1_edge_list_builder.html#a66aa1d48de5385be8233c8733af99186", null ],
+    [ "geometryLess", "class_ogre_1_1_edge_list_builder.html#a99d7b191452d6c4848576f0f3703e0a6", null ]
 ];
\ No newline at end of file
