@@ -3,7 +3,5 @@ var class_ogre_1_1_file_system_archive_factory =
     [ "getType", "class_ogre_1_1_file_system_archive_factory.html#a261df746daff723eea1a4570bf0023c2", null ],
     [ "createInstance", "class_ogre_1_1_file_system_archive_factory.html#ac5a0c402e76e62716bb6ddec2e5c0408", null ],
     [ "setIgnoreHidden", "class_ogre_1_1_file_system_archive_factory.html#ac73fdb14c70cf79e753d86a13273c2a3", null ],
-    [ "getIgnoreHidden", "class_ogre_1_1_file_system_archive_factory.html#a1bcf459933c38f70ccd8c7c235b725c2", null ],
-    [ "createInstance", "class_ogre_1_1_file_system_archive_factory.html#a51a3c68688eca8878bdecdc44929ee1a", null ],
-    [ "createInstance", "class_ogre_1_1_file_system_archive_factory.html#a2536e95961d315b49220d2d95caa6834", null ]
+    [ "getIgnoreHidden", "class_ogre_1_1_file_system_archive_factory.html#a1bcf459933c38f70ccd8c7c235b725c2", null ]
 ];
\ No newline at end of file
