@@ -1,9 +1,9 @@
 var class_ogre_1_1_font =
 [
-    [ "CodePoint", "class_ogre_1_1_font.html#ad664311d20390002b730f4d7895e59e6", null ],
-    [ "UVRect", "class_ogre_1_1_font.html#a18b387b355411d2e3efba99d1318a5ae", null ],
-    [ "CodePointRange", "class_ogre_1_1_font.html#a3683df497f7a2dc4e0665053a7e822ae", null ],
-    [ "CodePointRangeList", "class_ogre_1_1_font.html#ad461033abd8a457c0285557f4eaaa136", null ],
+    [ "CodePoint", "class_ogre_1_1_font.html#aaaa89c1bd6898818423e9ba89502cab3", null ],
+    [ "UVRect", "class_ogre_1_1_font.html#a9bdff138015537e6245b4fa016c37d52", null ],
+    [ "CodePointRange", "class_ogre_1_1_font.html#aa455a399457bd458852555c696b28f6a", null ],
+    [ "CodePointRangeList", "class_ogre_1_1_font.html#a3b754bb7b6d6b9be27d76d7c3a70fc7e", null ],
     [ "Font", "class_ogre_1_1_font.html#a9915203be62b8bd2feda436cc9f08cb0", null ],
     [ "~Font", "class_ogre_1_1_font.html#a02642b36387d7ffd80e164ce1fac4591", null ],
     [ "setType", "class_ogre_1_1_font.html#ab89abe298177153acda383de2d7823ca", null ],
@@ -24,10 +24,13 @@ var class_ogre_1_1_font =
     [ "addCodePointRange", "class_ogre_1_1_font.html#ac2c1fba5ad2d610ecc78b1e1a6a1b8dc", null ],
     [ "clearCodePointRanges", "class_ogre_1_1_font.html#aff75a40e8ca00a64f19c265e90c61733", null ],
     [ "getCodePointRangeList", "class_ogre_1_1_font.html#a847b5fa1668cee1943651d3bb496f243", null ],
+    [ "addMergeFont", "class_ogre_1_1_font.html#a87ce3d81e9b9b53479faa83c1d29c1bb", null ],
+    [ "getMergeFontList", "class_ogre_1_1_font.html#ac89f41cb59be64a896776e1b2cd307f4", null ],
     [ "getMaterial", "class_ogre_1_1_font.html#a7b1206935984cda27994ec766dae3f22", null ],
     [ "putText", "class_ogre_1_1_font.html#ac78d744eddeeaef4c01a078f9c3c9119", null ],
     [ "setAntialiasColour", "class_ogre_1_1_font.html#a6ca4172a3f554f07752997b1a25278c0", null ],
     [ "getAntialiasColour", "class_ogre_1_1_font.html#a278117d7414d69dbaed6e7290e842991", null ],
     [ "loadResource", "class_ogre_1_1_font.html#a7d54a57f586af8b040b4e2d3481aaa35", null ],
-    [ "_setMaterial", "class_ogre_1_1_font.html#a44e60ba33fb4a583d0239cc5cc9c849f", null ]
+    [ "_setMaterial", "class_ogre_1_1_font.html#a44e60ba33fb4a583d0239cc5cc9c849f", null ],
+    [ "ImGuiOverlay", "class_ogre_1_1_font.html#a837ff11c4d56b5bfd81ffe17c73d92c0", null ]
 ];
\ No newline at end of file
