@@ -3,7 +3,8 @@ var class_ogre_1_1_light =
     [ "LightTypes", "class_ogre_1_1_light.html#af20fe2bb87447be7a9a5327c65dee345", [
       [ "LT_POINT", "class_ogre_1_1_light.html#af20fe2bb87447be7a9a5327c65dee345a0d59bfdcfeb338dbfe06e2e2999e752f", null ],
       [ "LT_DIRECTIONAL", "class_ogre_1_1_light.html#af20fe2bb87447be7a9a5327c65dee345a4c5582d28848ce40c2b652488494b4a3", null ],
-      [ "LT_SPOTLIGHT", "class_ogre_1_1_light.html#af20fe2bb87447be7a9a5327c65dee345a8fc40a1ccfb026944417ef92b7ddaefe", null ]
+      [ "LT_SPOTLIGHT", "class_ogre_1_1_light.html#af20fe2bb87447be7a9a5327c65dee345a8fc40a1ccfb026944417ef92b7ddaefe", null ],
+      [ "LT_RECTLIGHT", "class_ogre_1_1_light.html#af20fe2bb87447be7a9a5327c65dee345aca0a6bc4ab27bc276096bc9b4a4add74", null ]
     ] ],
     [ "Light", "class_ogre_1_1_light.html#ad2e58022048b39881379298e30fa2765", null ],
     [ "Light", "class_ogre_1_1_light.html#acee7830214ec1660dc13796f6ca99e36", null ],
@@ -29,8 +30,8 @@ var class_ogre_1_1_light =
     [ "setDirection", "class_ogre_1_1_light.html#aa9c6df55eafb28a2a0bab287bc9596f7", null ],
     [ "setDirection", "class_ogre_1_1_light.html#a1659111f4eb55f3b3227e87c8bfce8d9", null ],
     [ "getDirection", "class_ogre_1_1_light.html#aa41bd29b2f37800f618cdb1eb73ef2c7", null ],
-    [ "_notifyAttached", "class_ogre_1_1_light.html#a2c4dddb1da9079b9f68236c86a689e54", null ],
-    [ "_notifyMoved", "class_ogre_1_1_light.html#acc93817276a3ea236bb45a19de4f5d4e", null ],
+    [ "_notifyAttached", "class_ogre_1_1_light.html#a7986250539b65b5c871c274605cb4ca9", null ],
+    [ "_notifyMoved", "class_ogre_1_1_light.html#a07d89683bfadf75cce21944e10dda0fb", null ],
     [ "setSpotlightRange", "class_ogre_1_1_light.html#a8ef06bd9c2e7113461c50c83c5f09fe9", null ],
     [ "getSpotlightInnerAngle", "class_ogre_1_1_light.html#a55cda420f991dcb9cfc8ccb56fc227b0", null ],
     [ "getSpotlightOuterAngle", "class_ogre_1_1_light.html#a20ef8a0dc69223d29971f00a90bf5b35", null ],
@@ -40,20 +41,24 @@ var class_ogre_1_1_light =
     [ "setSpotlightFalloff", "class_ogre_1_1_light.html#aec895d9f784ea062ce69c823737229c5", null ],
     [ "setSpotlightNearClipDistance", "class_ogre_1_1_light.html#aead9fea5c5d5869387d88869d0132cad", null ],
     [ "getSpotlightNearClipDistance", "class_ogre_1_1_light.html#ace79ed42960f5f2860b02bc408fbd767", null ],
+    [ "setSourceSize", "class_ogre_1_1_light.html#adab100d5c8d5f4024f377fe20aebe8f2", null ],
+    [ "getSourceSize", "class_ogre_1_1_light.html#ad03ff3840b97c737445128af9092ccc7", null ],
+    [ "getDerivedSourceHalfWidth", "class_ogre_1_1_light.html#a34ce016cfa80713aabfec6c6e560d09a", null ],
+    [ "getDerivedSourceHalfHeight", "class_ogre_1_1_light.html#a7f6a21c028c1623c9e16654da7d1c95c", null ],
     [ "setPowerScale", "class_ogre_1_1_light.html#a8588796e58389701c22fb8e5c62a080e", null ],
     [ "getPowerScale", "class_ogre_1_1_light.html#aaa6e49d21586b363c4d40a87407be38b", null ],
     [ "getBoundingRadius", "class_ogre_1_1_light.html#ad4a18c8fa6f5bfb38aba27dcbb8a2574", null ],
     [ "getBoundingBox", "class_ogre_1_1_light.html#ac055941546b1f7198952a833dfc675ae", null ],
     [ "_updateRenderQueue", "class_ogre_1_1_light.html#aff8c359ab9a11edca40236e45a7e39d0", null ],
-    [ "getMovableType", "class_ogre_1_1_light.html#a42fedb6f221a6712b1c21849fb650819", null ],
+    [ "getMovableType", "class_ogre_1_1_light.html#a62b19c68359eefb19d826160046a21e4", null ],
     [ "getDerivedPosition", "class_ogre_1_1_light.html#a3696c6673ab5951f0456b6b1a21e19ff", null ],
     [ "getDerivedDirection", "class_ogre_1_1_light.html#ad36544a14b5c9c0c2fff82e5a94abdf8", null ],
     [ "setVisible", "class_ogre_1_1_light.html#a264a43fc2cf02093736eae60316dda8e", null ],
     [ "getAs4DVector", "class_ogre_1_1_light.html#a052612372ad31e661d14fc4c3f83c5d2", null ],
     [ "_getNearClipVolume", "class_ogre_1_1_light.html#adae366516f078c422412f45778753516", null ],
     [ "_getFrustumClipVolumes", "class_ogre_1_1_light.html#a93ac8bb5fd365c2469c96db4b676a955", null ],
-    [ "getTypeFlags", "class_ogre_1_1_light.html#a4dfd204f10889876a729263099d9bd03", null ],
-    [ "createAnimableValue", "class_ogre_1_1_light.html#a6e0be3df5d41752c0bedfcf9c89e492b", null ],
+    [ "getTypeFlags", "class_ogre_1_1_light.html#a0cfffdce70400c39919f6625647a4c98", null ],
+    [ "createAnimableValue", "class_ogre_1_1_light.html#a1a0671d05e0dcde78bb636e84bb13274", null ],
     [ "setCustomShadowCameraSetup", "class_ogre_1_1_light.html#a4a6f664fade2ac14d1ed5910b0d1a21a", null ],
     [ "resetCustomShadowCameraSetup", "class_ogre_1_1_light.html#a8dfbfef136e815bd6c8d2850b5364c44", null ],
     [ "getCustomShadowCameraSetup", "class_ogre_1_1_light.html#ada3b24400adba1e04a230b75ecb494bc", null ],
@@ -72,8 +77,8 @@ var class_ogre_1_1_light =
     [ "_deriveShadowFarClipDistance", "class_ogre_1_1_light.html#a37e3831c612d5a238c3fc9961a6700a4", null ],
     [ "_deriveShadowFarClipDistance", "class_ogre_1_1_light.html#af49bbb5413e184b1e2c6c0fece911747", null ],
     [ "_setCameraRelative", "class_ogre_1_1_light.html#ad353bf8b10bd5da88f598c137081dda1", null ],
-    [ "setCustomParameter", "class_ogre_1_1_light.html#a4e8ebf22380f3c76cd7e901dac362abb", null ],
-    [ "getCustomParameter", "class_ogre_1_1_light.html#ab1014fe5901c78f1b51f00227a6d9f84", null ],
+    [ "setCustomParameter", "class_ogre_1_1_light.html#a6c7a27f0850dabeb1e9a6f568f7dba1a", null ],
+    [ "getCustomParameter", "class_ogre_1_1_light.html#aa654189e8307f6d173bdc657c4005674", null ],
     [ "_updateCustomGpuParameter", "class_ogre_1_1_light.html#a66a5e07e85c60958f6a22590b6bed9a5", null ],
     [ "isInLightRange", "class_ogre_1_1_light.html#a690b8626f9bc29d87dce0ac536276bb1", null ],
     [ "isInLightRange", "class_ogre_1_1_light.html#a555aaeda1762a4820baf9648a2189b85", null ],
