@@ -24,8 +24,10 @@ var class_ogre_1_1_mesh =
     [ "destroySubMesh", "class_ogre_1_1_mesh.html#aa17c84354f568f0ecc2b44448dd5436f", null ],
     [ "getSubMeshIterator", "class_ogre_1_1_mesh.html#a1891dd7442acc39c7edbf6a064e61b70", null ],
     [ "getSubMeshes", "class_ogre_1_1_mesh.html#a651ca791817fdfaad9c81343379cd3ec", null ],
+    [ "resetVertexData", "class_ogre_1_1_mesh.html#a71a34cd0545829efa85f8f98801a0a11", null ],
+    [ "createVertexData", "class_ogre_1_1_mesh.html#adcbc72da23236ec8c702f9b07defe37b", null ],
     [ "clone", "class_ogre_1_1_mesh.html#af889e01f6ded554aa491bff2265dc963", null ],
-    [ "reload", "class_ogre_1_1_mesh.html#adca1dc667f145d4a4132811eaadf324f", null ],
+    [ "reload", "class_ogre_1_1_mesh.html#a20e44c2efe0428087c7bb279ce5bec82", null ],
     [ "getBounds", "class_ogre_1_1_mesh.html#aed764722fedfeda05cb090909dee872d", null ],
     [ "getBoundingSphereRadius", "class_ogre_1_1_mesh.html#a643eccce735ca9edfbc85af7e30f86b8", null ],
     [ "getBoneBoundingRadius", "class_ogre_1_1_mesh.html#adca70032c33851d494649d08a1db15a2", null ],
@@ -61,15 +63,17 @@ var class_ogre_1_1_mesh =
     [ "getHardwareBufferManager", "class_ogre_1_1_mesh.html#a91521eee21914f51e3352da3c30e0e7d", null ],
     [ "setVertexBufferPolicy", "class_ogre_1_1_mesh.html#ae128dc852bd40fa4ebdeced17ef60daa", null ],
     [ "setIndexBufferPolicy", "class_ogre_1_1_mesh.html#a59b3e51a70be90023f1adec878910e17", null ],
-    [ "getVertexBufferUsage", "class_ogre_1_1_mesh.html#a76cda9fbd7ed49e6a4344b9789581d29", null ],
-    [ "getIndexBufferUsage", "class_ogre_1_1_mesh.html#af76cfb32787287070eefb7f42489f435", null ],
+    [ "getVertexBufferUsage", "class_ogre_1_1_mesh.html#ad2055fa75b57f5e8cf2c541fb4c75646", null ],
+    [ "getIndexBufferUsage", "class_ogre_1_1_mesh.html#af63777d0e7fd1e68a2661f45ff10ee83", null ],
     [ "isVertexBufferShadowed", "class_ogre_1_1_mesh.html#a8fdfe3cf4cfd8023fd305306c73004aa", null ],
     [ "isIndexBufferShadowed", "class_ogre_1_1_mesh.html#af37305346744be4480479e764036116f", null ],
     [ "_rationaliseBoneAssignments", "class_ogre_1_1_mesh.html#a71ecbba89597f5b3138a5fde91362e27", null ],
     [ "_compileBoneAssignments", "class_ogre_1_1_mesh.html#a3eb5c9c7643dbfdfbf4c0d53af4308ef", null ],
     [ "_updateCompiledBoneAssignments", "class_ogre_1_1_mesh.html#ac074f9b704766962ad9ddf8bc6f0cb29", null ],
     [ "mergeAdjacentTexcoords", "class_ogre_1_1_mesh.html#a9d9525a1266762908ba8327b2e8fa729", null ],
-    [ "buildTangentVectors", "class_ogre_1_1_mesh.html#ab6390fa87d0109e9f1c7e44a5d602dbf", null ],
+    [ "buildTangentVectors", "class_ogre_1_1_mesh.html#ac4f09054c162ca7649f4768141d483c0", null ],
+    [ "buildTangentVectors", "class_ogre_1_1_mesh.html#af025575e381d8eb9fdd0b9a87389b4e2", null ],
+    [ "suggestTangentVectorBuildParams", "class_ogre_1_1_mesh.html#ae0dfaa2876b2cdb7e70d918a1facde23", null ],
     [ "suggestTangentVectorBuildParams", "class_ogre_1_1_mesh.html#a6984c7229db58040770269710f5b2ac1", null ],
     [ "buildEdgeList", "class_ogre_1_1_mesh.html#a3b18cd2008a447fe5fac98d06a541994", null ],
     [ "freeEdgeList", "class_ogre_1_1_mesh.html#aeb87f5aedfc18527dc33ee2ab5e38e9c", null ],
@@ -80,20 +84,20 @@ var class_ogre_1_1_mesh =
     [ "isEdgeListBuilt", "class_ogre_1_1_mesh.html#a331fef3569b8bf34d28f245bcb61f531", null ],
     [ "prepareMatricesForVertexBlend", "class_ogre_1_1_mesh.html#a5219b5a94daa96cd93c9496b83ddab08", null ],
     [ "softwareVertexBlend", "class_ogre_1_1_mesh.html#ae57798459c55a564d81097c2af35863a", null ],
-    [ "softwareVertexMorph", "class_ogre_1_1_mesh.html#af6df6730f0559aa78ef6e8eaa67bbc36", null ],
-    [ "softwareVertexPoseBlend", "class_ogre_1_1_mesh.html#a2401f255e53f67ad41c41aafbbe8dfe5", null ],
+    [ "softwareVertexMorph", "class_ogre_1_1_mesh.html#afafeb19fc2c495c0bd30d12e894cdee7", null ],
+    [ "softwareVertexPoseBlend", "class_ogre_1_1_mesh.html#a79bc3cb8331a30b335660a1a5c9e343d", null ],
     [ "getSubMeshNameMap", "class_ogre_1_1_mesh.html#a9f74a43715bc0916f106365965f394ed", null ],
     [ "setAutoBuildEdgeLists", "class_ogre_1_1_mesh.html#ac4f3cb35c7eebbe35d5734c8e3682c7d", null ],
     [ "getAutoBuildEdgeLists", "class_ogre_1_1_mesh.html#a822eb4b24327d48d1a2296ba2b45b01f", null ],
     [ "getSharedVertexDataAnimationType", "class_ogre_1_1_mesh.html#a22bcc255d120bdf3f98a94afc704dd16", null ],
     [ "getSharedVertexDataAnimationIncludesNormals", "class_ogre_1_1_mesh.html#ae1e3d5cc737c082595ebf61e2bdea693", null ],
-    [ "createAnimation", "class_ogre_1_1_mesh.html#a7e3f1373c1e932f7cae05165d14b98ac", null ],
-    [ "getAnimation", "class_ogre_1_1_mesh.html#aff3c09a6fcf7c416bb6d603f0aa1aec4", null ],
+    [ "createAnimation", "class_ogre_1_1_mesh.html#a4eb193c50750115c151558d3c50b4948", null ],
+    [ "getAnimation", "class_ogre_1_1_mesh.html#a9f1713b3588433e5103b1cf78845a392", null ],
     [ "_getAnimationImpl", "class_ogre_1_1_mesh.html#aeb4587d33c6e5e34817a1fe0c63ccd4f", null ],
-    [ "hasAnimation", "class_ogre_1_1_mesh.html#a7c8b70b2c53108ebc963f08959855dde", null ],
-    [ "removeAnimation", "class_ogre_1_1_mesh.html#a4caff2592e1e2b223cfe9f62843c5153", null ],
-    [ "getNumAnimations", "class_ogre_1_1_mesh.html#a8f8cad841ab891a46811361546105edb", null ],
-    [ "getAnimation", "class_ogre_1_1_mesh.html#aea9957c8c421bafe5fe1e57014d5c72d", null ],
+    [ "hasAnimation", "class_ogre_1_1_mesh.html#aacffa484720a6bf8d636410e3906db66", null ],
+    [ "removeAnimation", "class_ogre_1_1_mesh.html#adc2b8a8f13c32e6b3a5bfd69428176c9", null ],
+    [ "getNumAnimations", "class_ogre_1_1_mesh.html#a3310e5311fb1d3fd5c9b884eb9dfbd54", null ],
+    [ "getAnimation", "class_ogre_1_1_mesh.html#aefae3d1a46d20b5f1274f90cade7a78c", null ],
     [ "removeAllAnimations", "class_ogre_1_1_mesh.html#ae1c65aa0e5a0e8f283392b8b814f2e7e", null ],
     [ "getVertexDataByTrackHandle", "class_ogre_1_1_mesh.html#a393ed1639f49e7b0a3748f1ec3106a44", null ],
     [ "_determineAnimationTypes", "class_ogre_1_1_mesh.html#ad79899dc7b98696ada9e40e19093c9f2", null ],
