@@ -7,9 +7,11 @@ var class_ogre_1_1_mesh_lod_generator =
     [ "generateLodLevels", "class_ogre_1_1_mesh_lod_generator.html#a3cdd91b72ba29ee177e3c8714f6f07a4", null ],
     [ "generateAutoconfiguredLodLevels", "class_ogre_1_1_mesh_lod_generator.html#a70146c67825ae4397ec2944faa8fad51", null ],
     [ "getAutoconfig", "class_ogre_1_1_mesh_lod_generator.html#ab3286e6d287197cdc7124bea95c17a38", null ],
+    [ "clearPendingLodRequests", "class_ogre_1_1_mesh_lod_generator.html#ac9f094ac0ad5b7edc0f9cfa31a688545", null ],
     [ "_configureMeshLodUsage", "class_ogre_1_1_mesh_lod_generator.html#ab81791d208bed419def6edc84142a6b9", null ],
     [ "_resolveComponents", "class_ogre_1_1_mesh_lod_generator.html#a433212c3162f9f3d5ddd01f7c9fd6578", null ],
-    [ "_process", "class_ogre_1_1_mesh_lod_generator.html#a8592deced84fda25792d7df26f4af878", null ],
     [ "_generateManualLodLevels", "class_ogre_1_1_mesh_lod_generator.html#aacbece25b64bac20fa3435c377a6160d", null ],
-    [ "_initWorkQueue", "class_ogre_1_1_mesh_lod_generator.html#adb238ad1038faeeb4701105912b58844", null ]
+    [ "setInjectorListener", "class_ogre_1_1_mesh_lod_generator.html#ad6a653630b7eb92972a58d2d1ff0b28c", null ],
+    [ "getInjectorListener", "class_ogre_1_1_mesh_lod_generator.html#a4764fab3b7b5917b2658f9a8dcf2cdaa", null ],
+    [ "removeInjectorListener", "class_ogre_1_1_mesh_lod_generator.html#aaadc4e888f367edb3779755dc0b63ff9", null ]
 ];
\ No newline at end of file
