@@ -2,7 +2,7 @@ var class_ogre_1_1_overlay_system =
 [
     [ "OverlaySystem", "group___overlays.html#gacd5c773075a7591f717fb2382df9a829", null ],
     [ "~OverlaySystem", "group___overlays.html#gad399638657ead9815683c02bc7fdf149", null ],
-    [ "renderQueueStarted", "group___overlays.html#ga60d6f81cb051bf6369a06c74b913c317", null ],
+    [ "preRenderQueues", "group___overlays.html#gaf6fb54d4dea385f958844f3ab8947bd0", null ],
     [ "eventOccurred", "group___overlays.html#ga449a8ac2b301e045c0ceec32a2289f8b", null ],
     [ "getSingleton", "group___overlays.html#gaffcea382193d1edf6b21703f298d35ce", null ],
     [ "getSingletonPtr", "group___overlays.html#ga7945d431719c60ccb40d356e268f5558", null ]
