@@ -217,27 +217,26 @@ var class_ogre_1_1_scene_manager =
     [ "destroyQuery", "class_ogre_1_1_scene_manager.html#aa4e86291c054d59c1312c10322e6bc55", null ],
     [ "setShadowTechnique", "class_ogre_1_1_scene_manager.html#ad716d3752418408f073d9be9bbfe62d0", null ],
     [ "getShadowTechnique", "class_ogre_1_1_scene_manager.html#a65a4957bcb2a0fbffcb8ef37c1f6c6b1", null ],
-    [ "setShowDebugShadows", "class_ogre_1_1_scene_manager.html#af5efe579331ee28f3cbe3919db52751f", null ],
-    [ "getShowDebugShadows", "class_ogre_1_1_scene_manager.html#a9d05b4611701aac416246a876d29c740", null ],
     [ "setShadowColour", "class_ogre_1_1_scene_manager.html#a81238e49e69e53ccbc650413410f3f92", null ],
     [ "getShadowColour", "class_ogre_1_1_scene_manager.html#a7b12c8a965b7dd03f6b07d8acfa74079", null ],
     [ "setShadowDirectionalLightExtrusionDistance", "class_ogre_1_1_scene_manager.html#a69d6cb870736cd52b9ca48986e2e442b", null ],
     [ "getShadowDirectionalLightExtrusionDistance", "class_ogre_1_1_scene_manager.html#a95ae7048e7f5d3ffabf6d8acbcf12a0d", null ],
-    [ "setShadowFarDistance", "class_ogre_1_1_scene_manager.html#a103f475cd458b8bbdbf5ff679eeb20a8", null ],
-    [ "getShadowFarDistance", "class_ogre_1_1_scene_manager.html#abd8b3284334279f65fa12b5ff2571eca", null ],
-    [ "getShadowFarDistanceSquared", "class_ogre_1_1_scene_manager.html#abe1ca9b5f8ea5a7256b1d0ca1a2d8f6c", null ],
-    [ "setShadowIndexBufferSize", "class_ogre_1_1_scene_manager.html#a39c2c5902cd0eb7e86f272ed421cb408", null ],
-    [ "getShadowIndexBufferSize", "class_ogre_1_1_scene_manager.html#a5dce576ae8d38b4ed712991115cf1067", null ],
-    [ "getShadowCameraSetup", "class_ogre_1_1_scene_manager.html#aa26b5c8c1d5094b5a09f1794dc834caf", null ],
-    [ "setShadowUseInfiniteFarPlane", "class_ogre_1_1_scene_manager.html#add6959f7447251600bd189008636e887", null ],
     [ "isShadowTechniqueStencilBased", "class_ogre_1_1_scene_manager.html#ab394162f7351f8701df5a8fee182f7e6", null ],
     [ "isShadowTechniqueTextureBased", "class_ogre_1_1_scene_manager.html#af1a5829a519ed4c752abd7619685d67b", null ],
     [ "isShadowTechniqueModulative", "class_ogre_1_1_scene_manager.html#a9d64b8d561a3d6d7886a62209c834065", null ],
     [ "isShadowTechniqueAdditive", "class_ogre_1_1_scene_manager.html#a181ab08e5363f7d00053eac122ade55b", null ],
     [ "isShadowTechniqueIntegrated", "class_ogre_1_1_scene_manager.html#a8af3e6766eb128c8a8c02aab822e87fc", null ],
     [ "isShadowTechniqueInUse", "class_ogre_1_1_scene_manager.html#a22b489f7b4262b530c35435527ca11ea", null ],
+    [ "setShowDebugShadows", "class_ogre_1_1_scene_manager.html#af5efe579331ee28f3cbe3919db52751f", null ],
+    [ "getShowDebugShadows", "class_ogre_1_1_scene_manager.html#a9d05b4611701aac416246a876d29c740", null ],
+    [ "setShadowIndexBufferSize", "class_ogre_1_1_scene_manager.html#a39c2c5902cd0eb7e86f272ed421cb408", null ],
+    [ "getShadowIndexBufferSize", "class_ogre_1_1_scene_manager.html#a5dce576ae8d38b4ed712991115cf1067", null ],
+    [ "setShadowUseInfiniteFarPlane", "class_ogre_1_1_scene_manager.html#add6959f7447251600bd189008636e887", null ],
     [ "setShadowUseLightClipPlanes", "class_ogre_1_1_scene_manager.html#a40f296de8599657b70b7072921cbaa16", null ],
     [ "getShadowUseLightClipPlanes", "class_ogre_1_1_scene_manager.html#a2b4a3f7bbd31ecd067ae017e6571da1b", null ],
+    [ "setShadowFarDistance", "class_ogre_1_1_scene_manager.html#a103f475cd458b8bbdbf5ff679eeb20a8", null ],
+    [ "getShadowFarDistance", "class_ogre_1_1_scene_manager.html#abd8b3284334279f65fa12b5ff2571eca", null ],
+    [ "getShadowFarDistanceSquared", "class_ogre_1_1_scene_manager.html#abe1ca9b5f8ea5a7256b1d0ca1a2d8f6c", null ],
     [ "prepareShadowTextures", "class_ogre_1_1_scene_manager.html#a95cd8ff86a7178c2e37b2fcb485f64fa", null ],
     [ "setShadowTextureSize", "class_ogre_1_1_scene_manager.html#aa55e7f4482a2860c6378d97d8b5dfb57", null ],
     [ "setShadowTextureConfig", "class_ogre_1_1_scene_manager.html#adcbf0f49de53a7b67574481703d4fc03", null ],
@@ -251,6 +250,7 @@ var class_ogre_1_1_scene_manager =
     [ "setShadowTextureCountPerLightType", "class_ogre_1_1_scene_manager.html#a70f8eddf9b8617783fb7d0995b985a9a", null ],
     [ "getShadowTextureCountPerLightType", "class_ogre_1_1_scene_manager.html#af6c350b864e2bca3132abfd05b9a4b5e", null ],
     [ "setShadowTextureSettings", "class_ogre_1_1_scene_manager.html#a6efbc50e4ab15a4436cac712e049e79e", null ],
+    [ "setShadowTextureCompositor", "class_ogre_1_1_scene_manager.html#a42817122ac0cbd7e3d95305681e661f0", null ],
     [ "getShadowTexture", "class_ogre_1_1_scene_manager.html#a3cd9f9a98d1daff0c440c54e3082bedc", null ],
     [ "setShadowDirLightTextureOffset", "class_ogre_1_1_scene_manager.html#a3596ae101fe86d686cc67e9b3aad58cb", null ],
     [ "getShadowDirLightTextureOffset", "class_ogre_1_1_scene_manager.html#a43c5ca986d31852a89c6e2d06a025ee3", null ],
@@ -263,6 +263,7 @@ var class_ogre_1_1_scene_manager =
     [ "setShadowCasterRenderBackFaces", "class_ogre_1_1_scene_manager.html#a9b4c5bd6f47373ca69a397edb49f3520", null ],
     [ "getShadowCasterRenderBackFaces", "class_ogre_1_1_scene_manager.html#a89d5a39615a8edb5923cef433aba210d", null ],
     [ "setShadowCameraSetup", "class_ogre_1_1_scene_manager.html#acd2de135b378c048c4c4a2dff4c73ac8", null ],
+    [ "getShadowCameraSetup", "class_ogre_1_1_scene_manager.html#aa26b5c8c1d5094b5a09f1794dc834caf", null ],
     [ "_setActiveCompositorChain", "class_ogre_1_1_scene_manager.html#a9a5c7191febaebc65eb605202c0062cb", null ],
     [ "setLateMaterialResolving", "class_ogre_1_1_scene_manager.html#a974ac50bee0284e4bf69dcffa836c11f", null ],
     [ "isLateMaterialResolving", "class_ogre_1_1_scene_manager.html#ab7f2ff2c074c944a8fca85bc9ef0e8b8", null ],
@@ -325,8 +326,9 @@ var class_ogre_1_1_scene_manager =
     [ "_notifyEntityMeshLodChanged", "class_ogre_1_1_scene_manager.html#ad0a84e6426cad7dfd721fb5fccd9976c", null ],
     [ "_notifyEntityMaterialLodChanged", "class_ogre_1_1_scene_manager.html#a272d1a76e7854e51f824f0099a4910cf", null ],
     [ "_handleLodEvents", "class_ogre_1_1_scene_manager.html#a72e39912a34617ffa0455f859ec438c3", null ],
-    [ "_getCurrentRenderStage", "class_ogre_1_1_scene_manager.html#a027227b35d611d5b0f07ce0f93403b19", null ],
-    [ "_getAutoParamDataSource", "class_ogre_1_1_scene_manager.html#ab681d6fe3691fbb8f964bbd6827dbfe2", null ],
+    [ "_getCurrentRenderStage", "class_ogre_1_1_scene_manager.html#aaa36e203e1ba3eeab880e4c51a51efae", null ],
+    [ "_getAutoParamDataSource", "class_ogre_1_1_scene_manager.html#aaa72eaf9861531687d7bb2a4cc989f42", null ],
+    [ "setVPRTCameras", "class_ogre_1_1_scene_manager.html#afcc3ad744c0bd91c63db369a70141482", null ],
     [ "SceneMgrQueuedRenderableVisitor", "class_ogre_1_1_scene_manager.html#a25811fa0c23672b27dccfffd48bec43a", null ],
     [ "PT_PLANE", "class_ogre_1_1_scene_manager.html#aba1522f277022ea928223ef9bb8f2806", null ],
     [ "PT_CUBE", "class_ogre_1_1_scene_manager.html#aeefb47c4d2f8b961381e9b25ab31c22d", null ],
