@@ -2,7 +2,5 @@ var dir_3ae3e761bf77602e3076fcfbcef7a68c =
 [
     [ "OgreOctreeZone.h", "_ogre_octree_zone_8h.html", null ],
     [ "OgreOctreeZoneOctree.h", "_ogre_octree_zone_octree_8h.html", "_ogre_octree_zone_octree_8h" ],
-    [ "OgreOctreeZonePlugin.h", "_ogre_octree_zone_plugin_8h.html", [
-      [ "Ogre::OctreeZonePlugin", "class_ogre_1_1_octree_zone_plugin.html", "class_ogre_1_1_octree_zone_plugin" ]
-    ] ]
+    [ "OgreOctreeZonePlugin.h", "_ogre_octree_zone_plugin_8h.html", "_ogre_octree_zone_plugin_8h" ]
 ];
\ No newline at end of file
