@@ -1,9 +1,7 @@
 var dir_9ba68fabe7d45cd05996335e8214ea54 =
 [
     [ "Ogre.h", "_ogre_8h.html", null ],
-    [ "OgreAlignedAllocator.h", "_ogre_aligned_allocator_8h.html", [
-      [ "Ogre::AlignedAllocator< T, Alignment >::rebind< Other >", "struct_ogre_1_1_aligned_allocator_1_1rebind.html", "struct_ogre_1_1_aligned_allocator_1_1rebind" ]
-    ] ],
+    [ "OgreAlignedAllocator.h", "_ogre_aligned_allocator_8h.html", "_ogre_aligned_allocator_8h" ],
     [ "OgreAnimable.h", "_ogre_animable_8h.html", null ],
     [ "OgreAnimation.h", "_ogre_animation_8h.html", null ],
     [ "OgreAnimationState.h", "_ogre_animation_state_8h.html", "_ogre_animation_state_8h" ],
@@ -16,34 +14,22 @@ var dir_9ba68fabe7d45cd05996335e8214ea54 =
     [ "OgreAutoParamDataSource.h", "_ogre_auto_param_data_source_8h.html", null ],
     [ "OgreAxisAlignedBox.h", "_ogre_axis_aligned_box_8h.html", null ],
     [ "OgreBillboard.h", "_ogre_billboard_8h.html", null ],
-    [ "OgreBillboardChain.h", "_ogre_billboard_chain_8h.html", [
-      [ "Ogre::BillboardChain::Element", "class_ogre_1_1_billboard_chain_1_1_element.html", "class_ogre_1_1_billboard_chain_1_1_element" ]
-    ] ],
+    [ "OgreBillboardChain.h", "_ogre_billboard_chain_8h.html", "_ogre_billboard_chain_8h" ],
     [ "OgreBillboardParticleRenderer.h", "_ogre_billboard_particle_renderer_8h.html", null ],
     [ "OgreBillboardSet.h", "_ogre_billboard_set_8h.html", "_ogre_billboard_set_8h" ],
     [ "OgreBitwise.h", "_ogre_bitwise_8h.html", "_ogre_bitwise_8h" ],
     [ "OgreBlendMode.h", "_ogre_blend_mode_8h.html", "_ogre_blend_mode_8h" ],
     [ "OgreBone.h", "_ogre_bone_8h.html", null ],
-    [ "OgreCamera.h", "_ogre_camera_8h.html", [
-      [ "Ogre::Camera::Listener", "class_ogre_1_1_camera_1_1_listener.html", "class_ogre_1_1_camera_1_1_listener" ]
-    ] ],
+    [ "OgreCamera.h", "_ogre_camera_8h.html", "_ogre_camera_8h" ],
     [ "OgreCodec.h", "_ogre_codec_8h.html", null ],
     [ "OgreColourValue.h", "_ogre_colour_value_8h.html", "_ogre_colour_value_8h" ],
     [ "OgreCommon.h", "_ogre_common_8h.html", "_ogre_common_8h" ],
-    [ "OgreCompositionPass.h", "_ogre_composition_pass_8h.html", [
-      [ "Ogre::CompositionPass::InputTex", "struct_ogre_1_1_composition_pass_1_1_input_tex.html", "struct_ogre_1_1_composition_pass_1_1_input_tex" ]
-    ] ],
+    [ "OgreCompositionPass.h", "_ogre_composition_pass_8h.html", "_ogre_composition_pass_8h" ],
     [ "OgreCompositionTargetPass.h", "_ogre_composition_target_pass_8h.html", null ],
-    [ "OgreCompositionTechnique.h", "_ogre_composition_technique_8h.html", [
-      [ "Ogre::CompositionTechnique::TextureDefinition", "class_ogre_1_1_composition_technique_1_1_texture_definition.html", "class_ogre_1_1_composition_technique_1_1_texture_definition" ]
-    ] ],
+    [ "OgreCompositionTechnique.h", "_ogre_composition_technique_8h.html", "_ogre_composition_technique_8h" ],
     [ "OgreCompositor.h", "_ogre_compositor_8h.html", null ],
     [ "OgreCompositorChain.h", "_ogre_compositor_chain_8h.html", null ],
-    [ "OgreCompositorInstance.h", "_ogre_compositor_instance_8h.html", [
-      [ "Ogre::CompositorInstance::Listener", "class_ogre_1_1_compositor_instance_1_1_listener.html", "class_ogre_1_1_compositor_instance_1_1_listener" ],
-      [ "Ogre::CompositorInstance::RenderSystemOperation", "class_ogre_1_1_compositor_instance_1_1_render_system_operation.html", "class_ogre_1_1_compositor_instance_1_1_render_system_operation" ],
-      [ "Ogre::CompositorInstance::TargetOperation", "class_ogre_1_1_compositor_instance_1_1_target_operation.html", "class_ogre_1_1_compositor_instance_1_1_target_operation" ]
-    ] ],
+    [ "OgreCompositorInstance.h", "_ogre_compositor_instance_8h.html", "_ogre_compositor_instance_8h" ],
     [ "OgreCompositorLogic.h", "_ogre_compositor_logic_8h.html", null ],
     [ "OgreCompositorManager.h", "_ogre_compositor_manager_8h.html", null ],
     [ "OgreConfig.h", "_ogre_config_8h.html", "_ogre_config_8h" ],
@@ -55,10 +41,9 @@ var dir_9ba68fabe7d45cd05996335e8214ea54 =
     [ "OgreConvexBody.h", "_ogre_convex_body_8h.html", null ],
     [ "OgreCustomCompositionPass.h", "_ogre_custom_composition_pass_8h.html", null ],
     [ "OgreDataStream.h", "_ogre_data_stream_8h.html", "_ogre_data_stream_8h" ],
-    [ "OgreDefaultDebugDrawer.h", "_ogre_default_debug_drawer_8h.html", [
-      [ "Ogre::DefaultDebugDrawer", "class_ogre_1_1_default_debug_drawer.html", "class_ogre_1_1_default_debug_drawer" ]
-    ] ],
+    [ "OgreDefaultDebugDrawer.h", "_ogre_default_debug_drawer_8h.html", "_ogre_default_debug_drawer_8h" ],
     [ "OgreDefaultHardwareBufferManager.h", "_ogre_default_hardware_buffer_manager_8h.html", "_ogre_default_hardware_buffer_manager_8h" ],
+    [ "OgreDefaultWorkQueue.h", "_ogre_default_work_queue_8h.html", "_ogre_default_work_queue_8h" ],
     [ "OgreDeflate.h", "_ogre_deflate_8h.html", "_ogre_deflate_8h" ],
     [ "OgreDeprecated.h", "_ogre_deprecated_8h.html", "_ogre_deprecated_8h" ],
     [ "OgreDepthBuffer.h", "_ogre_depth_buffer_8h.html", null ],
@@ -66,20 +51,14 @@ var dir_9ba68fabe7d45cd05996335e8214ea54 =
     [ "OgreDualQuaternion.h", "_ogre_dual_quaternion_8h.html", null ],
     [ "OgreDynLib.h", "_ogre_dyn_lib_8h.html", "_ogre_dyn_lib_8h" ],
     [ "OgreDynLibManager.h", "_ogre_dyn_lib_manager_8h.html", null ],
-    [ "OgreEdgeListBuilder.h", "_ogre_edge_list_builder_8h.html", [
-      [ "Ogre::EdgeData::Edge", "struct_ogre_1_1_edge_data_1_1_edge.html", "struct_ogre_1_1_edge_data_1_1_edge" ],
-      [ "Ogre::EdgeData::EdgeGroup", "struct_ogre_1_1_edge_data_1_1_edge_group.html", "struct_ogre_1_1_edge_data_1_1_edge_group" ],
-      [ "Ogre::EdgeData::Triangle", "struct_ogre_1_1_edge_data_1_1_triangle.html", "struct_ogre_1_1_edge_data_1_1_triangle" ]
-    ] ],
+    [ "OgreEdgeListBuilder.h", "_ogre_edge_list_builder_8h.html", "_ogre_edge_list_builder_8h" ],
     [ "OgreEntity.h", "_ogre_entity_8h.html", null ],
     [ "OgreException.h", "_ogre_exception_8h.html", "_ogre_exception_8h" ],
     [ "OgreExternalTextureSource.h", "_ogre_external_texture_source_8h.html", "_ogre_external_texture_source_8h" ],
     [ "OgreExternalTextureSourceManager.h", "_ogre_external_texture_source_manager_8h.html", null ],
     [ "OgreFactoryObj.h", "_ogre_factory_obj_8h.html", null ],
     [ "OgreFileSystem.h", "_ogre_file_system_8h.html", "_ogre_file_system_8h" ],
-    [ "OgreFileSystemLayer.h", "_ogre_file_system_layer_8h.html", [
-      [ "Ogre::FileSystemLayer", "class_ogre_1_1_file_system_layer.html", "class_ogre_1_1_file_system_layer" ]
-    ] ],
+    [ "OgreFileSystemLayer.h", "_ogre_file_system_layer_8h.html", "_ogre_file_system_layer_8h" ],
     [ "OgreFrameListener.h", "_ogre_frame_listener_8h.html", null ],
     [ "OgreFrustum.h", "_ogre_frustum_8h.html", "_ogre_frustum_8h" ],
     [ "OgreGpuProgram.h", "_ogre_gpu_program_8h.html", "_ogre_gpu_program_8h" ],
@@ -99,9 +78,7 @@ var dir_9ba68fabe7d45cd05996335e8214ea54 =
     [ "OgreHighLevelGpuProgram.h", "_ogre_high_level_gpu_program_8h.html", null ],
     [ "OgreHighLevelGpuProgramManager.h", "_ogre_high_level_gpu_program_manager_8h.html", null ],
     [ "OgreImage.h", "_ogre_image_8h.html", "_ogre_image_8h" ],
-    [ "OgreImageCodec.h", "_ogre_image_codec_8h.html", [
-      [ "Ogre::ImageCodec::ImageData", "class_ogre_1_1_image_codec_1_1_image_data.html", "class_ogre_1_1_image_codec_1_1_image_data" ]
-    ] ],
+    [ "OgreImageCodec.h", "_ogre_image_codec_8h.html", null ],
     [ "OgreInstanceBatch.h", "_ogre_instance_batch_8h.html", null ],
     [ "OgreInstanceBatchHW.h", "_ogre_instance_batch_h_w_8h.html", null ],
     [ "OgreInstanceBatchHW_VTF.h", "_ogre_instance_batch_h_w___v_t_f_8h.html", null ],
@@ -109,49 +86,30 @@ var dir_9ba68fabe7d45cd05996335e8214ea54 =
     [ "OgreInstanceBatchVTF.h", "_ogre_instance_batch_v_t_f_8h.html", null ],
     [ "OgreInstancedEntity.h", "_ogre_instanced_entity_8h.html", null ],
     [ "OgreInstanceManager.h", "_ogre_instance_manager_8h.html", null ],
-    [ "OgreIteratorWrapper.h", "_ogre_iterator_wrapper_8h.html", [
-      [ "Ogre::ConstMapIterator< T >", "class_ogre_1_1_const_map_iterator.html", "class_ogre_1_1_const_map_iterator" ],
-      [ "Ogre::ConstVectorIterator< T >", "class_ogre_1_1_const_vector_iterator.html", "class_ogre_1_1_const_vector_iterator" ],
-      [ "Ogre::IteratorWrapper< T, IteratorType, ValType >", "class_ogre_1_1_iterator_wrapper.html", "class_ogre_1_1_iterator_wrapper" ],
-      [ "Ogre::MapIterator< T >", "class_ogre_1_1_map_iterator.html", "class_ogre_1_1_map_iterator" ],
-      [ "Ogre::MapIteratorWrapper< T, IteratorType >", "class_ogre_1_1_map_iterator_wrapper.html", "class_ogre_1_1_map_iterator_wrapper" ],
-      [ "Ogre::VectorIterator< T >", "class_ogre_1_1_vector_iterator.html", "class_ogre_1_1_vector_iterator" ],
-      [ "Ogre::VectorIteratorWrapper< T, IteratorType >", "class_ogre_1_1_vector_iterator_wrapper.html", "class_ogre_1_1_vector_iterator_wrapper" ]
-    ] ],
+    [ "OgreIteratorWrapper.h", "_ogre_iterator_wrapper_8h.html", "_ogre_iterator_wrapper_8h" ],
     [ "OgreIteratorWrappers.h", "_ogre_iterator_wrappers_8h.html", null ],
-    [ "OgreKeyFrame.h", "_ogre_key_frame_8h.html", [
-      [ "Ogre::VertexPoseKeyFrame::PoseRef", "struct_ogre_1_1_vertex_pose_key_frame_1_1_pose_ref.html", "struct_ogre_1_1_vertex_pose_key_frame_1_1_pose_ref" ]
-    ] ],
+    [ "OgreKeyFrame.h", "_ogre_key_frame_8h.html", "_ogre_key_frame_8h" ],
     [ "OgreLight.h", "_ogre_light_8h.html", null ],
     [ "OgreLodListener.h", "_ogre_lod_listener_8h.html", null ],
     [ "OgreLodStrategy.h", "_ogre_lod_strategy_8h.html", null ],
     [ "OgreLodStrategyManager.h", "_ogre_lod_strategy_manager_8h.html", null ],
     [ "OgreLog.h", "_ogre_log_8h.html", "_ogre_log_8h" ],
     [ "OgreLogManager.h", "_ogre_log_manager_8h.html", null ],
-    [ "OgreManualObject.h", "_ogre_manual_object_8h.html", [
-      [ "Ogre::ManualObject::ManualObjectSection", "class_ogre_1_1_manual_object_1_1_manual_object_section.html", "class_ogre_1_1_manual_object_1_1_manual_object_section" ]
-    ] ],
+    [ "OgreManualObject.h", "_ogre_manual_object_8h.html", "_ogre_manual_object_8h" ],
     [ "OgreMaterial.h", "_ogre_material_8h.html", null ],
     [ "OgreMaterialManager.h", "_ogre_material_manager_8h.html", "_ogre_material_manager_8h" ],
-    [ "OgreMaterialSerializer.h", "_ogre_material_serializer_8h.html", [
-      [ "Ogre::MaterialSerializer::Listener", "class_ogre_1_1_material_serializer_1_1_listener.html", "class_ogre_1_1_material_serializer_1_1_listener" ]
-    ] ],
+    [ "OgreMaterialSerializer.h", "_ogre_material_serializer_8h.html", "_ogre_material_serializer_8h" ],
     [ "OgreMath.h", "_ogre_math_8h.html", "_ogre_math_8h" ],
     [ "OgreMatrix3.h", "_ogre_matrix3_8h.html", "_ogre_matrix3_8h" ],
     [ "OgreMatrix4.h", "_ogre_matrix4_8h.html", "_ogre_matrix4_8h" ],
     [ "OgreMesh.h", "_ogre_mesh_8h.html", null ],
     [ "OgreMeshManager.h", "_ogre_mesh_manager_8h.html", null ],
     [ "OgreMeshSerializer.h", "_ogre_mesh_serializer_8h.html", "_ogre_mesh_serializer_8h" ],
-    [ "OgreMovableObject.h", "_ogre_movable_object_8h.html", [
-      [ "Ogre::MovableObject::Listener", "class_ogre_1_1_movable_object_1_1_listener.html", "class_ogre_1_1_movable_object_1_1_listener" ]
-    ] ],
+    [ "OgreMovableObject.h", "_ogre_movable_object_8h.html", "_ogre_movable_object_8h" ],
     [ "OgreMovablePlane.h", "_ogre_movable_plane_8h.html", null ],
     [ "OgreMurmurHash3.h", "_ogre_murmur_hash3_8h.html", "_ogre_murmur_hash3_8h" ],
     [ "OgreNameGenerator.h", "_ogre_name_generator_8h.html", null ],
-    [ "OgreNode.h", "_ogre_node_8h.html", [
-      [ "Ogre::Node::Listener", "class_ogre_1_1_node_1_1_listener.html", "class_ogre_1_1_node_1_1_listener" ]
-    ] ],
-    [ "OgreNumerics.h", "_ogre_numerics_8h.html", null ],
+    [ "OgreNode.h", "_ogre_node_8h.html", "_ogre_node_8h" ],
     [ "OgreOptimisedUtil.h", "_ogre_optimised_util_8h.html", "_ogre_optimised_util_8h" ],
     [ "OgreParticle.h", "_ogre_particle_8h.html", null ],
     [ "OgreParticleAffector.h", "_ogre_particle_affector_8h.html", null ],
@@ -179,12 +137,8 @@ var dir_9ba68fabe7d45cd05996335e8214ea54 =
     [ "OgreQuaternion.h", "_ogre_quaternion_8h.html", null ],
     [ "OgreRay.h", "_ogre_ray_8h.html", null ],
     [ "OgreRectangle2D.h", "_ogre_rectangle2_d_8h.html", null ],
-    [ "OgreRenderable.h", "_ogre_renderable_8h.html", [
-      [ "Ogre::Renderable::Visitor", "class_ogre_1_1_renderable_1_1_visitor.html", "class_ogre_1_1_renderable_1_1_visitor" ]
-    ] ],
-    [ "OgreRenderObjectListener.h", "_ogre_render_object_listener_8h.html", [
-      [ "Ogre::RenderObjectListener", "class_ogre_1_1_render_object_listener.html", "class_ogre_1_1_render_object_listener" ]
-    ] ],
+    [ "OgreRenderable.h", "_ogre_renderable_8h.html", "_ogre_renderable_8h" ],
+    [ "OgreRenderObjectListener.h", "_ogre_render_object_listener_8h.html", "_ogre_render_object_listener_8h" ],
     [ "OgreRenderOperation.h", "_ogre_render_operation_8h.html", null ],
     [ "OgreRenderQueue.h", "_ogre_render_queue_8h.html", "_ogre_render_queue_8h" ],
     [ "OgreRenderQueueListener.h", "_ogre_render_queue_listener_8h.html", null ],
@@ -199,30 +153,26 @@ var dir_9ba68fabe7d45cd05996335e8214ea54 =
     [ "OgreRenderToVertexBuffer.h", "_ogre_render_to_vertex_buffer_8h.html", null ],
     [ "OgreRenderWindow.h", "_ogre_render_window_8h.html", null ],
     [ "OgreResource.h", "_ogre_resource_8h.html", "_ogre_resource_8h" ],
-    [ "OgreResourceBackgroundQueue.h", "_ogre_resource_background_queue_8h.html", "_ogre_resource_background_queue_8h" ],
+    [ "OgreResourceBackgroundQueue.h", "_ogre_resource_background_queue_8h.html", null ],
     [ "OgreResourceGroupManager.h", "_ogre_resource_group_manager_8h.html", "_ogre_resource_group_manager_8h" ],
-    [ "OgreResourceManager.h", "_ogre_resource_manager_8h.html", [
-      [ "Ogre::Pool< T >", "class_ogre_1_1_pool.html", "class_ogre_1_1_pool" ],
-      [ "Ogre::ResourceManager::ResourcePool", "class_ogre_1_1_resource_manager_1_1_resource_pool.html", "class_ogre_1_1_resource_manager_1_1_resource_pool" ]
-    ] ],
+    [ "OgreResourceManager.h", "_ogre_resource_manager_8h.html", "_ogre_resource_manager_8h" ],
     [ "OgreRibbonTrail.h", "_ogre_ribbon_trail_8h.html", null ],
     [ "OgreRoot.h", "_ogre_root_8h.html", "_ogre_root_8h" ],
     [ "OgreRotationalSpline.h", "_ogre_rotational_spline_8h.html", null ],
     [ "OgreSceneManager.h", "_ogre_scene_manager_8h.html", "_ogre_scene_manager_8h" ],
-    [ "OgreSceneManagerEnumerator.h", "_ogre_scene_manager_enumerator_8h.html", null ],
     [ "OgreSceneNode.h", "_ogre_scene_node_8h.html", null ],
     [ "OgreSceneQuery.h", "_ogre_scene_query_8h.html", "_ogre_scene_query_8h" ],
     [ "OgreScriptCompiler.h", "_ogre_script_compiler_8h.html", "_ogre_script_compiler_8h" ],
     [ "OgreScriptLoader.h", "_ogre_script_loader_8h.html", null ],
     [ "OgreScriptTranslator.h", "_ogre_script_translator_8h.html", null ],
-    [ "OgreSerializer.h", "_ogre_serializer_8h.html", "_ogre_serializer_8h" ],
+    [ "OgreSerializer.h", "_ogre_serializer_8h.html", null ],
     [ "OgreShadowCameraSetup.h", "_ogre_shadow_camera_setup_8h.html", null ],
     [ "OgreShadowCameraSetupFocused.h", "_ogre_shadow_camera_setup_focused_8h.html", null ],
     [ "OgreShadowCameraSetupLiSPSM.h", "_ogre_shadow_camera_setup_li_s_p_s_m_8h.html", null ],
     [ "OgreShadowCameraSetupPlaneOptimal.h", "_ogre_shadow_camera_setup_plane_optimal_8h.html", null ],
     [ "OgreShadowCameraSetupPSSM.h", "_ogre_shadow_camera_setup_p_s_s_m_8h.html", null ],
     [ "OgreShadowCaster.h", "_ogre_shadow_caster_8h.html", "_ogre_shadow_caster_8h" ],
-    [ "OgreSharedPtr.h", "_ogre_shared_ptr_8h.html", "_ogre_shared_ptr_8h" ],
+    [ "OgreSharedPtr.h", "_ogre_shared_ptr_8h.html", null ],
     [ "OgreSimpleRenderable.h", "_ogre_simple_renderable_8h.html", null ],
     [ "OgreSimpleSpline.h", "_ogre_simple_spline_8h.html", null ],
     [ "OgreSingleton.h", "_ogre_singleton_8h.html", null ],
@@ -232,20 +182,9 @@ var dir_9ba68fabe7d45cd05996335e8214ea54 =
     [ "OgreSkeletonManager.h", "_ogre_skeleton_manager_8h.html", null ],
     [ "OgreSkeletonSerializer.h", "_ogre_skeleton_serializer_8h.html", "_ogre_skeleton_serializer_8h" ],
     [ "OgreSphere.h", "_ogre_sphere_8h.html", null ],
-    [ "OgreStaticGeometry.h", "_ogre_static_geometry_8h.html", [
-      [ "Ogre::StaticGeometry::GeometryBucket", "class_ogre_1_1_static_geometry_1_1_geometry_bucket.html", "class_ogre_1_1_static_geometry_1_1_geometry_bucket" ],
-      [ "Ogre::StaticGeometry::LODBucket", "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html", "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket" ],
-      [ "Ogre::StaticGeometry::MaterialBucket", "class_ogre_1_1_static_geometry_1_1_material_bucket.html", "class_ogre_1_1_static_geometry_1_1_material_bucket" ],
-      [ "Ogre::StaticGeometry::OptimisedSubMeshGeometry", "class_ogre_1_1_static_geometry_1_1_optimised_sub_mesh_geometry.html", "class_ogre_1_1_static_geometry_1_1_optimised_sub_mesh_geometry" ],
-      [ "Ogre::StaticGeometry::QueuedGeometry", "struct_ogre_1_1_static_geometry_1_1_queued_geometry.html", "struct_ogre_1_1_static_geometry_1_1_queued_geometry" ],
-      [ "Ogre::StaticGeometry::QueuedSubMesh", "struct_ogre_1_1_static_geometry_1_1_queued_sub_mesh.html", "struct_ogre_1_1_static_geometry_1_1_queued_sub_mesh" ],
-      [ "Ogre::StaticGeometry::Region", "class_ogre_1_1_static_geometry_1_1_region.html", "class_ogre_1_1_static_geometry_1_1_region" ],
-      [ "Ogre::StaticGeometry::SubMeshLodGeometryLink", "struct_ogre_1_1_static_geometry_1_1_sub_mesh_lod_geometry_link.html", "struct_ogre_1_1_static_geometry_1_1_sub_mesh_lod_geometry_link" ]
-    ] ],
+    [ "OgreStaticGeometry.h", "_ogre_static_geometry_8h.html", "_ogre_static_geometry_8h" ],
     [ "OgreStdHeaders.h", "_ogre_std_headers_8h.html", null ],
-    [ "OgreStreamSerialiser.h", "_ogre_stream_serialiser_8h.html", [
-      [ "Ogre::StreamSerialiser::Chunk", "struct_ogre_1_1_stream_serialiser_1_1_chunk.html", "struct_ogre_1_1_stream_serialiser_1_1_chunk" ]
-    ] ],
+    [ "OgreStreamSerialiser.h", "_ogre_stream_serialiser_8h.html", "_ogre_stream_serialiser_8h" ],
     [ "OgreString.h", "_ogre_string_8h.html", "_ogre_string_8h" ],
     [ "OgreStringConverter.h", "_ogre_string_converter_8h.html", "_ogre_string_converter_8h" ],
     [ "OgreStringInterface.h", "_ogre_string_interface_8h.html", "_ogre_string_interface_8h" ],
@@ -253,37 +192,21 @@ var dir_9ba68fabe7d45cd05996335e8214ea54 =
     [ "OgreSubEntity.h", "_ogre_sub_entity_8h.html", null ],
     [ "OgreSubMesh.h", "_ogre_sub_mesh_8h.html", null ],
     [ "OgreTagPoint.h", "_ogre_tag_point_8h.html", null ],
-    [ "OgreTangentSpaceCalc.h", "_ogre_tangent_space_calc_8h.html", [
-      [ "Ogre::TangentSpaceCalc::IndexRemap", "struct_ogre_1_1_tangent_space_calc_1_1_index_remap.html", "struct_ogre_1_1_tangent_space_calc_1_1_index_remap" ],
-      [ "Ogre::TangentSpaceCalc::Result", "struct_ogre_1_1_tangent_space_calc_1_1_result.html", "struct_ogre_1_1_tangent_space_calc_1_1_result" ]
-    ] ],
-    [ "OgreTechnique.h", "_ogre_technique_8h.html", [
-      [ "Ogre::Technique::GPUDeviceNameRule", "struct_ogre_1_1_technique_1_1_g_p_u_device_name_rule.html", "struct_ogre_1_1_technique_1_1_g_p_u_device_name_rule" ],
-      [ "Ogre::Technique::GPUVendorRule", "struct_ogre_1_1_technique_1_1_g_p_u_vendor_rule.html", "struct_ogre_1_1_technique_1_1_g_p_u_vendor_rule" ]
-    ] ],
+    [ "OgreTangentSpaceCalc.h", "_ogre_tangent_space_calc_8h.html", "_ogre_tangent_space_calc_8h" ],
+    [ "OgreTechnique.h", "_ogre_technique_8h.html", "_ogre_technique_8h" ],
     [ "OgreTexture.h", "_ogre_texture_8h.html", "_ogre_texture_8h" ],
     [ "OgreTextureManager.h", "_ogre_texture_manager_8h.html", null ],
     [ "OgreTextureUnitState.h", "_ogre_texture_unit_state_8h.html", "_ogre_texture_unit_state_8h" ],
-    [ "OgreTimer.h", "_ogre_timer_8h.html", [
-      [ "Ogre::Timer", "class_ogre_1_1_timer.html", "class_ogre_1_1_timer" ]
-    ] ],
-    [ "OgreUnifiedHighLevelGpuProgram.h", "_ogre_unified_high_level_gpu_program_8h.html", null ],
+    [ "OgreTimer.h", "_ogre_timer_8h.html", "_ogre_timer_8h" ],
     [ "OgreUserObjectBindings.h", "_ogre_user_object_bindings_8h.html", null ],
     [ "OgreVector.h", "_ogre_vector_8h.html", null ],
     [ "OgreVector2.h", "_ogre_vector2_8h.html", null ],
     [ "OgreVector3.h", "_ogre_vector3_8h.html", null ],
     [ "OgreVector4.h", "_ogre_vector4_8h.html", null ],
-    [ "OgreVertexBoneAssignment.h", "_ogre_vertex_bone_assignment_8h.html", "_ogre_vertex_bone_assignment_8h" ],
+    [ "OgreVertexBoneAssignment.h", "_ogre_vertex_bone_assignment_8h.html", null ],
     [ "OgreVertexIndexData.h", "_ogre_vertex_index_data_8h.html", "_ogre_vertex_index_data_8h" ],
-    [ "OgreViewport.h", "_ogre_viewport_8h.html", [
-      [ "Ogre::Viewport::Listener", "class_ogre_1_1_viewport_1_1_listener.html", "class_ogre_1_1_viewport_1_1_listener" ]
-    ] ],
+    [ "OgreViewport.h", "_ogre_viewport_8h.html", "_ogre_viewport_8h" ],
     [ "OgreWireBoundingBox.h", "_ogre_wire_bounding_box_8h.html", null ],
-    [ "OgreWorkQueue.h", "_ogre_work_queue_8h.html", [
-      [ "Ogre::WorkQueue::Request", "class_ogre_1_1_work_queue_1_1_request.html", "class_ogre_1_1_work_queue_1_1_request" ],
-      [ "Ogre::WorkQueue::RequestHandler", "class_ogre_1_1_work_queue_1_1_request_handler.html", "class_ogre_1_1_work_queue_1_1_request_handler" ],
-      [ "Ogre::WorkQueue::Response", "struct_ogre_1_1_work_queue_1_1_response.html", "struct_ogre_1_1_work_queue_1_1_response" ],
-      [ "Ogre::WorkQueue::ResponseHandler", "class_ogre_1_1_work_queue_1_1_response_handler.html", "class_ogre_1_1_work_queue_1_1_response_handler" ]
-    ] ],
+    [ "OgreWorkQueue.h", "_ogre_work_queue_8h.html", "_ogre_work_queue_8h" ],
     [ "OgreZip.h", "_ogre_zip_8h.html", null ]
 ];
\ No newline at end of file
