@@ -6,9 +6,7 @@ var dir_d32b938072b268341fd046bfca590d66 =
     [ "OgreApplicationContextQt.h", "_ogre_application_context_qt_8h.html", "_ogre_application_context_qt_8h" ],
     [ "OgreBitesConfigDialog.h", "_ogre_bites_config_dialog_8h.html", "_ogre_bites_config_dialog_8h" ],
     [ "OgreCameraMan.h", "_ogre_camera_man_8h.html", "_ogre_camera_man_8h" ],
-    [ "OgreImGuiInputListener.h", "_ogre_im_gui_input_listener_8h.html", [
-      [ "OgreBites::ImGuiInputListener", "struct_ogre_bites_1_1_im_gui_input_listener.html", "struct_ogre_bites_1_1_im_gui_input_listener" ]
-    ] ],
+    [ "OgreImGuiInputListener.h", "_ogre_im_gui_input_listener_8h.html", "_ogre_im_gui_input_listener_8h" ],
     [ "OgreInput.h", "_ogre_input_8h.html", "_ogre_input_8h" ],
     [ "OgreSGTechniqueResolverListener.h", "_ogre_s_g_technique_resolver_listener_8h.html", null ],
     [ "OgreStaticPluginLoader.h", "_ogre_static_plugin_loader_8h.html", null ],
