@@ -40,13 +40,10 @@ var group___direct3_d9 =
       [ "_setTextureCoordSet", "class_ogre_1_1_d3_d9_render_system.html#acfaf7c8ec448362a48a5ab1a026909dd", null ],
       [ "_setTextureCoordCalculation", "class_ogre_1_1_d3_d9_render_system.html#aa54b0c2ad942d41897c0b8a0a8e44166", null ],
       [ "_setTextureBlendMode", "class_ogre_1_1_d3_d9_render_system.html#ad0ce107404650d8b2ba8fcfba1448b60", null ],
-      [ "_setTextureAddressingMode", "class_ogre_1_1_d3_d9_render_system.html#a6d7e92fba6760452e19d7a414ccc8672", null ],
       [ "_setTextureMatrix", "class_ogre_1_1_d3_d9_render_system.html#aaf51e7092d88a781953f3d0d0048eb52", null ],
       [ "_setAlphaRejectSettings", "class_ogre_1_1_d3_d9_render_system.html#ab63c18908e608834b601298afd2da197", null ],
       [ "_setViewport", "class_ogre_1_1_d3_d9_render_system.html#a85ad53d4f860030b319ce0420f4ece2a", null ],
       [ "_beginFrame", "class_ogre_1_1_d3_d9_render_system.html#a3b458922197e5a3502b29e9bfe016cdf", null ],
-      [ "_pauseFrame", "class_ogre_1_1_d3_d9_render_system.html#a6eba351f3da4503d5c3b1d67789f2754", null ],
-      [ "_resumeFrame", "class_ogre_1_1_d3_d9_render_system.html#a21e6f22c4f85330f8f546f4469f23fbe", null ],
       [ "_endFrame", "class_ogre_1_1_d3_d9_render_system.html#aff3564dce1811300a2d4e7a65e4e9c66", null ],
       [ "_setCullingMode", "class_ogre_1_1_d3_d9_render_system.html#a96a7b98979ad56646ad87c4e327098cd", null ],
       [ "_setDepthBufferParams", "class_ogre_1_1_d3_d9_render_system.html#a0d4aad4a09e5ccb9edea8814b53c3142", null ],
@@ -58,11 +55,8 @@ var group___direct3_d9 =
       [ "_setFog", "class_ogre_1_1_d3_d9_render_system.html#a1702436e6653d2102443599326bca7e3", null ],
       [ "_convertProjectionMatrix", "class_ogre_1_1_d3_d9_render_system.html#acdd1a102566c67c2ce3426f06179cdae", null ],
       [ "_setPolygonMode", "class_ogre_1_1_d3_d9_render_system.html#a0d5d7d3f33d4a8a6ee1ce2e416d7320a", null ],
-      [ "_setTextureUnitFiltering", "class_ogre_1_1_d3_d9_render_system.html#a2844693c27bb55b93af8098fd658fb38", null ],
       [ "setVertexDeclaration", "class_ogre_1_1_d3_d9_render_system.html#a014e9b7fe6828806a7234f3115d029b8", null ],
-      [ "setVertexDeclaration", "class_ogre_1_1_d3_d9_render_system.html#ad11519e92283a6cb4186dc618e037eec", null ],
-      [ "setVertexBufferBinding", "class_ogre_1_1_d3_d9_render_system.html#a1819f0182b2c7ee533cf1032786d6d08", null ],
-      [ "setVertexBufferBinding", "class_ogre_1_1_d3_d9_render_system.html#a4e565e4d5edfeedc47f8cc10dbccc3df", null ],
+      [ "setVertexBufferBinding", "class_ogre_1_1_d3_d9_render_system.html#a123832bb34dcbd4c6f25244fa274c103", null ],
       [ "_render", "class_ogre_1_1_d3_d9_render_system.html#ac95209c361f6d09fb6e0af0f6d4b4107", null ],
       [ "bindGpuProgram", "class_ogre_1_1_d3_d9_render_system.html#a82c436739e35880bf9a03d3296b93e4d", null ],
       [ "unbindGpuProgram", "class_ogre_1_1_d3_d9_render_system.html#a08255da85acf7431528d739c77d37ec3", null ],
@@ -89,7 +83,6 @@ var group___direct3_d9 =
       [ "_getDepthStencilFormatFor", "class_ogre_1_1_d3_d9_render_system.html#a756e9227a2d0147e31100ce041d4f9cb", null ],
       [ "_checkTextureFilteringSupported", "class_ogre_1_1_d3_d9_render_system.html#a09b739bb7b2d3c3aff1fecece56e9baa", null ],
       [ "determineFSAASettings", "class_ogre_1_1_d3_d9_render_system.html#abeb5bc1a5691a572c5dc2f4775cf76c5", null ],
-      [ "getDisplayMonitorCount", "class_ogre_1_1_d3_d9_render_system.html#a44795018c7a6f424849c23cb3947a240", null ],
       [ "beginProfileEvent", "class_ogre_1_1_d3_d9_render_system.html#ac5910601e68f4c7c08370e2b74066d9b", null ],
       [ "endProfileEvent", "class_ogre_1_1_d3_d9_render_system.html#ae849367c0ad6d28ecc8db5d95b3e56d7", null ],
       [ "markProfileEvent", "class_ogre_1_1_d3_d9_render_system.html#a489d99fe770e4c105434ed13911ce350", null ],
@@ -100,6 +93,5 @@ var group___direct3_d9 =
       [ "_cleanupDepthBuffers", "class_ogre_1_1_d3_d9_render_system.html#a568dd8e5d75fc7eef649dda6d14d447d", null ],
       [ "D3D9Device", "class_ogre_1_1_d3_d9_render_system.html#a62a49b9f66b36b9be215f88e190366a2", null ],
       [ "D3D9DeviceManager", "class_ogre_1_1_d3_d9_render_system.html#aec82c6ec0be39f7ecb3e0d165125a540", null ]
-    ] ],
-    [ "MAX_LIGHTS", "group___direct3_d9.html#ga737b417f16ea225cf15e8d4c23df53dc", null ]
+    ] ]
 ];
\ No newline at end of file
