@@ -310,6 +310,7 @@ var group___effects =
         [ "refTexName", "class_ogre_1_1_composition_technique_1_1_texture_definition.html#a438d2780a5dfe0ac83309b0b9e7dde96", null ],
         [ "width", "class_ogre_1_1_composition_technique_1_1_texture_definition.html#a46b4ede7400302f6d58e03d1eb4489ae", null ],
         [ "height", "class_ogre_1_1_composition_technique_1_1_texture_definition.html#abbbb4c6b2ea75b413ff5534be536ad73", null ],
+        [ "depth", "class_ogre_1_1_composition_technique_1_1_texture_definition.html#a961b6a77bc1f93094da60c68ce7124f6", null ],
         [ "type", "class_ogre_1_1_composition_technique_1_1_texture_definition.html#a2b3a7551a57b77fde8c23de7267b2056", null ],
         [ "widthFactor", "class_ogre_1_1_composition_technique_1_1_texture_definition.html#a5c71286e9daa688d6028deb524c15ddc", null ],
         [ "heightFactor", "class_ogre_1_1_composition_technique_1_1_texture_definition.html#a99163323a7ab7d6b661f538b17c8f97b", null ],
@@ -485,6 +486,7 @@ var group___effects =
       [ "_getTexturedRectangle2D", "class_ogre_1_1_compositor_manager.html#abc22280b859b4f57bb71a63374c36032", null ],
       [ "removeAll", "class_ogre_1_1_compositor_manager.html#a40feb1956c7edd68fd65835a44db84b0", null ],
       [ "_reconstructAllCompositorResources", "class_ogre_1_1_compositor_manager.html#a5cc7bae199f7984d34f725c7d0d255fb", null ],
+      [ "getPooledTexture", "class_ogre_1_1_compositor_manager.html#a13a596ef6964a68dc25e9858b2201d26", null ],
       [ "getPooledTexture", "class_ogre_1_1_compositor_manager.html#ac6daf1c536921b05c05a172a6a2b466f", null ],
       [ "freePooledTextures", "class_ogre_1_1_compositor_manager.html#a1ac07452c980fbcb7445346b4ff329bf", null ],
       [ "registerCompositorLogic", "class_ogre_1_1_compositor_manager.html#a9c7d4168d56868599badb2789d54157c", null ],
