@@ -66,10 +66,11 @@ var group___general =
       [ "decode", "class_ogre_1_1_codec.html#aa09f02c08e53d8e58835a7a342e8be64", null ],
       [ "getType", "class_ogre_1_1_codec.html#ada1a5477ab6a563565f1b3599d7b806a", null ],
       [ "magicNumberMatch", "class_ogre_1_1_codec.html#a2e3a2fbc93450efac141578d33c4bbc0", null ],
-      [ "magicNumberToFileExt", "class_ogre_1_1_codec.html#af90756f690827353e18347d328bc5180", null ]
+      [ "magicNumberToFileExt", "class_ogre_1_1_codec.html#af90756f690827353e18347d328bc5180", null ],
+      [ "setParameter", "class_ogre_1_1_codec.html#a464e7b1ef3fae566425b2d7f4ed982db", null ]
     ] ],
     [ "Ogre::ColourValue", "class_ogre_1_1_colour_value.html", [
-      [ "ColourValue", "class_ogre_1_1_colour_value.html#acc033c4828ad9f7469269933d24850f5", null ],
+      [ "ColourValue", "class_ogre_1_1_colour_value.html#a783132a039d3d5bbccedbcea77ff3c79", null ],
       [ "ColourValue", "class_ogre_1_1_colour_value.html#aa807f795d563dbf32601b20925cd46d4", null ],
       [ "operator==", "class_ogre_1_1_colour_value.html#a7c80a19ac61f97f217d5b39d8f1dd39b", null ],
       [ "operator!=", "class_ogre_1_1_colour_value.html#a4825d1fb89ea5aae7f2e18e108aa7f23", null ],
@@ -103,12 +104,12 @@ var group___general =
       [ "getHSB", "class_ogre_1_1_colour_value.html#af9df6a8c10f290187bc051c6ee61863f", null ],
       [ "operator*", "class_ogre_1_1_colour_value.html#a5b0ed5d4289ec1f56295380a0a334e4f", null ],
       [ "operator<<", "class_ogre_1_1_colour_value.html#a6141ef6c5e433c9e59807222f7fa79fe", null ],
-      [ "ZERO", "class_ogre_1_1_colour_value.html#abc5d5f80d4d99438863cc808169283b5", null ],
-      [ "Black", "class_ogre_1_1_colour_value.html#a7f8a06f2a9dd645417c36b560f496c1a", null ],
-      [ "White", "class_ogre_1_1_colour_value.html#a8eba66b2908f44f00f8d9c9ec25877de", null ],
-      [ "Red", "class_ogre_1_1_colour_value.html#ab9c2a36f53ac599850f1cf8b822f750d", null ],
-      [ "Green", "class_ogre_1_1_colour_value.html#a00384a789ac354ea8dd252c62cb17aa4", null ],
-      [ "Blue", "class_ogre_1_1_colour_value.html#a67ef25ecd0fa97e7e51e5bd87b29ae65", null ],
+      [ "ZERO", "class_ogre_1_1_colour_value.html#a0b3c6d7aba3e2879c5bff3d864241584", null ],
+      [ "Black", "class_ogre_1_1_colour_value.html#a0f66d1fae35f9f2a13ce26349fb71a79", null ],
+      [ "White", "class_ogre_1_1_colour_value.html#ab67f75eb63c2ee10cb6e874219b01b67", null ],
+      [ "Red", "class_ogre_1_1_colour_value.html#a1bcb3611eec7ec5ce68967e6023acb6d", null ],
+      [ "Green", "class_ogre_1_1_colour_value.html#a4b5005bc7a691be69292a06fdab037fd", null ],
+      [ "Blue", "class_ogre_1_1_colour_value.html#aabc748c7dbf62da85d6016c073314e7b", null ],
       [ "r", "class_ogre_1_1_colour_value.html#a6e086633637e335238d517e0ec9f2cd2", null ],
       [ "g", "class_ogre_1_1_colour_value.html#a13fbd050af26b8bd549ccb46aa699e07", null ],
       [ "b", "class_ogre_1_1_colour_value.html#aae078d77b654f76e3b760174f93474ec", null ],
@@ -444,7 +445,7 @@ var group___general =
       [ "getRenderSystemByName", "class_ogre_1_1_root.html#a20b606897509da75ad2795a8c894f2c0", null ],
       [ "setRenderSystem", "class_ogre_1_1_root.html#af768914a0dd431ee442bf83157daf570", null ],
       [ "getRenderSystem", "class_ogre_1_1_root.html#a8ddde4d4b5c30072619f5afd91222492", null ],
-      [ "initialise", "class_ogre_1_1_root.html#ac62dc40092cfe152bb85fa1245222d82", null ],
+      [ "initialise", "class_ogre_1_1_root.html#a3df84a70d266bd6a7be33f54c5c6f2c8", null ],
       [ "isInitialised", "class_ogre_1_1_root.html#a12dc2722de43cb2aa8e93845ea641358", null ],
       [ "useCustomRenderSystemCapabilities", "class_ogre_1_1_root.html#a0c36540d9764ec4e41940423dd0ae88b", null ],
       [ "getRemoveRenderQueueStructuresOnClear", "class_ogre_1_1_root.html#a734be2fb6e01355f328fa5ccd2e737f6", null ],
@@ -556,9 +557,7 @@ var group___general =
     ] ],
     [ "Ogre::SimpleParamCommand< _Class, const String &, getter, setter >", "class_ogre_1_1_simple_param_command_3_01___class_00_01const_01_string_01_6_00_01getter_00_01setter_01_4.html", [
       [ "doGet", "class_ogre_1_1_simple_param_command_3_01___class_00_01const_01_string_01_6_00_01getter_00_01setter_01_4.html#aad3aa9c19d5ee9d99cc680ba84162082", null ],
-      [ "doSet", "class_ogre_1_1_simple_param_command_3_01___class_00_01const_01_string_01_6_00_01getter_00_01setter_01_4.html#a5f19051871ee808c8efad85a47e80521", null ],
-      [ "doGet", "class_ogre_1_1_simple_param_command.html#a29ff02942b19b51153abd53a878e244a", null ],
-      [ "doSet", "class_ogre_1_1_simple_param_command.html#a9727fda386f95b2bb29bf41c553bd944", null ]
+      [ "doSet", "class_ogre_1_1_simple_param_command_3_01___class_00_01const_01_string_01_6_00_01getter_00_01setter_01_4.html#a5f19051871ee808c8efad85a47e80521", null ]
     ] ],
     [ "Ogre::Singleton< T >", "class_ogre_1_1_singleton.html", [
       [ "Singleton", "class_ogre_1_1_singleton.html#a2b0622a1223ac3a0c6b9c53e787b8d93", null ],
