@@ -72,12 +72,15 @@ var group___overlays =
       [ "addCodePointRange", "class_ogre_1_1_font.html#ac2c1fba5ad2d610ecc78b1e1a6a1b8dc", null ],
       [ "clearCodePointRanges", "class_ogre_1_1_font.html#aff75a40e8ca00a64f19c265e90c61733", null ],
       [ "getCodePointRangeList", "class_ogre_1_1_font.html#a847b5fa1668cee1943651d3bb496f243", null ],
+      [ "addMergeFont", "class_ogre_1_1_font.html#a87ce3d81e9b9b53479faa83c1d29c1bb", null ],
+      [ "getMergeFontList", "class_ogre_1_1_font.html#ac89f41cb59be64a896776e1b2cd307f4", null ],
       [ "getMaterial", "class_ogre_1_1_font.html#a7b1206935984cda27994ec766dae3f22", null ],
       [ "putText", "class_ogre_1_1_font.html#ac78d744eddeeaef4c01a078f9c3c9119", null ],
       [ "setAntialiasColour", "class_ogre_1_1_font.html#a6ca4172a3f554f07752997b1a25278c0", null ],
       [ "getAntialiasColour", "class_ogre_1_1_font.html#a278117d7414d69dbaed6e7290e842991", null ],
       [ "loadResource", "class_ogre_1_1_font.html#a7d54a57f586af8b040b4e2d3481aaa35", null ],
-      [ "_setMaterial", "class_ogre_1_1_font.html#a44e60ba33fb4a583d0239cc5cc9c849f", null ]
+      [ "_setMaterial", "class_ogre_1_1_font.html#a44e60ba33fb4a583d0239cc5cc9c849f", null ],
+      [ "ImGuiOverlay", "class_ogre_1_1_font.html#a837ff11c4d56b5bfd81ffe17c73d92c0", null ]
     ] ],
     [ "Ogre::FontManager", "class_ogre_1_1_font_manager.html", [
       [ "FontManager", "class_ogre_1_1_font_manager.html#a159ba6550b0c2731768db9df66472d19", null ],
@@ -310,7 +313,7 @@ var group___overlays =
     [ "Ogre::OverlaySystem", "class_ogre_1_1_overlay_system.html", [
       [ "OverlaySystem", "group___overlays.html#gacd5c773075a7591f717fb2382df9a829", null ],
       [ "~OverlaySystem", "group___overlays.html#gad399638657ead9815683c02bc7fdf149", null ],
-      [ "renderQueueStarted", "group___overlays.html#ga60d6f81cb051bf6369a06c74b913c317", null ],
+      [ "preRenderQueues", "group___overlays.html#gaf6fb54d4dea385f958844f3ab8947bd0", null ],
       [ "eventOccurred", "group___overlays.html#ga449a8ac2b301e045c0ceec32a2289f8b", null ],
       [ "getSingleton", "group___overlays.html#gaffcea382193d1edf6b21703f298d35ce", null ],
       [ "getSingletonPtr", "group___overlays.html#ga7945d431719c60ccb40d356e268f5558", null ]
@@ -409,7 +412,7 @@ var group___overlays =
     [ "Ogre::OverlayProfileSessionListener::getDisplayMode", "group___overlays.html#ga945723ccd02d3d9592903813e27d5e94", null ],
     [ "Ogre::OverlaySystem::OverlaySystem", "group___overlays.html#gacd5c773075a7591f717fb2382df9a829", null ],
     [ "Ogre::OverlaySystem::~OverlaySystem", "group___overlays.html#gad399638657ead9815683c02bc7fdf149", null ],
-    [ "Ogre::OverlaySystem::renderQueueStarted", "group___overlays.html#ga60d6f81cb051bf6369a06c74b913c317", null ],
+    [ "Ogre::OverlaySystem::preRenderQueues", "group___overlays.html#gaf6fb54d4dea385f958844f3ab8947bd0", null ],
     [ "Ogre::OverlaySystem::eventOccurred", "group___overlays.html#ga449a8ac2b301e045c0ceec32a2289f8b", null ],
     [ "Ogre::OverlaySystem::getSingleton", "group___overlays.html#gaffcea382193d1edf6b21703f298d35ce", null ],
     [ "Ogre::OverlaySystem::getSingletonPtr", "group___overlays.html#ga7945d431719c60ccb40d356e268f5558", null ]
