@@ -36,17 +36,17 @@ var group___r_t_shader =
     ] ],
     [ "Ogre::RTShader::Function", "class_ogre_1_1_r_t_shader_1_1_function.html", [
       [ "Function", "class_ogre_1_1_r_t_shader_1_1_function.html#a12894b02670ae32e4c54ab709ab08182", null ],
-      [ "resolveInputParameter", "class_ogre_1_1_r_t_shader_1_1_function.html#ad7edaafbe5157420d481902c54292cf2", null ],
-      [ "resolveInputParameter", "class_ogre_1_1_r_t_shader_1_1_function.html#a9452b0bbda2a8c1236f4eaafa061d4dc", null ],
+      [ "resolveInputParameter", "class_ogre_1_1_r_t_shader_1_1_function.html#a2d69afef17244d8b8f4f2b41b5c0d0a5", null ],
+      [ "resolveInputParameter", "class_ogre_1_1_r_t_shader_1_1_function.html#a41709ca7448d7c3cc25efa474535c752", null ],
       [ "resolveInputParameter", "class_ogre_1_1_r_t_shader_1_1_function.html#a6c3bc19e310e10fb2ca1fa21320575d7", null ],
-      [ "getInputParameter", "class_ogre_1_1_r_t_shader_1_1_function.html#a15c301954bb05ae0884608a0d22902bb", null ],
-      [ "resolveOutputParameter", "class_ogre_1_1_r_t_shader_1_1_function.html#ad112e1d948a65c3104b9cfde9eb0b939", null ],
-      [ "resolveOutputParameter", "class_ogre_1_1_r_t_shader_1_1_function.html#a7137a85782731f56c8d1de98d2d6e6b9", null ],
-      [ "getOutputParameter", "class_ogre_1_1_r_t_shader_1_1_function.html#aa7167d7341037ac16ce0555e08a80cef", null ],
+      [ "getInputParameter", "class_ogre_1_1_r_t_shader_1_1_function.html#a6f8e85c4f711f6739c00d723d0d8fbf9", null ],
+      [ "resolveOutputParameter", "class_ogre_1_1_r_t_shader_1_1_function.html#a0f98fa3f8efb5c913362bdbc76fe97ee", null ],
+      [ "resolveOutputParameter", "class_ogre_1_1_r_t_shader_1_1_function.html#ae63fa9eb90cf351eaac310d83303c7d3", null ],
+      [ "getOutputParameter", "class_ogre_1_1_r_t_shader_1_1_function.html#a04bbd46ad555743385156be23b2bc495", null ],
       [ "resolveLocalParameter", "class_ogre_1_1_r_t_shader_1_1_function.html#a67016b960f622a4292e37e7fa28c43b9", null ],
-      [ "resolveLocalParameter", "class_ogre_1_1_r_t_shader_1_1_function.html#a4bad4a422742f2d73126303a6af9d229", null ],
+      [ "resolveLocalParameter", "class_ogre_1_1_r_t_shader_1_1_function.html#ab29de02c856376cc68e0c2f0a4316a27", null ],
       [ "resolveLocalStructParameter", "class_ogre_1_1_r_t_shader_1_1_function.html#af4c761e04ba4f6fa32bfe4589713b49e", null ],
-      [ "getLocalParameter", "class_ogre_1_1_r_t_shader_1_1_function.html#a86212e62d4b7bfd8c6dc084dcd1f607f", null ],
+      [ "getLocalParameter", "class_ogre_1_1_r_t_shader_1_1_function.html#aed18dcfe406442fea14c0ce18030901b", null ],
       [ "getLocalParameter", "class_ogre_1_1_r_t_shader_1_1_function.html#ae4a22b20ed6ef533b5b887f1b11bf5f5", null ],
       [ "getInputParameters", "class_ogre_1_1_r_t_shader_1_1_function.html#ab218b89ece9bab69a757c89f512d473c", null ],
       [ "getOutputParameters", "class_ogre_1_1_r_t_shader_1_1_function.html#a011c1140d868a15fc0bb3d37b31d8ced", null ],
@@ -113,7 +113,7 @@ var group___r_t_shader =
       [ "HardwareSkinningFactory", "class_ogre_1_1_r_t_shader_1_1_hardware_skinning_factory.html#a3475a3c6970fa475a23df8fbeec8a295", null ],
       [ "~HardwareSkinningFactory", "class_ogre_1_1_r_t_shader_1_1_hardware_skinning_factory.html#af4cd5b084e60358a05eefa1f97bf30ee", null ],
       [ "getType", "class_ogre_1_1_r_t_shader_1_1_hardware_skinning_factory.html#ac8f82af0f4fc7100bf5e17553387c2fd", null ],
-      [ "createInstance", "class_ogre_1_1_r_t_shader_1_1_hardware_skinning_factory.html#a8e62c06065b1bab85530147845cdc988", null ],
+      [ "createInstance", "class_ogre_1_1_r_t_shader_1_1_hardware_skinning_factory.html#a0bd9f1363ffef103ea9364f425f91934", null ],
       [ "writeInstance", "class_ogre_1_1_r_t_shader_1_1_hardware_skinning_factory.html#ab7db0312e767acbd8954146133555eff", null ],
       [ "setCustomShadowCasterMaterials", "class_ogre_1_1_r_t_shader_1_1_hardware_skinning_factory.html#a706dfbec2705d025b118a07edc996f66", null ],
       [ "setCustomShadowReceiverMaterials", "class_ogre_1_1_r_t_shader_1_1_hardware_skinning_factory.html#ae64c12272755d7e8a4bce22e1b1476c6", null ],
@@ -200,7 +200,8 @@ var group___r_t_shader =
         [ "SPS_TEXTURE_COORDINATES", "class_ogre_1_1_r_t_shader_1_1_parameter.html#a91fc3614f191bebf0461676a03750312aacb3f8c7623415a9398f1d0aeb0849d9", null ],
         [ "SPS_BINORMAL", "class_ogre_1_1_r_t_shader_1_1_parameter.html#a91fc3614f191bebf0461676a03750312af67c3c93adcb32edbb0b93fa6ac21ac0", null ],
         [ "SPS_TANGENT", "class_ogre_1_1_r_t_shader_1_1_parameter.html#a91fc3614f191bebf0461676a03750312aa27b75d58d2ae680d71d5eda917c5783", null ],
-        [ "SPS_FRONT_FACING", "class_ogre_1_1_r_t_shader_1_1_parameter.html#a91fc3614f191bebf0461676a03750312adea400d134099c950fbbed0a21dc3170", null ]
+        [ "SPS_FRONT_FACING", "class_ogre_1_1_r_t_shader_1_1_parameter.html#a91fc3614f191bebf0461676a03750312adea400d134099c950fbbed0a21dc3170", null ],
+        [ "SPS_LAYER", "class_ogre_1_1_r_t_shader_1_1_parameter.html#a91fc3614f191bebf0461676a03750312ac4c0468d5523a097db78aa5854aadc51", null ]
       ] ],
       [ "Content", "class_ogre_1_1_r_t_shader_1_1_parameter.html#a4fa6286f097d19e92a8ed91645fbfbe7", [
         [ "SPC_UNKNOWN", "class_ogre_1_1_r_t_shader_1_1_parameter.html#a4fa6286f097d19e92a8ed91645fbfbe7a8c55ed23aa8cdca9f420634d00c0104b", null ],
@@ -246,18 +247,19 @@ var group___r_t_shader =
         [ "SPC_POINTSPRITE_COORDINATE", "class_ogre_1_1_r_t_shader_1_1_parameter.html#a4fa6286f097d19e92a8ed91645fbfbe7a6bcc8a3bfd23f3cdaa0930d020b5bf0b", null ],
         [ "SPC_POINTSPRITE_SIZE", "class_ogre_1_1_r_t_shader_1_1_parameter.html#a4fa6286f097d19e92a8ed91645fbfbe7a5fc3476511cdfaf5c5a6bde5fa3f6eef", null ],
         [ "SPC_FRONT_FACING", "class_ogre_1_1_r_t_shader_1_1_parameter.html#a4fa6286f097d19e92a8ed91645fbfbe7a7ac1b257d627f71ebd88417f70819a94", null ],
+        [ "SPC_LAYER", "class_ogre_1_1_r_t_shader_1_1_parameter.html#a4fa6286f097d19e92a8ed91645fbfbe7a5b8ae9b3c541bf88272efcdca0f92d42", null ],
         [ "SPC_CUSTOM_CONTENT_BEGIN", "class_ogre_1_1_r_t_shader_1_1_parameter.html#a4fa6286f097d19e92a8ed91645fbfbe7a1a85a6dd6da63324f7028b042313145b", null ],
         [ "SPC_CUSTOM_CONTENT_END", "class_ogre_1_1_r_t_shader_1_1_parameter.html#a4fa6286f097d19e92a8ed91645fbfbe7ad2f7a789b2cf0c838b37d54bdb469467", null ]
       ] ],
       [ "Parameter", "class_ogre_1_1_r_t_shader_1_1_parameter.html#a9f241674489c5321d2741df6d928fc3d", null ],
-      [ "Parameter", "class_ogre_1_1_r_t_shader_1_1_parameter.html#a9e0f11ec8780314d7dd0eb32e93798c9", null ],
+      [ "Parameter", "class_ogre_1_1_r_t_shader_1_1_parameter.html#a1f70b4242ca1d97ca56649c09ae89e98", null ],
       [ "~Parameter", "class_ogre_1_1_r_t_shader_1_1_parameter.html#a05435ba326deda0d3a0254b24870ccff", null ],
       [ "getName", "class_ogre_1_1_r_t_shader_1_1_parameter.html#a5619ee392f00630f3391f7dff49a43b6", null ],
       [ "_rename", "class_ogre_1_1_r_t_shader_1_1_parameter.html#a731d5bfce5b8813f0588775ecae64259", null ],
       [ "getType", "class_ogre_1_1_r_t_shader_1_1_parameter.html#a83a641fd3be8b42222c1a5988c5c74fd", null ],
       [ "getSemantic", "class_ogre_1_1_r_t_shader_1_1_parameter.html#a38b0c608a4d6542d4b277ef7a647d4b3", null ],
       [ "getIndex", "class_ogre_1_1_r_t_shader_1_1_parameter.html#a66737b9982cbf8778c4114082d8ab496", null ],
-      [ "getContent", "class_ogre_1_1_r_t_shader_1_1_parameter.html#ab8ed4fa20a94d4dc3b964ee20d56769f", null ],
+      [ "getContent", "class_ogre_1_1_r_t_shader_1_1_parameter.html#a8feab0b136029256f616e2f38807bb76", null ],
       [ "isConstParameter", "class_ogre_1_1_r_t_shader_1_1_parameter.html#a6c48a5ac72a1af0f25168c3d4a06b71b", null ],
       [ "toString", "class_ogre_1_1_r_t_shader_1_1_parameter.html#a3210eee0554afecb57185a0ae938e2ee", null ],
       [ "isArray", "class_ogre_1_1_r_t_shader_1_1_parameter.html#a35b50410cc2fef7dbf39066b1b44e4ae", null ],
@@ -271,7 +273,7 @@ var group___r_t_shader =
       [ "setStructType", "class_ogre_1_1_r_t_shader_1_1_parameter.html#ab91af159d722cbd7577208f7360af72a", null ]
     ] ],
     [ "Ogre::RTShader::ParameterFactory", "class_ogre_1_1_r_t_shader_1_1_parameter_factory.html", [
-      [ "createInPosition", "class_ogre_1_1_r_t_shader_1_1_parameter_factory.html#ac0a02aa9babb2203fbf0945888c1f906", null ],
+      [ "createInPosition", "class_ogre_1_1_r_t_shader_1_1_parameter_factory.html#abd7c7b70f307f5d47287b3f51b0c81ad", null ],
       [ "createOutPosition", "class_ogre_1_1_r_t_shader_1_1_parameter_factory.html#aac159df02f9d38f97074da632e33e5c7", null ],
       [ "createInNormal", "class_ogre_1_1_r_t_shader_1_1_parameter_factory.html#a4e641bf17c16a7cc65bea17b849cfa37", null ],
       [ "createInWeights", "class_ogre_1_1_r_t_shader_1_1_parameter_factory.html#a2b3190c854a26190034080a2734645af", null ],
@@ -283,8 +285,8 @@ var group___r_t_shader =
       [ "createOutTangent", "class_ogre_1_1_r_t_shader_1_1_parameter_factory.html#ad0461fc33fb6bbb8ebb1d732f2ccb17a", null ],
       [ "createInColor", "class_ogre_1_1_r_t_shader_1_1_parameter_factory.html#a03888f5210bf17cc1350793c72e2a4ce", null ],
       [ "createOutColor", "class_ogre_1_1_r_t_shader_1_1_parameter_factory.html#adc993ce92bf6f96b4010ce4ae3e4d7a0", null ],
-      [ "createInTexcoord", "class_ogre_1_1_r_t_shader_1_1_parameter_factory.html#ae1e6ad891b88b61a9f16c9f7fd15d993", null ],
-      [ "createOutTexcoord", "class_ogre_1_1_r_t_shader_1_1_parameter_factory.html#ad1bf68269aadb9f521d3168090e7bd11", null ],
+      [ "createInTexcoord", "class_ogre_1_1_r_t_shader_1_1_parameter_factory.html#a840d1f360b06954d3f134b0e83c37b01", null ],
+      [ "createOutTexcoord", "class_ogre_1_1_r_t_shader_1_1_parameter_factory.html#a011a272527b0dfec88b44aa130026449", null ],
       [ "createConstParam", "class_ogre_1_1_r_t_shader_1_1_parameter_factory.html#ab92a78b6e66962547a12c0f9845ce4e3", null ],
       [ "createConstParam", "class_ogre_1_1_r_t_shader_1_1_parameter_factory.html#a99b245c958ecaa99551d8ba2325e7aca", null ],
       [ "createConstParam", "class_ogre_1_1_r_t_shader_1_1_parameter_factory.html#a57244950f3a5267399c3fb82db6ec836", null ],
@@ -384,7 +386,8 @@ var group___r_t_shader =
     [ "Ogre::RTShader::SGScriptTranslator", "class_ogre_1_1_r_t_shader_1_1_s_g_script_translator.html", [
       [ "SGScriptTranslator", "group___r_t_shader.html#ga86e3c331a22325d04420a5a84b905595", null ],
       [ "translate", "group___r_t_shader.html#ga8b29c5c9e53e5a39b8108975fd1d7157", null ],
-      [ "getGeneratedSubRenderState", "group___r_t_shader.html#gaa051b58444aedec84801aa00b8ef3852", null ]
+      [ "getGeneratedSubRenderState", "group___r_t_shader.html#gaa051b58444aedec84801aa00b8ef3852", null ],
+      [ "emitError", "group___r_t_shader.html#ga1702d763dad86032fab754d20e574063", null ]
     ] ],
     [ "Ogre::RTShader::ShaderGenerator", "class_ogre_1_1_r_t_shader_1_1_shader_generator.html", [
       [ "RenderStateCreateOrRetrieveResult", "class_ogre_1_1_r_t_shader_1_1_shader_generator.html#ac7eb87c69e1a22e1ad0c0c4a3a9dded1", null ],
@@ -426,14 +429,14 @@ var group___r_t_shader =
       [ "cloneShaderBasedTechniques", "class_ogre_1_1_r_t_shader_1_1_shader_generator.html#aff6355a837f7625ef6e734dabf2f9a90", null ],
       [ "removeAllShaderBasedTechniques", "class_ogre_1_1_r_t_shader_1_1_shader_generator.html#ae8f84b4afc636a6fbe754495b916e5e3", null ],
       [ "createScheme", "class_ogre_1_1_r_t_shader_1_1_shader_generator.html#a4d27197d6de2e7b02bf0127cc9619081", null ],
-      [ "invalidateScheme", "class_ogre_1_1_r_t_shader_1_1_shader_generator.html#a4853e5eea4d5e3c1d0e09e40d9424da1", null ],
-      [ "validateScheme", "class_ogre_1_1_r_t_shader_1_1_shader_generator.html#a651a5f61020937cc40f4090f1f18e458", null ],
-      [ "invalidateMaterial", "class_ogre_1_1_r_t_shader_1_1_shader_generator.html#a62782289b008fd98693ac49a14fef58a", null ],
+      [ "invalidateScheme", "class_ogre_1_1_r_t_shader_1_1_shader_generator.html#af0d1caf0430962d6826bbc3b0393edab", null ],
+      [ "validateScheme", "class_ogre_1_1_r_t_shader_1_1_shader_generator.html#a27a3f2f3512021f460ec23425971d689", null ],
+      [ "invalidateMaterial", "class_ogre_1_1_r_t_shader_1_1_shader_generator.html#a93b8687cb9654f03c7480b587723b39a", null ],
       [ "invalidateMaterial", "class_ogre_1_1_r_t_shader_1_1_shader_generator.html#a6378d5b1199e5be790469eae6e535de7", null ],
-      [ "validateMaterial", "class_ogre_1_1_r_t_shader_1_1_shader_generator.html#a5c707c5cbc981badceb9946728c708e6", null ],
-      [ "validateMaterial", "class_ogre_1_1_r_t_shader_1_1_shader_generator.html#aab3ded51ae63c0120b321d340d667703", null ],
-      [ "invalidateMaterialIlluminationPasses", "class_ogre_1_1_r_t_shader_1_1_shader_generator.html#af452809bad58cd56ea0f3121f216f86c", null ],
-      [ "validateMaterialIlluminationPasses", "class_ogre_1_1_r_t_shader_1_1_shader_generator.html#aba60c37a422d8834a02108cb98c9890e", null ],
+      [ "validateMaterial", "class_ogre_1_1_r_t_shader_1_1_shader_generator.html#a266d1cbee31dcd63963b7a9392a5c53f", null ],
+      [ "validateMaterial", "class_ogre_1_1_r_t_shader_1_1_shader_generator.html#aca5db9df0c2f03ba48590f7bfa39f804", null ],
+      [ "invalidateMaterialIlluminationPasses", "class_ogre_1_1_r_t_shader_1_1_shader_generator.html#a72bda9281e16af2127a1b6f2d50d38b5", null ],
+      [ "validateMaterialIlluminationPasses", "class_ogre_1_1_r_t_shader_1_1_shader_generator.html#ae31497e08ba880771e60c155b92d4fe1", null ],
       [ "getMaterialSerializerListener", "class_ogre_1_1_r_t_shader_1_1_shader_generator.html#a9aa570e30b737d5475bfb11eb016f2c6", null ],
       [ "getShaderCount", "class_ogre_1_1_r_t_shader_1_1_shader_generator.html#af5c45f520b80e490a398b5d3c625463a", null ],
       [ "setVertexShaderOutputsCompactPolicy", "class_ogre_1_1_r_t_shader_1_1_shader_generator.html#ac784b3f7ac300e33ade90143314effaa", null ],
@@ -479,7 +482,9 @@ var group___r_t_shader =
       [ "~SubRenderStateFactory", "class_ogre_1_1_r_t_shader_1_1_sub_render_state_factory.html#a9b3e25bb3aa398c8068cd5790002899d", null ],
       [ "getType", "class_ogre_1_1_r_t_shader_1_1_sub_render_state_factory.html#ac9ab0dc7c43018657518c15484a5bc74", null ],
       [ "createInstance", "class_ogre_1_1_r_t_shader_1_1_sub_render_state_factory.html#adbc886fee2e4369520aaed1ce7592e62", null ],
+      [ "createInstance", "class_ogre_1_1_r_t_shader_1_1_sub_render_state_factory.html#a19ac15b36396eb63e6e88c87e5bec47f", null ],
       [ "createInstance", "class_ogre_1_1_r_t_shader_1_1_sub_render_state_factory.html#ad449bb3ec441e90c5b76b8ea0f2a0f86", null ],
+      [ "createInstance", "class_ogre_1_1_r_t_shader_1_1_sub_render_state_factory.html#a49db795c9a9223f0fc68b8de768ba8ec", null ],
       [ "createInstance", "class_ogre_1_1_r_t_shader_1_1_sub_render_state_factory.html#a4d3207a77a6c8c295f20b0e348b2e10c", null ],
       [ "createOrRetrieveInstance", "class_ogre_1_1_r_t_shader_1_1_sub_render_state_factory.html#a25e2d4314ce2e1c2dc95a39f3daf8f18", null ],
       [ "destroyInstance", "class_ogre_1_1_r_t_shader_1_1_sub_render_state_factory.html#a23839e5fc35257e4ffb9076e2aaf9409", null ],
@@ -500,7 +505,7 @@ var group___r_t_shader =
       [ "UserKey", "class_ogre_1_1_r_t_shader_1_1_target_render_state.html#ad89fc9a3c7ec0c73a5d7805013547c24", null ]
     ] ],
     [ "Ogre::RTShader::UniformParameter", "class_ogre_1_1_r_t_shader_1_1_uniform_parameter.html", [
-      [ "UniformParameter", "class_ogre_1_1_r_t_shader_1_1_uniform_parameter.html#a4f69ada139bae0a8ffb68492e709d8ee", null ],
+      [ "UniformParameter", "class_ogre_1_1_r_t_shader_1_1_uniform_parameter.html#a19c3e44e39d852dd494523bba52d0917", null ],
       [ "UniformParameter", "class_ogre_1_1_r_t_shader_1_1_uniform_parameter.html#aee8254cb049370aacb188f1ed16bd87e", null ],
       [ "UniformParameter", "class_ogre_1_1_r_t_shader_1_1_uniform_parameter.html#aaa04793a3e2f44644a59777c382f2d63", null ],
       [ "UniformParameter", "class_ogre_1_1_r_t_shader_1_1_uniform_parameter.html#a95051a3abbaea567019fbf29a9ca7950", null ],
@@ -585,6 +590,7 @@ var group___r_t_shader =
     [ "Ogre::RTShader::SGScriptTranslator::SGScriptTranslator", "group___r_t_shader.html#ga86e3c331a22325d04420a5a84b905595", null ],
     [ "Ogre::RTShader::SGScriptTranslator::translate", "group___r_t_shader.html#ga8b29c5c9e53e5a39b8108975fd1d7157", null ],
     [ "Ogre::RTShader::SGScriptTranslator::getGeneratedSubRenderState", "group___r_t_shader.html#gaa051b58444aedec84801aa00b8ef3852", null ],
+    [ "Ogre::RTShader::SGScriptTranslator::emitError", "group___r_t_shader.html#ga1702d763dad86032fab754d20e574063", null ],
     [ "Ogre::RTShader::SRS_TRANSFORM", "group___r_t_shader.html#ga8cb98be9db81aa08483836d3cda49c31", null ],
     [ "Ogre::RTShader::SRS_VERTEX_COLOUR", "group___r_t_shader.html#gaaedbac186ba67be460c9ff2609104d89", null ],
     [ "Ogre::RTShader::SRS_TEXTURING", "group___r_t_shader.html#gaf78d62646d139c60af9f8cd7daa8136c", null ],
