@@ -5,6 +5,7 @@ var group___render_systems =
     [ "GL", "group___g_l.html", "group___g_l" ],
     [ "GL3Plus", "group___g_l3_plus.html", "group___g_l3_plus" ],
     [ "GLES2", "group___g_l_e_s2.html", "group___g_l_e_s2" ],
-    [ "GLSupport", "group___g_l_support.html", "group___g_l_support" ],
-    [ "Tiny", "group___tiny.html", "group___tiny" ]
+    [ "Metal", "group___metal.html", "group___metal" ],
+    [ "Tiny", "group___tiny.html", "group___tiny" ],
+    [ "Vulkan", "group___vulkan.html", "group___vulkan" ]
 ];
\ No newline at end of file
