@@ -62,6 +62,9 @@ var hierarchy =
     [ "bsp_shader_t", "structbsp__shader__t.html", null ],
     [ "bsp_vertex_t", "structbsp__vertex__t.html", null ],
     [ "bsp_vis_t", "structbsp__vis__t.html", null ],
+    [ "btActionInterface", null, [
+      [ "Ogre::Bullet::KinematicMotionSimple", "class_ogre_1_1_bullet_1_1_kinematic_motion_simple.html", null ]
+    ] ],
     [ "btIDebugDraw", null, [
       [ "Ogre::Bullet::DebugDrawer", "class_ogre_1_1_bullet_1_1_debug_drawer.html", null ]
     ] ],
@@ -317,6 +320,7 @@ var hierarchy =
     [ "Ogre::Bullet::CollisionWorld", "class_ogre_1_1_bullet_1_1_collision_world.html", [
       [ "Ogre::Bullet::DynamicsWorld", "class_ogre_1_1_bullet_1_1_dynamics_world.html", null ]
     ] ],
+    [ "Ogre::Bullet::HeightFieldData", "struct_ogre_1_1_bullet_1_1_height_field_data.html", null ],
     [ "Ogre::Bullet::RayResultCallback", "struct_ogre_1_1_bullet_1_1_ray_result_callback.html", null ],
     [ "Ogre::Camera::Listener", "class_ogre_1_1_camera_1_1_listener.html", null ],
     [ "Ogre::Capsule", "class_ogre_1_1_capsule.html", null ],
@@ -357,6 +361,7 @@ var hierarchy =
         [ "OgreBites::ApplicationContextQt", "class_ogre_bites_1_1_application_context_qt.html", null ]
       ] ]
     ] ],
+    [ "Ogre::GlobalInstancingData", "struct_ogre_1_1_global_instancing_data.html", null ],
     [ "Ogre::GlyphInfo", "struct_ogre_1_1_glyph_info.html", null ],
     [ "Ogre::GpuConstantDefinition", "struct_ogre_1_1_gpu_constant_definition.html", null ],
     [ "Ogre::GpuLogicalIndexUse", "struct_ogre_1_1_gpu_logical_index_use.html", null ],
@@ -746,6 +751,7 @@ var hierarchy =
       ] ],
       [ "Ogre::ScriptCompilerManager", "class_ogre_1_1_script_compiler_manager.html", null ]
     ] ],
+    [ "Ogre::ScriptProperty", "struct_ogre_1_1_script_property.html", null ],
     [ "Ogre::Segment", "class_ogre_1_1_segment.html", null ],
     [ "Ogre::set< T, P >", "struct_ogre_1_1set.html", null ],
     [ "Ogre::ShadowCaster", "class_ogre_1_1_shadow_caster.html", [
