@@ -4,6 +4,8 @@ var namespace_ogre_1_1_bullet =
     [ "CollisionWorld", "class_ogre_1_1_bullet_1_1_collision_world.html", "class_ogre_1_1_bullet_1_1_collision_world" ],
     [ "DebugDrawer", "class_ogre_1_1_bullet_1_1_debug_drawer.html", "class_ogre_1_1_bullet_1_1_debug_drawer" ],
     [ "DynamicsWorld", "class_ogre_1_1_bullet_1_1_dynamics_world.html", "class_ogre_1_1_bullet_1_1_dynamics_world" ],
+    [ "HeightFieldData", "struct_ogre_1_1_bullet_1_1_height_field_data.html", "struct_ogre_1_1_bullet_1_1_height_field_data" ],
+    [ "KinematicMotionSimple", "class_ogre_1_1_bullet_1_1_kinematic_motion_simple.html", "class_ogre_1_1_bullet_1_1_kinematic_motion_simple" ],
     [ "RayResultCallback", "struct_ogre_1_1_bullet_1_1_ray_result_callback.html", "struct_ogre_1_1_bullet_1_1_ray_result_callback" ],
     [ "RigidBodyState", "class_ogre_1_1_bullet_1_1_rigid_body_state.html", "class_ogre_1_1_bullet_1_1_rigid_body_state" ],
     [ "ColliderType", "group___bullet.html#ga3830c02915732639d36dd2f7aa7b6d98", [
@@ -12,7 +14,8 @@ var namespace_ogre_1_1_bullet =
       [ "CT_CYLINDER", "group___bullet.html#gga3830c02915732639d36dd2f7aa7b6d98a6e2834b721b1bf5444d685379e6a1031", null ],
       [ "CT_CAPSULE", "group___bullet.html#gga3830c02915732639d36dd2f7aa7b6d98a073e87fdfdfabb19755f1defcbe1bb78", null ],
       [ "CT_TRIMESH", "group___bullet.html#gga3830c02915732639d36dd2f7aa7b6d98a4c72346edc69af82d8ee74e32f0f19d9", null ],
-      [ "CT_HULL", "group___bullet.html#gga3830c02915732639d36dd2f7aa7b6d98a3a55904467ef9e191aedbf08f5ca67e2", null ]
+      [ "CT_HULL", "group___bullet.html#gga3830c02915732639d36dd2f7aa7b6d98a3a55904467ef9e191aedbf08f5ca67e2", null ],
+      [ "CT_COMPOUND", "group___bullet.html#gga3830c02915732639d36dd2f7aa7b6d98a93188a275f493576a9744fa6738198f8", null ]
     ] ],
     [ "convert", "group___bullet.html#gae507a0bfafc7f585d0270d7445767065", null ],
     [ "convert", "group___bullet.html#ga6e488b2065b2f2daea503cfb2d7b7c0a", null ],
@@ -21,5 +24,9 @@ var namespace_ogre_1_1_bullet =
     [ "createSphereCollider", "group___bullet.html#ga4816ec507132c27c52b40dab60c6ba87", null ],
     [ "createBoxCollider", "group___bullet.html#ga508ce5259dc72353adaf458c9a1165bd", null ],
     [ "createCapsuleCollider", "group___bullet.html#ga4f6fa3c86ab9ac184a2149768002991d", null ],
-    [ "createCylinderCollider", "group___bullet.html#ga9dd4ceac77c2c6b52bc8e659fa39d82c", null ]
+    [ "createCylinderCollider", "group___bullet.html#ga9dd4ceac77c2c6b52bc8e659fa39d82c", null ],
+    [ "createTrimeshCollider", "group___bullet.html#gaed45b1c7e0ab58c9a0126671ab47c5cc", null ],
+    [ "createConvexHullCollider", "group___bullet.html#ga4b0184ec77d0e75daaf8e55fd8b90965", null ],
+    [ "createCompoundShape", "group___bullet.html#gab62b4f5293ae739167b3b22688d53b27", null ],
+    [ "createHeightfieldTerrainShape", "group___bullet.html#ga4f8524c5a233db7cae27d5b9bc90db05", null ]
 ];
\ No newline at end of file
