@@ -3,35 +3,25 @@ var namespace_ogre_1_1_r_t_shader =
     [ "AssignmentAtom", "class_ogre_1_1_r_t_shader_1_1_assignment_atom.html", "class_ogre_1_1_r_t_shader_1_1_assignment_atom" ],
     [ "At", "struct_ogre_1_1_r_t_shader_1_1_at.html", "struct_ogre_1_1_r_t_shader_1_1_at" ],
     [ "BinaryOpAtom", "class_ogre_1_1_r_t_shader_1_1_binary_op_atom.html", "class_ogre_1_1_r_t_shader_1_1_binary_op_atom" ],
+    [ "BuiltinFunctionAtom", "class_ogre_1_1_r_t_shader_1_1_builtin_function_atom.html", "class_ogre_1_1_r_t_shader_1_1_builtin_function_atom" ],
     [ "ConstParameter", "class_ogre_1_1_r_t_shader_1_1_const_parameter.html", "class_ogre_1_1_r_t_shader_1_1_const_parameter" ],
     [ "FFPTexturing", "class_ogre_1_1_r_t_shader_1_1_f_f_p_texturing.html", "class_ogre_1_1_r_t_shader_1_1_f_f_p_texturing" ],
-    [ "FFPTexturingFactory", "class_ogre_1_1_r_t_shader_1_1_f_f_p_texturing_factory.html", "class_ogre_1_1_r_t_shader_1_1_f_f_p_texturing_factory" ],
-    [ "FFPTransform", "class_ogre_1_1_r_t_shader_1_1_f_f_p_transform.html", "class_ogre_1_1_r_t_shader_1_1_f_f_p_transform" ],
-    [ "FFPTransformFactory", "class_ogre_1_1_r_t_shader_1_1_f_f_p_transform_factory.html", "class_ogre_1_1_r_t_shader_1_1_f_f_p_transform_factory" ],
     [ "Function", "class_ogre_1_1_r_t_shader_1_1_function.html", "class_ogre_1_1_r_t_shader_1_1_function" ],
     [ "FunctionAtom", "class_ogre_1_1_r_t_shader_1_1_function_atom.html", "class_ogre_1_1_r_t_shader_1_1_function_atom" ],
     [ "FunctionInvocation", "class_ogre_1_1_r_t_shader_1_1_function_invocation.html", "class_ogre_1_1_r_t_shader_1_1_function_invocation" ],
     [ "FunctionStageRef", "class_ogre_1_1_r_t_shader_1_1_function_stage_ref.html", "class_ogre_1_1_r_t_shader_1_1_function_stage_ref" ],
-    [ "GBuffer", "class_ogre_1_1_r_t_shader_1_1_g_buffer.html", "class_ogre_1_1_r_t_shader_1_1_g_buffer" ],
-    [ "GBufferFactory", "class_ogre_1_1_r_t_shader_1_1_g_buffer_factory.html", "class_ogre_1_1_r_t_shader_1_1_g_buffer_factory" ],
-    [ "HardwareSkinning", "class_ogre_1_1_r_t_shader_1_1_hardware_skinning.html", "class_ogre_1_1_r_t_shader_1_1_hardware_skinning" ],
     [ "HardwareSkinningFactory", "class_ogre_1_1_r_t_shader_1_1_hardware_skinning_factory.html", "class_ogre_1_1_r_t_shader_1_1_hardware_skinning_factory" ],
     [ "In", "struct_ogre_1_1_r_t_shader_1_1_in.html", "struct_ogre_1_1_r_t_shader_1_1_in" ],
     [ "InOut", "struct_ogre_1_1_r_t_shader_1_1_in_out.html", "struct_ogre_1_1_r_t_shader_1_1_in_out" ],
-    [ "IntegratedPSSM3", "class_ogre_1_1_r_t_shader_1_1_integrated_p_s_s_m3.html", "class_ogre_1_1_r_t_shader_1_1_integrated_p_s_s_m3" ],
-    [ "IntegratedPSSM3Factory", "class_ogre_1_1_r_t_shader_1_1_integrated_p_s_s_m3_factory.html", "class_ogre_1_1_r_t_shader_1_1_integrated_p_s_s_m3_factory" ],
     [ "LayeredBlending", "class_ogre_1_1_r_t_shader_1_1_layered_blending.html", "class_ogre_1_1_r_t_shader_1_1_layered_blending" ],
-    [ "LayeredBlendingFactory", "class_ogre_1_1_r_t_shader_1_1_layered_blending_factory.html", "class_ogre_1_1_r_t_shader_1_1_layered_blending_factory" ],
     [ "Operand", "class_ogre_1_1_r_t_shader_1_1_operand.html", "class_ogre_1_1_r_t_shader_1_1_operand" ],
     [ "Out", "struct_ogre_1_1_r_t_shader_1_1_out.html", "struct_ogre_1_1_r_t_shader_1_1_out" ],
     [ "Parameter", "class_ogre_1_1_r_t_shader_1_1_parameter.html", "class_ogre_1_1_r_t_shader_1_1_parameter" ],
     [ "ParameterFactory", "class_ogre_1_1_r_t_shader_1_1_parameter_factory.html", "class_ogre_1_1_r_t_shader_1_1_parameter_factory" ],
     [ "Program", "class_ogre_1_1_r_t_shader_1_1_program.html", "class_ogre_1_1_r_t_shader_1_1_program" ],
     [ "ProgramManager", "class_ogre_1_1_r_t_shader_1_1_program_manager.html", "class_ogre_1_1_r_t_shader_1_1_program_manager" ],
-    [ "ProgramProcessor", "class_ogre_1_1_r_t_shader_1_1_program_processor.html", "class_ogre_1_1_r_t_shader_1_1_program_processor" ],
     [ "ProgramSet", "class_ogre_1_1_r_t_shader_1_1_program_set.html", "class_ogre_1_1_r_t_shader_1_1_program_set" ],
     [ "ProgramWriter", "class_ogre_1_1_r_t_shader_1_1_program_writer.html", "class_ogre_1_1_r_t_shader_1_1_program_writer" ],
-    [ "ProgramWriterFactory", "class_ogre_1_1_r_t_shader_1_1_program_writer_factory.html", "class_ogre_1_1_r_t_shader_1_1_program_writer_factory" ],
     [ "ProgramWriterManager", "class_ogre_1_1_r_t_shader_1_1_program_writer_manager.html", "class_ogre_1_1_r_t_shader_1_1_program_writer_manager" ],
     [ "RenderState", "class_ogre_1_1_r_t_shader_1_1_render_state.html", "class_ogre_1_1_r_t_shader_1_1_render_state" ],
     [ "SampleTextureAtom", "class_ogre_1_1_r_t_shader_1_1_sample_texture_atom.html", "class_ogre_1_1_r_t_shader_1_1_sample_texture_atom" ],
@@ -41,8 +31,6 @@ var namespace_ogre_1_1_r_t_shader =
     [ "SubRenderStateAccessor", "class_ogre_1_1_r_t_shader_1_1_sub_render_state_accessor.html", "class_ogre_1_1_r_t_shader_1_1_sub_render_state_accessor" ],
     [ "SubRenderStateFactory", "class_ogre_1_1_r_t_shader_1_1_sub_render_state_factory.html", "class_ogre_1_1_r_t_shader_1_1_sub_render_state_factory" ],
     [ "TargetRenderState", "class_ogre_1_1_r_t_shader_1_1_target_render_state.html", "class_ogre_1_1_r_t_shader_1_1_target_render_state" ],
-    [ "TriplanarTexturing", "class_ogre_1_1_r_t_shader_1_1_triplanar_texturing.html", "class_ogre_1_1_r_t_shader_1_1_triplanar_texturing" ],
-    [ "TriplanarTexturingFactory", "class_ogre_1_1_r_t_shader_1_1_triplanar_texturing_factory.html", "class_ogre_1_1_r_t_shader_1_1_triplanar_texturing_factory" ],
     [ "UniformParameter", "class_ogre_1_1_r_t_shader_1_1_uniform_parameter.html", "class_ogre_1_1_r_t_shader_1_1_uniform_parameter" ],
     [ "ShaderFunctionList", "group___r_t_shader.html#ga19bee49a255fef79de7adf9c9ab08c62", null ],
     [ "ShaderFunctionIterator", "group___r_t_shader.html#ga91a7dab08d3a156422a3187fdb79f9d1", null ],
@@ -66,6 +54,10 @@ var namespace_ogre_1_1_r_t_shader =
     [ "SubRenderStateSet", "group___r_t_shader.html#ga9b918e7e9259b2d82e48e788da9f1485", null ],
     [ "SubRenderStateSetIterator", "group___r_t_shader.html#gab67a8756fb7f065af7052ef1fb14b1ec", null ],
     [ "SubRenderStateSetConstIterator", "group___r_t_shader.html#ga00d3d84afe3e5e75ca3fe1050c2fd29a", null ],
+    [ "SkinningType", "group___r_t_shader.html#ga8c100ce939d23573f062f3ad579998a1", [
+      [ "ST_LINEAR", "group___r_t_shader.html#gga8c100ce939d23573f062f3ad579998a1ab979c94e41c61d62d15f4771c5202e3c", null ],
+      [ "ST_DUAL_QUATERNION", "group___r_t_shader.html#gga8c100ce939d23573f062f3ad579998a1a08c0d76a7a8df2b6a839749c5be6c1af", null ]
+    ] ],
     [ "FFPVertexShaderStage", "group___r_t_shader.html#ga7d20b2397c3eab2b52ec405863c6f274", [
       [ "FFP_VS_PRE_PROCESS", "group___r_t_shader.html#gga7d20b2397c3eab2b52ec405863c6f274ad955465ff061413a966f568fc187599e", null ],
       [ "FFP_VS_TRANSFORM", "group___r_t_shader.html#gga7d20b2397c3eab2b52ec405863c6f274a04f47ef20926c0a10951eb3d6fa9af91", null ],
@@ -100,8 +92,21 @@ var namespace_ogre_1_1_r_t_shader =
       [ "VSOCP_MEDIUM", "namespace_ogre_1_1_r_t_shader.html#ab0694782a83ac342574ac3cf1e053355ae8945142e897f91a533021242ce30313", null ],
       [ "VSOCP_HIGH", "namespace_ogre_1_1_r_t_shader.html#ab0694782a83ac342574ac3cf1e053355af47ac7ffe0e82bd495a51205c2132aa4", null ]
     ] ],
-    [ "SkinningType", "namespace_ogre_1_1_r_t_shader.html#a8c100ce939d23573f062f3ad579998a1", [
-      [ "ST_LINEAR", "namespace_ogre_1_1_r_t_shader.html#a8c100ce939d23573f062f3ad579998a1ab979c94e41c61d62d15f4771c5202e3c", null ],
-      [ "ST_DUAL_QUATERNION", "namespace_ogre_1_1_r_t_shader.html#a8c100ce939d23573f062f3ad579998a1a08c0d76a7a8df2b6a839749c5be6c1af", null ]
-    ] ]
+    [ "SRS_TRANSFORM", "group___r_t_shader.html#ga8cb98be9db81aa08483836d3cda49c31", null ],
+    [ "SRS_VERTEX_COLOUR", "group___r_t_shader.html#gaaedbac186ba67be460c9ff2609104d89", null ],
+    [ "SRS_TEXTURING", "group___r_t_shader.html#gaf78d62646d139c60af9f8cd7daa8136c", null ],
+    [ "SRS_PER_VERTEX_LIGHTING", "group___r_t_shader.html#ga9df9782a53f184e3ec6a81926443afc4", null ],
+    [ "SRS_FOG", "group___r_t_shader.html#ga1198bbdd726ff91909afccbbb9538b9d", null ],
+    [ "SRS_ALPHA_TEST", "group___r_t_shader.html#gaf09319722f63550be8795b06bca8b1be", null ],
+    [ "SRS_INTEGRATED_PSSM3", "group___r_t_shader.html#gaec1615ce2452bc42bac73b00d740d9fb", null ],
+    [ "SRS_SHADOW_MAPPING", "group___r_t_shader.html#ga45a3189a26452fb887e09f6a092ac5a2", null ],
+    [ "SRS_PER_PIXEL_LIGHTING", "group___r_t_shader.html#gaeaa32a701498564aaf74ad6a03ee007f", null ],
+    [ "SRS_COOK_TORRANCE_LIGHTING", "group___r_t_shader.html#ga5006000d64f8d8aa291348e77c2fa0b5", null ],
+    [ "SRS_IMAGE_BASED_LIGHTING", "group___r_t_shader.html#gac09ee99e37f1742ea23a35960816cafd", null ],
+    [ "SRS_NORMALMAP", "group___r_t_shader.html#ga3eb58166dcc24a19e7ff0cb34f8f3b84", null ],
+    [ "SRS_WBOIT", "group___r_t_shader.html#ga59abbc0e8ec9ec8f101255f210896d7c", null ],
+    [ "SRS_GBUFFER", "group___r_t_shader.html#gac54469f6b123a91ff3c75de1b16c9f10", null ],
+    [ "SRS_TRIPLANAR_TEXTURING", "group___r_t_shader.html#gaa9191d59af2f6c1d9369c5de77279d86", null ],
+    [ "SRS_LAYERED_BLENDING", "group___r_t_shader.html#ga830e3fb403b2e0238a81c59eb9b05dce", null ],
+    [ "SRS_HARDWARE_SKINNING", "group___r_t_shader.html#ga1bd766b84d202e5a644be7a97cb9be79", null ]
 ];
\ No newline at end of file
