@@ -4,7 +4,6 @@ var namespacemembers_eval =
     [ "a", "namespacemembers_eval_a.html", null ],
     [ "b", "namespacemembers_eval_b.html", null ],
     [ "c", "namespacemembers_eval_c.html", null ],
-    [ "e", "namespacemembers_eval_e.html", null ],
     [ "f", "namespacemembers_eval_f.html", null ],
     [ "g", "namespacemembers_eval_g.html", null ],
     [ "h", "namespacemembers_eval_h.html", null ],
@@ -19,7 +18,6 @@ var namespacemembers_eval =
     [ "r", "namespacemembers_eval_r.html", null ],
     [ "s", "namespacemembers_eval_s.html", null ],
     [ "t", "namespacemembers_eval_t.html", null ],
-    [ "u", "namespacemembers_eval_u.html", null ],
     [ "v", "namespacemembers_eval_v.html", null ],
     [ "w", "namespacemembers_eval_w.html", null ]
 ];
\ No newline at end of file
