@@ -60,14 +60,14 @@ var NAVTREEINDEX0 =
 "_compositor-_scripts.html#compositor-texture":[1,3,5,1,0],
 "_cross-platform-_shaders.html":[1,10],
 "_cross-platform-_shaders.html#OgreUnifiedShader":[1,10,1],
-"_cross-platform-_shaders.html#autotoc_md205":[1,10,0],
-"_cross-platform-_shaders.html#autotoc_md206":[1,10,2],
-"_external-_texture-_sources.html":[2,14],
-"_external-_texture-_sources.html#autotoc_md294":[2,14,0],
-"_external-_texture-_sources.html#autotoc_md295":[2,14,1],
-"_external-_texture-_sources.html#autotoc_md296":[2,14,2],
-"_external-_texture-_sources.html#autotoc_md297":[2,14,3],
-"_external-_texture-_sources.html#autotoc_md298":[2,14,4],
+"_cross-platform-_shaders.html#autotoc_md204":[1,10,0],
+"_cross-platform-_shaders.html#autotoc_md205":[1,10,2],
+"_external-_texture-_sources.html":[2,13],
+"_external-_texture-_sources.html#autotoc_md293":[2,13,0],
+"_external-_texture-_sources.html#autotoc_md294":[2,13,1],
+"_external-_texture-_sources.html#autotoc_md295":[2,13,2],
+"_external-_texture-_sources.html#autotoc_md296":[2,13,3],
+"_external-_texture-_sources.html#autotoc_md297":[2,13,4],
 "_font-_definition-_scripts.html":[1,3,8],
 "_font-_definition-_scripts.html#autotoc_md108":[1,3,8,0],
 "_font-_definition-_scripts.html#autotoc_md109":[1,3,8,1],
@@ -98,12 +98,13 @@ var NAVTREEINDEX0 =
 "_hardware-_buffers.html#Updating-Vertex-Buffers":[1,6,5,5],
 "_hardware-_buffers.html#Vertex-Buffer-Bindings":[1,6,5,2],
 "_hardware-_buffers.html#Vertex-Declarations":[1,6,5,1],
-"_hardware-_buffers.html#autotoc_md241":[1,6,3,0],
-"_hardware-_buffers.html#autotoc_md242":[1,6,3,1,0],
-"_hardware-_buffers.html#autotoc_md243":[1,6,4,0],
-"_hardware-_buffers.html#autotoc_md244":[1,6,6,1],
+"_hardware-_buffers.html#autotoc_md240":[1,6,3,0],
+"_hardware-_buffers.html#autotoc_md241":[1,6,3,1,0],
+"_hardware-_buffers.html#autotoc_md242":[1,6,4,0],
+"_hardware-_buffers.html#autotoc_md243":[1,6,6,1],
 "_hardware-_buffers.html#blitFromMemory":[1,6,7,1,0],
 "_high-level-_programs.html":[1,3,4],
+"_high-level-_programs.html#Assembler-Shaders":[1,3,4,5],
 "_high-level-_programs.html#Binding-vertex-attributes":[1,3,4,2,0],
 "_high-level-_programs.html#Cg":[1,3,4,3],
 "_high-level-_programs.html#Declaring-Shared-Parameters":[1,3,4,9],
@@ -133,17 +134,16 @@ var NAVTREEINDEX0 =
 "_high-level-_programs.html#autotoc_md191":[1,3,4,2,6,1],
 "_high-level-_programs.html#autotoc_md192":[1,3,4,2,6,2],
 "_high-level-_programs.html#autotoc_md193":[1,3,4,2,6,3],
-"_high-level-_programs.html#autotoc_md194":[1,3,4,5],
-"_high-level-_programs.html#autotoc_md195":[1,3,4,8,0],
-"_high-level-_programs.html#autotoc_md196":[1,3,4,8,1],
-"_high-level-_programs.html#autotoc_md197":[1,3,4,8,2],
-"_high-level-_programs.html#autotoc_md198":[1,3,4,8,3],
-"_high-level-_programs.html#autotoc_md199":[1,3,4,8,4],
-"_high-level-_programs.html#autotoc_md200":[1,3,4,9,0],
-"_high-level-_programs.html#autotoc_md201":[1,3,4,15,0],
-"_high-level-_programs.html#autotoc_md202":[1,3,4,15,1],
-"_high-level-_programs.html#autotoc_md203":[1,3,4,15,2],
-"_high-level-_programs.html#autotoc_md204":[1,3,4,15,3],
+"_high-level-_programs.html#autotoc_md194":[1,3,4,8,0],
+"_high-level-_programs.html#autotoc_md195":[1,3,4,8,1],
+"_high-level-_programs.html#autotoc_md196":[1,3,4,8,2],
+"_high-level-_programs.html#autotoc_md197":[1,3,4,8,3],
+"_high-level-_programs.html#autotoc_md198":[1,3,4,8,4],
+"_high-level-_programs.html#autotoc_md199":[1,3,4,9,0],
+"_high-level-_programs.html#autotoc_md200":[1,3,4,15,0],
+"_high-level-_programs.html#autotoc_md201":[1,3,4,15,1],
+"_high-level-_programs.html#autotoc_md202":[1,3,4,15,2],
+"_high-level-_programs.html#autotoc_md203":[1,3,4,15,3],
 "_high-level-_programs.html#multi-language-programs":[1,3,4,6],
 "_high_py_8py.html":[8,0,0,6,0],
 "_instancing.html":[1,9],
