@@ -1,5 +1,26 @@
 var NAVTREEINDEX12 =
 {
+"class_ogre_1_1_default_debug_drawer.html#a96bec68667abef108812e67af9992a47":[6,0,1,97,4],
+"class_ogre_1_1_default_debug_drawer.html#a96bec68667abef108812e67af9992a47":[7,0,0,97,4],
+"class_ogre_1_1_default_debug_drawer.html#abd9aa227f93cc19a3203e442343ebe37":[6,0,1,97,5],
+"class_ogre_1_1_default_debug_drawer.html#abd9aa227f93cc19a3203e442343ebe37":[7,0,0,97,5],
+"class_ogre_1_1_default_debug_drawer.html#ad291150ad2a0cbcddd5d803914b5b4ba":[6,0,1,97,2],
+"class_ogre_1_1_default_debug_drawer.html#ad291150ad2a0cbcddd5d803914b5b4ba":[7,0,0,97,2],
+"class_ogre_1_1_default_debug_drawer.html#ad583dda40c55a78057864e8718beb52a":[6,0,1,97,3],
+"class_ogre_1_1_default_debug_drawer.html#ad583dda40c55a78057864e8718beb52a":[7,0,0,97,3],
+"class_ogre_1_1_default_debug_drawer.html#aeb637f7326367d271fdcd0c4412cea08":[6,0,1,97,1],
+"class_ogre_1_1_default_debug_drawer.html#aeb637f7326367d271fdcd0c4412cea08":[7,0,0,97,1],
+"class_ogre_1_1_default_hardware_buffer.html":[5,0,7,1],
+"class_ogre_1_1_default_hardware_buffer.html#a050c9b25ac465441a52837bb75ebc60f":[5,0,7,1,3],
+"class_ogre_1_1_default_hardware_buffer.html#a3b7d53524bb4efc2aa1b9ebf608dcea2":[5,0,7,1,2],
+"class_ogre_1_1_default_hardware_buffer.html#aa2e1f53f6c37b0bb57bc38e4fe4d8fef":[5,0,7,1,4],
+"class_ogre_1_1_default_hardware_buffer.html#abf4158a560d35033133680dfb29e99f7":[5,0,7,1,1],
+"class_ogre_1_1_default_hardware_buffer.html#af5bf169a8912f614a2e301993e66abee":[5,0,7,1,0],
+"class_ogre_1_1_default_hardware_buffer_manager.html":[5,0,7,2],
+"class_ogre_1_1_default_hardware_buffer_manager.html#a222290dca734e3cb879691b334776e34":[5,0,7,2,1],
+"class_ogre_1_1_default_hardware_buffer_manager.html#a4705dd8822b0d33c17e1941572bd820d":[5,0,7,2,2],
+"class_ogre_1_1_default_hardware_buffer_manager.html#a4cd035da8caa2867d327ea9490f91c4d":[5,0,7,2,0],
+"class_ogre_1_1_default_hardware_buffer_manager.html#ad52b27601f52d5028d5f56e074e27d06":[5,0,7,2,4],
 "class_ogre_1_1_default_hardware_buffer_manager.html#af224a816c521f8d7da2aa5c1e312f25b":[5,0,7,2,5],
 "class_ogre_1_1_default_hardware_buffer_manager.html#afcf18a21b65c0375d28c5686307a3eee":[5,0,7,2,3],
 "class_ogre_1_1_default_hardware_buffer_manager_base.html":[5,0,7,3],
@@ -228,26 +249,5 @@ var NAVTREEINDEX12 =
 "class_ogre_1_1_distance_lod_strategy_base.html#a5b60368988f8c388b97d6af77b7c08c9":[5,0,4,3,11],
 "class_ogre_1_1_distance_lod_strategy_base.html#a65d9d54235e62d66e1f25355926d7a63":[5,0,4,3,6],
 "class_ogre_1_1_distance_lod_strategy_base.html#a8a2e6192e83057b8973b5247a8ff7abe":[5,0,4,3,1],
-"class_ogre_1_1_distance_lod_strategy_base.html#ab26e68a2e700746489699bc1c70e8e18":[5,0,4,3,3],
-"class_ogre_1_1_distance_lod_strategy_base.html#acb473d444fc5b8b836b172d3baaa6a75":[5,0,4,3,4],
-"class_ogre_1_1_distance_lod_strategy_base.html#ae0eb79032a169437c7ecdad4d20e8a81":[5,0,4,3,5],
-"class_ogre_1_1_distance_lod_strategy_base.html#ae8568a566aac276fcf9f1ab7c5f19a38":[5,0,4,3,2],
-"class_ogre_1_1_distance_lod_strategy_base.html#aed77c6dfbdc0fbf75bf9deaf4f2b8bfc":[5,0,4,3,9],
-"class_ogre_1_1_dot_scene_loader.html":[5,2,3,0],
-"class_ogre_1_1_dot_scene_loader.html#a4d3297139bca45e1130443d79b7b2e70":[5,2,3,0,0],
-"class_ogre_1_1_dot_scene_loader.html#a6a2e576a1adac9e7dd9c59548c02df47":[5,2,3,0,1],
-"class_ogre_1_1_dot_scene_loader.html#a6e5298ed5aed9df4bc08a9e76db432a0":[5,2,3,0,2],
-"class_ogre_1_1_dot_scene_loader.html#ab47d1392af6c3f5679f45d79fd31261b":[5,2,3,0,4],
-"class_ogre_1_1_dot_scene_loader.html#ae35c9465e0d77b51589dabefa2cdeb6d":[5,2,3,0,3],
-"class_ogre_1_1_dot_scene_plugin.html":[5,2,3,1],
-"class_ogre_1_1_dual_quaternion.html":[5,0,6,6],
-"class_ogre_1_1_dual_quaternion.html#a024daf85de3ed5b28ac41d490012dd2f":[5,0,6,6,7],
-"class_ogre_1_1_dual_quaternion.html#a0eb3f8e285a3aaddb6867f24486dbf21":[5,0,6,6,8],
-"class_ogre_1_1_dual_quaternion.html#a10574bf89fef9fc12fac5ed4e8085f71":[5,0,6,6,3],
-"class_ogre_1_1_dual_quaternion.html#a123fbf0958bccd9f5381d6f124d0586e":[5,0,6,6,25],
-"class_ogre_1_1_dual_quaternion.html#a16fefc12aaa35460748c8dfc253d39f1":[5,0,6,6,17],
-"class_ogre_1_1_dual_quaternion.html#a1afbb66b83f2085f452bb663ceafc9dc":[5,0,6,6,20],
-"class_ogre_1_1_dual_quaternion.html#a303afd76b65bd34a28accdb6eb0c024c":[5,0,6,6,4],
-"class_ogre_1_1_dual_quaternion.html#a43375b322ae7a0b7f5d03318bfa33f17":[5,0,6,6,21],
-"class_ogre_1_1_dual_quaternion.html#a488ce81a7866d481169647cff04dc17c":[5,0,6,6,24]
+"class_ogre_1_1_distance_lod_strategy_base.html#ab26e68a2e700746489699bc1c70e8e18":[5,0,4,3,3]
 };
