@@ -1,5 +1,26 @@
 var NAVTREEINDEX13 =
 {
+"class_ogre_1_1_distance_lod_strategy_base.html#acb473d444fc5b8b836b172d3baaa6a75":[5,0,4,3,4],
+"class_ogre_1_1_distance_lod_strategy_base.html#ae0eb79032a169437c7ecdad4d20e8a81":[5,0,4,3,5],
+"class_ogre_1_1_distance_lod_strategy_base.html#ae8568a566aac276fcf9f1ab7c5f19a38":[5,0,4,3,2],
+"class_ogre_1_1_distance_lod_strategy_base.html#aed77c6dfbdc0fbf75bf9deaf4f2b8bfc":[5,0,4,3,9],
+"class_ogre_1_1_dot_scene_loader.html":[5,2,3,0],
+"class_ogre_1_1_dot_scene_loader.html#a4d3297139bca45e1130443d79b7b2e70":[5,2,3,0,0],
+"class_ogre_1_1_dot_scene_loader.html#a6a2e576a1adac9e7dd9c59548c02df47":[5,2,3,0,1],
+"class_ogre_1_1_dot_scene_loader.html#a6e5298ed5aed9df4bc08a9e76db432a0":[5,2,3,0,2],
+"class_ogre_1_1_dot_scene_loader.html#ab47d1392af6c3f5679f45d79fd31261b":[5,2,3,0,4],
+"class_ogre_1_1_dot_scene_loader.html#ae35c9465e0d77b51589dabefa2cdeb6d":[5,2,3,0,3],
+"class_ogre_1_1_dot_scene_plugin.html":[5,2,3,1],
+"class_ogre_1_1_dual_quaternion.html":[5,0,6,6],
+"class_ogre_1_1_dual_quaternion.html#a024daf85de3ed5b28ac41d490012dd2f":[5,0,6,6,7],
+"class_ogre_1_1_dual_quaternion.html#a0eb3f8e285a3aaddb6867f24486dbf21":[5,0,6,6,8],
+"class_ogre_1_1_dual_quaternion.html#a10574bf89fef9fc12fac5ed4e8085f71":[5,0,6,6,3],
+"class_ogre_1_1_dual_quaternion.html#a123fbf0958bccd9f5381d6f124d0586e":[5,0,6,6,25],
+"class_ogre_1_1_dual_quaternion.html#a16fefc12aaa35460748c8dfc253d39f1":[5,0,6,6,17],
+"class_ogre_1_1_dual_quaternion.html#a1afbb66b83f2085f452bb663ceafc9dc":[5,0,6,6,20],
+"class_ogre_1_1_dual_quaternion.html#a303afd76b65bd34a28accdb6eb0c024c":[5,0,6,6,4],
+"class_ogre_1_1_dual_quaternion.html#a43375b322ae7a0b7f5d03318bfa33f17":[5,0,6,6,21],
+"class_ogre_1_1_dual_quaternion.html#a488ce81a7866d481169647cff04dc17c":[5,0,6,6,24],
 "class_ogre_1_1_dual_quaternion.html#a4e1b52752fb889035e68f893f2a246c6":[5,0,6,6,19],
 "class_ogre_1_1_dual_quaternion.html#a67e838a3d4ab670c3a4ef9c62293b038":[5,0,6,6,9],
 "class_ogre_1_1_dual_quaternion.html#a80c92016a8442946a264b8c13ba9f300":[5,0,6,6,12],
@@ -228,26 +249,5 @@ var NAVTREEINDEX13 =
 "class_ogre_1_1_file_handle_data_stream.html#a18495697fbafb35e7a7f0598ee2f05eb":[5,0,8,7,6],
 "class_ogre_1_1_file_handle_data_stream.html#a34724e68b6851b82f2b24258374fa36f":[5,0,8,7,7],
 "class_ogre_1_1_file_handle_data_stream.html#a8ea944090aacbf0c01b4173ffd06263d":[5,0,8,7,4],
-"class_ogre_1_1_file_handle_data_stream.html#a9b0503929f53ff42daa0eac1847a6c06":[5,0,8,7,2],
-"class_ogre_1_1_file_handle_data_stream.html#ab989e33923b0a1e183daace6e04fe095":[5,0,8,7,5],
-"class_ogre_1_1_file_handle_data_stream.html#ac103b47f41b7eb60c413f09e00a52618":[5,0,8,7,9],
-"class_ogre_1_1_file_handle_data_stream.html#ad23d93b3f62ab0413599c7650708fdd3":[5,0,8,7,8],
-"class_ogre_1_1_file_handle_data_stream.html#ae02327b74fba680f4f5c412dca0c24df":[5,0,8,7,3],
-"class_ogre_1_1_file_handle_data_stream.html#af3d8fd17787d46b2e6ab486586e0925f":[5,0,8,7,0],
-"class_ogre_1_1_file_not_found_exception.html":[5,0,2,14],
-"class_ogre_1_1_file_not_found_exception.html#ac5774daad7866a3b538731c16ba08faf":[5,0,2,14,0],
-"class_ogre_1_1_file_stream_data_stream.html":[5,0,8,9],
-"class_ogre_1_1_file_stream_data_stream.html#a0c97b2349bd5b4e80d9c5d7e5fac28fa":[5,0,8,9,8],
-"class_ogre_1_1_file_stream_data_stream.html#a105ef33e795dbe3ae862f8cc6eddedba":[5,0,8,9,11],
-"class_ogre_1_1_file_stream_data_stream.html#a17da6f498bcd96c82e6e9d899d5a6c45":[5,0,8,9,1],
-"class_ogre_1_1_file_stream_data_stream.html#a1eddb0271c48d023de2320d000db6bb9":[5,0,8,9,7],
-"class_ogre_1_1_file_stream_data_stream.html#a28e08d055a4f0a5aa45ebebcd1b0fc76":[5,0,8,9,13],
-"class_ogre_1_1_file_stream_data_stream.html#a2b75e029e956749aac1cd0b83e71a4b3":[5,0,8,9,14],
-"class_ogre_1_1_file_stream_data_stream.html#a5a24dd1dcf7146d5ff2284dc51df3fe6":[5,0,8,9,2],
-"class_ogre_1_1_file_stream_data_stream.html#a5df1c318c09bdd986a5a5a3d42f16b93":[5,0,8,9,0],
-"class_ogre_1_1_file_stream_data_stream.html#a645b1e56b481855c35185ff98cfc06ce":[5,0,8,9,6],
-"class_ogre_1_1_file_stream_data_stream.html#a77232ae394e34633ccace38df0fe2e65":[5,0,8,9,12],
-"class_ogre_1_1_file_stream_data_stream.html#a85cb7005fc0eadec79baae3e11eb5865":[5,0,8,9,4],
-"class_ogre_1_1_file_stream_data_stream.html#a914e50d8b76768a48ec7ab3b11b7f54a":[5,0,8,9,10],
-"class_ogre_1_1_file_stream_data_stream.html#ad3a630e313bd60e09074abcef3fd0b83":[5,0,8,9,9]
+"class_ogre_1_1_file_handle_data_stream.html#a9b0503929f53ff42daa0eac1847a6c06":[5,0,8,7,2]
 };
