@@ -1,5 +1,26 @@
 var NAVTREEINDEX14 =
 {
+"class_ogre_1_1_file_handle_data_stream.html#ab989e33923b0a1e183daace6e04fe095":[5,0,8,7,5],
+"class_ogre_1_1_file_handle_data_stream.html#ac103b47f41b7eb60c413f09e00a52618":[5,0,8,7,9],
+"class_ogre_1_1_file_handle_data_stream.html#ad23d93b3f62ab0413599c7650708fdd3":[5,0,8,7,8],
+"class_ogre_1_1_file_handle_data_stream.html#ae02327b74fba680f4f5c412dca0c24df":[5,0,8,7,3],
+"class_ogre_1_1_file_handle_data_stream.html#af3d8fd17787d46b2e6ab486586e0925f":[5,0,8,7,0],
+"class_ogre_1_1_file_not_found_exception.html":[5,0,2,14],
+"class_ogre_1_1_file_not_found_exception.html#ac5774daad7866a3b538731c16ba08faf":[5,0,2,14,0],
+"class_ogre_1_1_file_stream_data_stream.html":[5,0,8,9],
+"class_ogre_1_1_file_stream_data_stream.html#a0c97b2349bd5b4e80d9c5d7e5fac28fa":[5,0,8,9,8],
+"class_ogre_1_1_file_stream_data_stream.html#a105ef33e795dbe3ae862f8cc6eddedba":[5,0,8,9,11],
+"class_ogre_1_1_file_stream_data_stream.html#a17da6f498bcd96c82e6e9d899d5a6c45":[5,0,8,9,1],
+"class_ogre_1_1_file_stream_data_stream.html#a1eddb0271c48d023de2320d000db6bb9":[5,0,8,9,7],
+"class_ogre_1_1_file_stream_data_stream.html#a28e08d055a4f0a5aa45ebebcd1b0fc76":[5,0,8,9,13],
+"class_ogre_1_1_file_stream_data_stream.html#a2b75e029e956749aac1cd0b83e71a4b3":[5,0,8,9,14],
+"class_ogre_1_1_file_stream_data_stream.html#a5a24dd1dcf7146d5ff2284dc51df3fe6":[5,0,8,9,2],
+"class_ogre_1_1_file_stream_data_stream.html#a5df1c318c09bdd986a5a5a3d42f16b93":[5,0,8,9,0],
+"class_ogre_1_1_file_stream_data_stream.html#a645b1e56b481855c35185ff98cfc06ce":[5,0,8,9,6],
+"class_ogre_1_1_file_stream_data_stream.html#a77232ae394e34633ccace38df0fe2e65":[5,0,8,9,12],
+"class_ogre_1_1_file_stream_data_stream.html#a85cb7005fc0eadec79baae3e11eb5865":[5,0,8,9,4],
+"class_ogre_1_1_file_stream_data_stream.html#a914e50d8b76768a48ec7ab3b11b7f54a":[5,0,8,9,10],
+"class_ogre_1_1_file_stream_data_stream.html#ad3a630e313bd60e09074abcef3fd0b83":[5,0,8,9,9],
 "class_ogre_1_1_file_stream_data_stream.html#adcc220c9d2d2e6724c05359e854dc95c":[5,0,8,9,5],
 "class_ogre_1_1_file_stream_data_stream.html#ae57d5d322a93cbf21e5ffd382919f3a3":[5,0,8,9,3],
 "class_ogre_1_1_file_system_archive_factory.html":[5,0,8,10],
@@ -48,16 +69,18 @@ var NAVTREEINDEX14 =
 "class_ogre_1_1_font.html#a08e9fef8b8196c28d928c690964fc031":[5,1,3,2,8],
 "class_ogre_1_1_font.html#a1248de6416ef53ce06eaf69bbb20a576":[5,1,3,2,7],
 "class_ogre_1_1_font.html#a242776c92b41e51d0dbce17ba9fec747":[5,1,3,2,10],
-"class_ogre_1_1_font.html#a278117d7414d69dbaed6e7290e842991":[5,1,3,2,27],
+"class_ogre_1_1_font.html#a278117d7414d69dbaed6e7290e842991":[5,1,3,2,29],
 "class_ogre_1_1_font.html#a3b754bb7b6d6b9be27d76d7c3a70fc7e":[5,1,3,2,3],
-"class_ogre_1_1_font.html#a44e60ba33fb4a583d0239cc5cc9c849f":[5,1,3,2,29],
+"class_ogre_1_1_font.html#a44e60ba33fb4a583d0239cc5cc9c849f":[5,1,3,2,31],
 "class_ogre_1_1_font.html#a47a7dce0f5dc507a7e95b9a86f1be869":[5,1,3,2,17],
 "class_ogre_1_1_font.html#a68ba192b84cc956d76b5d5f463b2f6b2":[5,1,3,2,14],
-"class_ogre_1_1_font.html#a6ca4172a3f554f07752997b1a25278c0":[5,1,3,2,26],
+"class_ogre_1_1_font.html#a6ca4172a3f554f07752997b1a25278c0":[5,1,3,2,28],
 "class_ogre_1_1_font.html#a72c15459c7101517430c046bfa653702":[5,1,3,2,9],
-"class_ogre_1_1_font.html#a7b1206935984cda27994ec766dae3f22":[5,1,3,2,24],
-"class_ogre_1_1_font.html#a7d54a57f586af8b040b4e2d3481aaa35":[5,1,3,2,28],
+"class_ogre_1_1_font.html#a7b1206935984cda27994ec766dae3f22":[5,1,3,2,26],
+"class_ogre_1_1_font.html#a7d54a57f586af8b040b4e2d3481aaa35":[5,1,3,2,30],
+"class_ogre_1_1_font.html#a837ff11c4d56b5bfd81ffe17c73d92c0":[5,1,3,2,32],
 "class_ogre_1_1_font.html#a847b5fa1668cee1943651d3bb496f243":[5,1,3,2,23],
+"class_ogre_1_1_font.html#a87ce3d81e9b9b53479faa83c1d29c1bb":[5,1,3,2,24],
 "class_ogre_1_1_font.html#a9915203be62b8bd2feda436cc9f08cb0":[5,1,3,2,4],
 "class_ogre_1_1_font.html#a9bdff138015537e6245b4fa016c37d52":[5,1,3,2,1],
 "class_ogre_1_1_font.html#aa455a399457bd458852555c696b28f6a":[5,1,3,2,2],
@@ -68,7 +91,8 @@ var NAVTREEINDEX14 =
 "class_ogre_1_1_font.html#abfa4659b19ef3052676ccf8a64181e6f":[5,1,3,2,11],
 "class_ogre_1_1_font.html#ac2c1fba5ad2d610ecc78b1e1a6a1b8dc":[5,1,3,2,21],
 "class_ogre_1_1_font.html#ac550d4abfd2c2a61edf2c1ad8718afc6":[5,1,3,2,20],
-"class_ogre_1_1_font.html#ac78d744eddeeaef4c01a078f9c3c9119":[5,1,3,2,25],
+"class_ogre_1_1_font.html#ac78d744eddeeaef4c01a078f9c3c9119":[5,1,3,2,27],
+"class_ogre_1_1_font.html#ac89f41cb59be64a896776e1b2cd307f4":[5,1,3,2,25],
 "class_ogre_1_1_font.html#ad68729fd75b27236a4174a5e5013c448":[5,1,3,2,12],
 "class_ogre_1_1_font.html#add35224e7d0fe9615222944ea17cde13":[5,1,3,2,16],
 "class_ogre_1_1_font.html#adfdd689e89e023ae144207da8b82487a":[5,1,3,2,13],
@@ -225,29 +249,5 @@ var NAVTREEINDEX14 =
 "class_ogre_1_1_g_l3_plus_render_system.html#af888cf5cd565f35f849dc47b25b62208":[5,3,3,0,7],
 "class_ogre_1_1_g_l3_plus_render_system.html#af91a889e23e61ce3172493d4f1b36ae5":[5,3,3,0,19],
 "class_ogre_1_1_g_l3_plus_render_system.html#afe6d5b7391f34b5c5839eb39f17cf0db":[5,3,3,0,2],
-"class_ogre_1_1_g_l_e_s2_render_system.html":[5,3,4,0],
-"class_ogre_1_1_g_l_render_system.html":[5,3,2,0],
-"class_ogre_1_1_g_l_render_system.html#a0783b0403ec180031f37239eed3147cc":[5,3,2,0,30],
-"class_ogre_1_1_g_l_render_system.html#a132d0da2b48c7b5daa44ec3730b64873":[5,3,2,0,14],
-"class_ogre_1_1_g_l_render_system.html#a21d3ff16052756ba9a5b21feab552e05":[5,3,2,0,8],
-"class_ogre_1_1_g_l_render_system.html#a2e37d62e2c532d8c524d6140cde01b34":[5,3,2,0,25],
-"class_ogre_1_1_g_l_render_system.html#a358f097fac58b32424c5be500351fe64":[5,3,2,0,35],
-"class_ogre_1_1_g_l_render_system.html#a37177c469fc81c836d1176ceb3e9b60d":[5,3,2,0,28],
-"class_ogre_1_1_g_l_render_system.html#a4a10e74f96f2a3d9b8d34565335e02cf":[5,3,2,0,20],
-"class_ogre_1_1_g_l_render_system.html#a55e308041ab5a5f3528e2704083d5def":[5,3,2,0,52],
-"class_ogre_1_1_g_l_render_system.html#a5a17497222615664e3ee0c0acc710996":[5,3,2,0,55],
-"class_ogre_1_1_g_l_render_system.html#a5a270133c9e8652aa81da874a7af2f7b":[5,3,2,0,24],
-"class_ogre_1_1_g_l_render_system.html#a5cdbf5bc81db26a06ea374852f8c06db":[5,3,2,0,1],
-"class_ogre_1_1_g_l_render_system.html#a5f6f169f08fcba1c4c698e8e2deb5b77":[5,3,2,0,7],
-"class_ogre_1_1_g_l_render_system.html#a645c652995972bdc77ab87fa550fd4f9":[5,3,2,0,0],
-"class_ogre_1_1_g_l_render_system.html#a6a37f51fa922ed17414905d8e6f52a6c":[5,3,2,0,57],
-"class_ogre_1_1_g_l_render_system.html#a7071890524a4893e80ece1a814ec8480":[5,3,2,0,40],
-"class_ogre_1_1_g_l_render_system.html#a71e280a2d4ca87f14fcf16f123b0a4e7":[5,3,2,0,4],
-"class_ogre_1_1_g_l_render_system.html#a736d0e32dd7a0ed3141ed92e915fba15":[5,3,2,0,27],
-"class_ogre_1_1_g_l_render_system.html#a7992c7c6510cbb66509d30729fb9fd42":[5,3,2,0,26],
-"class_ogre_1_1_g_l_render_system.html#a7add2c48b5716a2b4c4be8559b58c896":[5,3,2,0,9],
-"class_ogre_1_1_g_l_render_system.html#a7bd95de6fee50bc35fcf39056be9eec1":[5,3,2,0,46],
-"class_ogre_1_1_g_l_render_system.html#a7e7249f7fc6dbc0eebee3dc76fcaec6f":[5,3,2,0,41],
-"class_ogre_1_1_g_l_render_system.html#a8016fb6b9e3c437dfa930f4e73c0c5b8":[5,3,2,0,56],
-"class_ogre_1_1_g_l_render_system.html#a81ac92bb216f899508d34b843f9a1aa6":[5,3,2,0,2]
+"class_ogre_1_1_g_l_e_s2_render_system.html":[5,3,4,0]
 };
