@@ -1,5 +1,30 @@
 var NAVTREEINDEX18 =
 {
+"class_ogre_1_1_import_abstract_node.html#abf7e3cadcd65283bae356cc5dde84826":[5,0,10,8,4],
+"class_ogre_1_1_index_data.html":[5,0,7,16],
+"class_ogre_1_1_index_data.html#a0c19f7fc00c66266fd0d7fe671733112":[5,0,7,16,3],
+"class_ogre_1_1_index_data.html#a1a9f241fbc57ce4cce5615302da71b76":[5,0,7,16,4],
+"class_ogre_1_1_index_data.html#a5de34ff4f44a224ac2f1f9b855d8671c":[5,0,7,16,5],
+"class_ogre_1_1_index_data.html#a77a5cd1f32a0ac033a7cee9b50424c4e":[5,0,7,16,6],
+"class_ogre_1_1_index_data.html#a79242aa4c8893016a56d2cc13a10f803":[5,0,7,16,0],
+"class_ogre_1_1_index_data.html#a952375c947bc66a7bc98fa1e20ac1e3d":[5,0,7,16,1],
+"class_ogre_1_1_index_data.html#ab3b66e2bdf177564d8bba86553c3695d":[5,0,7,16,2],
+"class_ogre_1_1_instance_batch.html":[5,0,9,13],
+"class_ogre_1_1_instance_batch.html#a196b591da8b57799ef3c960c60552876":[5,0,9,13,37],
+"class_ogre_1_1_instance_batch.html#abd85c7ae6f5de865b8037f37e426886e":[5,0,9,13,38],
+"class_ogre_1_1_instance_batch_h_w.html":[5,0,9,14],
+"class_ogre_1_1_instance_batch_h_w___v_t_f.html":[5,0,9,15],
+"class_ogre_1_1_instance_batch_shader.html":[5,0,9,16],
+"class_ogre_1_1_instance_batch_v_t_f.html":[5,0,9,17],
+"class_ogre_1_1_instance_manager.html":[5,0,9,19],
+"class_ogre_1_1_instanced_entity.html":[5,0,9,18],
+"class_ogre_1_1_internal_error_exception.html":[5,0,2,17],
+"class_ogre_1_1_internal_error_exception.html#a5bc4d45afee8370b1688b13dd6099cb2":[5,0,2,17,0],
+"class_ogre_1_1_intersection_scene_query.html":[5,0,9,20],
+"class_ogre_1_1_intersection_scene_query.html#a22d71638bac66acdaf3a5b3ced9f3af5":[5,0,9,20,6],
+"class_ogre_1_1_intersection_scene_query.html#a23bc9fc19792b2c646cb02013f4f4e90":[5,0,9,20,2],
+"class_ogre_1_1_intersection_scene_query.html#a2d2dae1d033750a297a681e4f7f71f06":[5,0,9,20,0],
+"class_ogre_1_1_intersection_scene_query.html#a4897a8a1976f075977275fa743f6a852":[5,0,9,20,7],
 "class_ogre_1_1_intersection_scene_query.html#a7df8386f937c104aeb4f6cf50eb3bd8f":[5,0,9,20,4],
 "class_ogre_1_1_intersection_scene_query.html#a8d842a355cf6348c4e969e2e84aa631b":[5,0,9,20,5],
 "class_ogre_1_1_intersection_scene_query.html#aa4302f9623d93f620cde40ebc8c18e3c":[5,0,9,20,3],
@@ -16,28 +41,28 @@ var NAVTREEINDEX18 =
 "class_ogre_1_1_invalid_state_exception.html#ab0379b445379968669795492ba1ef567":[5,0,2,20,0],
 "class_ogre_1_1_item_identity_exception.html":[5,0,2,22],
 "class_ogre_1_1_item_identity_exception.html#ae98c4a38b709e81ef21722be30db5060":[5,0,2,22,0],
-"class_ogre_1_1_iterator_wrapper.html":[6,0,1,226],
-"class_ogre_1_1_iterator_wrapper.html":[7,0,0,226],
-"class_ogre_1_1_iterator_wrapper.html#a22c1c22fab97253a922a190d2ace205e":[6,0,1,226,2],
-"class_ogre_1_1_iterator_wrapper.html#a22c1c22fab97253a922a190d2ace205e":[7,0,0,226,2],
-"class_ogre_1_1_iterator_wrapper.html#a4eec47de73ce626e19d5c7321a5fcefe":[6,0,1,226,7],
-"class_ogre_1_1_iterator_wrapper.html#a4eec47de73ce626e19d5c7321a5fcefe":[7,0,0,226,7],
-"class_ogre_1_1_iterator_wrapper.html#a5955d5dac2bd4a84d0f7120d3fb2a2bc":[6,0,1,226,8],
-"class_ogre_1_1_iterator_wrapper.html#a5955d5dac2bd4a84d0f7120d3fb2a2bc":[7,0,0,226,8],
-"class_ogre_1_1_iterator_wrapper.html#a704ce78ef948a2730b4774b4ba0cea69":[6,0,1,226,3],
-"class_ogre_1_1_iterator_wrapper.html#a704ce78ef948a2730b4774b4ba0cea69":[7,0,0,226,3],
-"class_ogre_1_1_iterator_wrapper.html#a72bb580445cd26d668677e159b692d4f":[6,0,1,226,1],
-"class_ogre_1_1_iterator_wrapper.html#a72bb580445cd26d668677e159b692d4f":[7,0,0,226,1],
-"class_ogre_1_1_iterator_wrapper.html#a72df6843478e277b8dde180081156b98":[6,0,1,226,0],
-"class_ogre_1_1_iterator_wrapper.html#a72df6843478e277b8dde180081156b98":[7,0,0,226,0],
-"class_ogre_1_1_iterator_wrapper.html#a7d788cb5bce74b71aafeee0c13340f7c":[6,0,1,226,9],
-"class_ogre_1_1_iterator_wrapper.html#a7d788cb5bce74b71aafeee0c13340f7c":[7,0,0,226,9],
-"class_ogre_1_1_iterator_wrapper.html#aae5af61f58bb7e21b76f6b44088d5ea8":[6,0,1,226,4],
-"class_ogre_1_1_iterator_wrapper.html#aae5af61f58bb7e21b76f6b44088d5ea8":[7,0,0,226,4],
-"class_ogre_1_1_iterator_wrapper.html#aaf01f897bea391797dc2bb9fb8374a5f":[6,0,1,226,6],
-"class_ogre_1_1_iterator_wrapper.html#aaf01f897bea391797dc2bb9fb8374a5f":[7,0,0,226,6],
-"class_ogre_1_1_iterator_wrapper.html#abd1f3f1f5143828a6296347d5b0b9d04":[6,0,1,226,5],
-"class_ogre_1_1_iterator_wrapper.html#abd1f3f1f5143828a6296347d5b0b9d04":[7,0,0,226,5],
+"class_ogre_1_1_iterator_wrapper.html":[6,0,1,227],
+"class_ogre_1_1_iterator_wrapper.html":[7,0,0,227],
+"class_ogre_1_1_iterator_wrapper.html#a22c1c22fab97253a922a190d2ace205e":[6,0,1,227,2],
+"class_ogre_1_1_iterator_wrapper.html#a22c1c22fab97253a922a190d2ace205e":[7,0,0,227,2],
+"class_ogre_1_1_iterator_wrapper.html#a4eec47de73ce626e19d5c7321a5fcefe":[6,0,1,227,7],
+"class_ogre_1_1_iterator_wrapper.html#a4eec47de73ce626e19d5c7321a5fcefe":[7,0,0,227,7],
+"class_ogre_1_1_iterator_wrapper.html#a5955d5dac2bd4a84d0f7120d3fb2a2bc":[6,0,1,227,8],
+"class_ogre_1_1_iterator_wrapper.html#a5955d5dac2bd4a84d0f7120d3fb2a2bc":[7,0,0,227,8],
+"class_ogre_1_1_iterator_wrapper.html#a704ce78ef948a2730b4774b4ba0cea69":[6,0,1,227,3],
+"class_ogre_1_1_iterator_wrapper.html#a704ce78ef948a2730b4774b4ba0cea69":[7,0,0,227,3],
+"class_ogre_1_1_iterator_wrapper.html#a72bb580445cd26d668677e159b692d4f":[6,0,1,227,1],
+"class_ogre_1_1_iterator_wrapper.html#a72bb580445cd26d668677e159b692d4f":[7,0,0,227,1],
+"class_ogre_1_1_iterator_wrapper.html#a72df6843478e277b8dde180081156b98":[6,0,1,227,0],
+"class_ogre_1_1_iterator_wrapper.html#a72df6843478e277b8dde180081156b98":[7,0,0,227,0],
+"class_ogre_1_1_iterator_wrapper.html#a7d788cb5bce74b71aafeee0c13340f7c":[6,0,1,227,9],
+"class_ogre_1_1_iterator_wrapper.html#a7d788cb5bce74b71aafeee0c13340f7c":[7,0,0,227,9],
+"class_ogre_1_1_iterator_wrapper.html#aae5af61f58bb7e21b76f6b44088d5ea8":[6,0,1,227,4],
+"class_ogre_1_1_iterator_wrapper.html#aae5af61f58bb7e21b76f6b44088d5ea8":[7,0,0,227,4],
+"class_ogre_1_1_iterator_wrapper.html#aaf01f897bea391797dc2bb9fb8374a5f":[6,0,1,227,6],
+"class_ogre_1_1_iterator_wrapper.html#aaf01f897bea391797dc2bb9fb8374a5f":[7,0,0,227,6],
+"class_ogre_1_1_iterator_wrapper.html#abd1f3f1f5143828a6296347d5b0b9d04":[6,0,1,227,5],
+"class_ogre_1_1_iterator_wrapper.html#abd1f3f1f5143828a6296347d5b0b9d04":[7,0,0,227,5],
 "class_ogre_1_1_key_frame.html":[5,0,0,16],
 "class_ogre_1_1_key_frame.html#a2f8e964ccf18553eef80f93c26d0e7bc":[5,0,0,16,1],
 "class_ogre_1_1_key_frame.html#a6d31b620621fdeed1a3fc9f752498ad7":[5,0,0,16,0],
@@ -171,14 +196,14 @@ var NAVTREEINDEX18 =
 "class_ogre_1_1_linear_force_affector_1_1_cmd_force_vector.html":[5,2,10,12,1],
 "class_ogre_1_1_linear_force_affector_1_1_cmd_force_vector.html#a5f0c7f69f8fb52a61e0f77be7c2224d7":[5,2,10,12,1,1],
 "class_ogre_1_1_linear_force_affector_1_1_cmd_force_vector.html#add323c4f58deed328029f38537760fae":[5,2,10,12,1,0],
-"class_ogre_1_1_lod0_stripifier.html":[6,0,1,235],
-"class_ogre_1_1_lod0_stripifier.html":[7,0,0,235],
-"class_ogre_1_1_lod0_stripifier.html#a36470f9df4835807557d9a1b58c0e0b8":[6,0,1,235,3],
-"class_ogre_1_1_lod0_stripifier.html#a36470f9df4835807557d9a1b58c0e0b8":[7,0,0,235,3],
-"class_ogre_1_1_lod0_stripifier.html#a94f191280507c1253370ddca21113c87":[6,0,1,235,1],
-"class_ogre_1_1_lod0_stripifier.html#a94f191280507c1253370ddca21113c87":[7,0,0,235,1],
-"class_ogre_1_1_lod0_stripifier.html#aaf8b57b5395eed707f960a10a1856d1d":[6,0,1,235,2],
-"class_ogre_1_1_lod0_stripifier.html#aaf8b57b5395eed707f960a10a1856d1d":[7,0,0,235,2],
+"class_ogre_1_1_lod0_stripifier.html":[6,0,1,236],
+"class_ogre_1_1_lod0_stripifier.html":[7,0,0,236],
+"class_ogre_1_1_lod0_stripifier.html#a36470f9df4835807557d9a1b58c0e0b8":[6,0,1,236,3],
+"class_ogre_1_1_lod0_stripifier.html#a36470f9df4835807557d9a1b58c0e0b8":[7,0,0,236,3],
+"class_ogre_1_1_lod0_stripifier.html#a94f191280507c1253370ddca21113c87":[6,0,1,236,1],
+"class_ogre_1_1_lod0_stripifier.html#a94f191280507c1253370ddca21113c87":[7,0,0,236,1],
+"class_ogre_1_1_lod0_stripifier.html#aaf8b57b5395eed707f960a10a1856d1d":[6,0,1,236,2],
+"class_ogre_1_1_lod0_stripifier.html#aaf8b57b5395eed707f960a10a1856d1d":[7,0,0,236,2],
 "class_ogre_1_1_lod_collapse_cost.html":[5,1,2,0],
 "class_ogre_1_1_lod_collapse_cost.html#a0544405a072903833e93500006036743":[5,1,2,0,1],
 "class_ogre_1_1_lod_collapse_cost.html#a0abbea261fa39ad12d0e6aa458072aaf":[5,1,2,0,0],
@@ -189,65 +214,40 @@ var NAVTREEINDEX18 =
 "class_ogre_1_1_lod_collapse_cost.html#a76100f9a20fbe556fea79c9fb33edc82":[5,1,2,0,8],
 "class_ogre_1_1_lod_collapse_cost.html#a9bbdb780b79f29c37c205a3f05683437":[5,1,2,0,6],
 "class_ogre_1_1_lod_collapse_cost.html#ae76380b7497b62c7baafffe8a618a3d6":[5,1,2,0,3],
-"class_ogre_1_1_lod_collapse_cost_curvature.html":[6,0,1,237],
-"class_ogre_1_1_lod_collapse_cost_curvature.html":[7,0,0,237],
-"class_ogre_1_1_lod_collapse_cost_curvature.html#a9f9908954d4c9b1f39a333141d15441c":[6,0,1,237,0],
-"class_ogre_1_1_lod_collapse_cost_curvature.html#a9f9908954d4c9b1f39a333141d15441c":[7,0,0,237,0],
-"class_ogre_1_1_lod_collapse_cost_outside.html":[6,0,1,238],
-"class_ogre_1_1_lod_collapse_cost_outside.html":[7,0,0,238],
-"class_ogre_1_1_lod_collapse_cost_outside.html#a6a8adf615e71f822dda5d7183f271c34":[6,0,1,238,3],
-"class_ogre_1_1_lod_collapse_cost_outside.html#a6a8adf615e71f822dda5d7183f271c34":[7,0,0,238,3],
-"class_ogre_1_1_lod_collapse_cost_outside.html#aa5cef7538a33a82740003f63b3e9337c":[6,0,1,238,0],
-"class_ogre_1_1_lod_collapse_cost_outside.html#aa5cef7538a33a82740003f63b3e9337c":[7,0,0,238,0],
-"class_ogre_1_1_lod_collapse_cost_outside.html#ab2987b3470f541061d6b4a8825324b5a":[6,0,1,238,2],
-"class_ogre_1_1_lod_collapse_cost_outside.html#ab2987b3470f541061d6b4a8825324b5a":[7,0,0,238,2],
-"class_ogre_1_1_lod_collapse_cost_outside.html#af49fbc592c47e4b9521c03148bbbbbbf":[6,0,1,238,1],
-"class_ogre_1_1_lod_collapse_cost_outside.html#af49fbc592c47e4b9521c03148bbbbbbf":[7,0,0,238,1],
-"class_ogre_1_1_lod_collapse_cost_profiler.html":[6,0,1,239],
-"class_ogre_1_1_lod_collapse_cost_profiler.html":[7,0,0,239],
-"class_ogre_1_1_lod_collapse_cost_profiler.html#a54c2815544dadcfeacd1e79f2ce8ba6f":[6,0,1,239,0],
-"class_ogre_1_1_lod_collapse_cost_profiler.html#a54c2815544dadcfeacd1e79f2ce8ba6f":[7,0,0,239,0],
-"class_ogre_1_1_lod_collapse_cost_profiler.html#a7ca1ac32f2f5efd735204f732f15037d":[6,0,1,239,3],
-"class_ogre_1_1_lod_collapse_cost_profiler.html#a7ca1ac32f2f5efd735204f732f15037d":[7,0,0,239,3],
-"class_ogre_1_1_lod_collapse_cost_profiler.html#ab0100fde2b3953dd389fe578a413f4c9":[6,0,1,239,1],
-"class_ogre_1_1_lod_collapse_cost_profiler.html#ab0100fde2b3953dd389fe578a413f4c9":[7,0,0,239,1],
-"class_ogre_1_1_lod_collapse_cost_profiler.html#ae8a2d2cf140fa05e2132f8d8cfe76d2a":[6,0,1,239,2],
-"class_ogre_1_1_lod_collapse_cost_profiler.html#ae8a2d2cf140fa05e2132f8d8cfe76d2a":[7,0,0,239,2],
-"class_ogre_1_1_lod_collapse_cost_quadric.html":[6,0,1,240],
-"class_ogre_1_1_lod_collapse_cost_quadric.html":[7,0,0,240],
-"class_ogre_1_1_lod_collapse_cost_quadric.html#a36e8c2daebc2cb8013716485fc472fe0":[6,0,1,240,0],
-"class_ogre_1_1_lod_collapse_cost_quadric.html#a36e8c2daebc2cb8013716485fc472fe0":[7,0,0,240,0],
-"class_ogre_1_1_lod_collapse_cost_quadric.html#a5fd759d8f5be1763147fa547cc1c2223":[6,0,1,240,2],
-"class_ogre_1_1_lod_collapse_cost_quadric.html#a5fd759d8f5be1763147fa547cc1c2223":[7,0,0,240,2],
-"class_ogre_1_1_lod_collapse_cost_quadric.html#a6c5d7dbd0032ba9e5722ce7efa2a520e":[6,0,1,240,1],
-"class_ogre_1_1_lod_collapse_cost_quadric.html#a6c5d7dbd0032ba9e5722ce7efa2a520e":[7,0,0,240,1],
+"class_ogre_1_1_lod_collapse_cost_curvature.html":[6,0,1,238],
+"class_ogre_1_1_lod_collapse_cost_curvature.html":[7,0,0,238],
+"class_ogre_1_1_lod_collapse_cost_curvature.html#a9f9908954d4c9b1f39a333141d15441c":[6,0,1,238,0],
+"class_ogre_1_1_lod_collapse_cost_curvature.html#a9f9908954d4c9b1f39a333141d15441c":[7,0,0,238,0],
+"class_ogre_1_1_lod_collapse_cost_outside.html":[6,0,1,239],
+"class_ogre_1_1_lod_collapse_cost_outside.html":[7,0,0,239],
+"class_ogre_1_1_lod_collapse_cost_outside.html#a6a8adf615e71f822dda5d7183f271c34":[6,0,1,239,3],
+"class_ogre_1_1_lod_collapse_cost_outside.html#a6a8adf615e71f822dda5d7183f271c34":[7,0,0,239,3],
+"class_ogre_1_1_lod_collapse_cost_outside.html#aa5cef7538a33a82740003f63b3e9337c":[6,0,1,239,0],
+"class_ogre_1_1_lod_collapse_cost_outside.html#aa5cef7538a33a82740003f63b3e9337c":[7,0,0,239,0],
+"class_ogre_1_1_lod_collapse_cost_outside.html#ab2987b3470f541061d6b4a8825324b5a":[6,0,1,239,2],
+"class_ogre_1_1_lod_collapse_cost_outside.html#ab2987b3470f541061d6b4a8825324b5a":[7,0,0,239,2],
+"class_ogre_1_1_lod_collapse_cost_outside.html#af49fbc592c47e4b9521c03148bbbbbbf":[6,0,1,239,1],
+"class_ogre_1_1_lod_collapse_cost_outside.html#af49fbc592c47e4b9521c03148bbbbbbf":[7,0,0,239,1],
+"class_ogre_1_1_lod_collapse_cost_profiler.html":[6,0,1,240],
+"class_ogre_1_1_lod_collapse_cost_profiler.html":[7,0,0,240],
+"class_ogre_1_1_lod_collapse_cost_profiler.html#a54c2815544dadcfeacd1e79f2ce8ba6f":[6,0,1,240,0],
+"class_ogre_1_1_lod_collapse_cost_profiler.html#a54c2815544dadcfeacd1e79f2ce8ba6f":[7,0,0,240,0],
+"class_ogre_1_1_lod_collapse_cost_profiler.html#a7ca1ac32f2f5efd735204f732f15037d":[6,0,1,240,3],
+"class_ogre_1_1_lod_collapse_cost_profiler.html#a7ca1ac32f2f5efd735204f732f15037d":[7,0,0,240,3],
+"class_ogre_1_1_lod_collapse_cost_profiler.html#ab0100fde2b3953dd389fe578a413f4c9":[6,0,1,240,1],
+"class_ogre_1_1_lod_collapse_cost_profiler.html#ab0100fde2b3953dd389fe578a413f4c9":[7,0,0,240,1],
+"class_ogre_1_1_lod_collapse_cost_profiler.html#ae8a2d2cf140fa05e2132f8d8cfe76d2a":[6,0,1,240,2],
+"class_ogre_1_1_lod_collapse_cost_profiler.html#ae8a2d2cf140fa05e2132f8d8cfe76d2a":[7,0,0,240,2],
+"class_ogre_1_1_lod_collapse_cost_quadric.html":[6,0,1,241],
+"class_ogre_1_1_lod_collapse_cost_quadric.html":[7,0,0,241],
+"class_ogre_1_1_lod_collapse_cost_quadric.html#a36e8c2daebc2cb8013716485fc472fe0":[6,0,1,241,0],
+"class_ogre_1_1_lod_collapse_cost_quadric.html#a36e8c2daebc2cb8013716485fc472fe0":[7,0,0,241,0],
+"class_ogre_1_1_lod_collapse_cost_quadric.html#a5fd759d8f5be1763147fa547cc1c2223":[6,0,1,241,2],
+"class_ogre_1_1_lod_collapse_cost_quadric.html#a5fd759d8f5be1763147fa547cc1c2223":[7,0,0,241,2],
+"class_ogre_1_1_lod_collapse_cost_quadric.html#a6c5d7dbd0032ba9e5722ce7efa2a520e":[6,0,1,241,1],
+"class_ogre_1_1_lod_collapse_cost_quadric.html#a6c5d7dbd0032ba9e5722ce7efa2a520e":[7,0,0,241,1],
 "class_ogre_1_1_lod_collapser.html":[5,1,2,1],
 "class_ogre_1_1_lod_collapser.html#a51d851d50ebcee4f77cff26f500ccce7":[5,1,2,1,0],
 "class_ogre_1_1_lod_collapser.html#a8a3dc7a3ba0d2777dd8656429540e8cd":[5,1,2,1,3],
-"class_ogre_1_1_lod_collapser.html#ab2c58971bcc0ecac574ac377b56f3c30":[5,1,2,1,2],
-"class_ogre_1_1_lod_collapser.html#ad292c42636402fafb2eb193264ca67a4":[5,1,2,1,1],
-"class_ogre_1_1_lod_config_serializer.html":[6,0,1,243],
-"class_ogre_1_1_lod_config_serializer.html":[7,0,0,243],
-"class_ogre_1_1_lod_config_serializer.html#a0f12f84184b32b0d2716667d533e3d1c":[6,0,1,243,2],
-"class_ogre_1_1_lod_config_serializer.html#a0f12f84184b32b0d2716667d533e3d1c":[7,0,0,243,2],
-"class_ogre_1_1_lod_config_serializer.html#a72f631aab3f43aa1ccb441cbbd8cd63c":[6,0,1,243,4],
-"class_ogre_1_1_lod_config_serializer.html#a72f631aab3f43aa1ccb441cbbd8cd63c":[7,0,0,243,4],
-"class_ogre_1_1_lod_config_serializer.html#a90888570c5ea11c98e7ea8cfdab52fae":[6,0,1,243,0],
-"class_ogre_1_1_lod_config_serializer.html#a90888570c5ea11c98e7ea8cfdab52fae":[7,0,0,243,0],
-"class_ogre_1_1_lod_config_serializer.html#ab0d2cd1a61870f28aabbf0bd9d61b350":[6,0,1,243,1],
-"class_ogre_1_1_lod_config_serializer.html#ab0d2cd1a61870f28aabbf0bd9d61b350":[7,0,0,243,1],
-"class_ogre_1_1_lod_config_serializer.html#af4e0f6e5ceae25f6fdb735cec0b51069":[6,0,1,243,3],
-"class_ogre_1_1_lod_config_serializer.html#af4e0f6e5ceae25f6fdb735cec0b51069":[7,0,0,243,3],
-"class_ogre_1_1_lod_input_provider.html":[6,0,1,245],
-"class_ogre_1_1_lod_input_provider.html":[7,0,0,245],
-"class_ogre_1_1_lod_input_provider.html#a1b5411e968e40e5e645871eaeba90270":[6,0,1,245,1],
-"class_ogre_1_1_lod_input_provider.html#a1b5411e968e40e5e645871eaeba90270":[7,0,0,245,1],
-"class_ogre_1_1_lod_input_provider.html#a551a6f7b7d3e27fccea16452485f5167":[6,0,1,245,0],
-"class_ogre_1_1_lod_input_provider.html#a551a6f7b7d3e27fccea16452485f5167":[7,0,0,245,0],
-"class_ogre_1_1_lod_listener.html":[5,0,4,6],
-"class_ogre_1_1_lod_listener.html#a2690efbb582ca532ad79f4e682730ecd":[5,0,4,6,5],
-"class_ogre_1_1_lod_listener.html#a437b5f300e0f3c38fa581d87e8643784":[5,0,4,6,0],
-"class_ogre_1_1_lod_listener.html#a80c7d710fa6e8119a3294f3f8fd80e46":[5,0,4,6,2],
-"class_ogre_1_1_lod_listener.html#a812c2bf8014cda9f2ef8fa115d4be416":[5,0,4,6,3],
-"class_ogre_1_1_lod_listener.html#a90c2e6ca102b8b43fa2819fc752caf5a":[5,0,4,6,4]
+"class_ogre_1_1_lod_collapser.html#ab2c58971bcc0ecac574ac377b56f3c30":[5,1,2,1,2]
 };
