@@ -1,32 +1,5 @@
 var NAVTREEINDEX2 =
 {
-"_ogre_page_connection_8h.html":[8,0,0,4,0,3],
-"_ogre_page_content_8h.html":[8,0,0,4,0,4],
-"_ogre_page_content_collection_8h.html":[8,0,0,4,0,5],
-"_ogre_page_content_collection_factory_8h.html":[8,0,0,4,0,6],
-"_ogre_page_content_factory_8h.html":[8,0,0,4,0,7],
-"_ogre_page_file_formats_8h.html":[8,0,0,4,0,10],
-"_ogre_page_manager_8h.html":[8,0,0,4,0,11],
-"_ogre_page_strategy_8h.html":[8,0,0,4,0,12],
-"_ogre_paged_world_8h.html":[8,0,0,4,0,8],
-"_ogre_paged_world_section_8h.html":[8,0,0,4,0,9],
-"_ogre_paging_8h.html":[8,0,0,4,0,13],
-"_ogre_paging_prerequisites_8h.html":[8,0,0,4,0,14],
-"_ogre_paging_prerequisites_8h.html#a12507ffbcb05d7b7af41403ff7db8a5c":[8,0,0,4,0,14,0],
-"_ogre_paging_prerequisites_8h.html#a5126a9c9fbccbfe4c78070263098acb2":[8,0,0,4,0,14,2],
-"_ogre_paging_prerequisites_8h.html#a660664a63929ba9f460ae738a3ed59eb":[8,0,0,4,0,14,1],
-"_ogre_panel_overlay_element_8h.html":[8,0,0,3,0,11],
-"_ogre_particle_8h.html":[8,0,1,0,111],
-"_ogre_particle_affector_8h.html":[8,0,1,0,112],
-"_ogre_particle_affector_factory_8h.html":[8,0,1,0,113],
-"_ogre_particle_emitter_8h.html":[8,0,1,0,114],
-"_ogre_particle_emitter_factory_8h.html":[8,0,1,0,115],
-"_ogre_particle_f_x_plugin_8h.html":[8,0,2,9,0,12],
-"_ogre_particle_system_8h.html":[8,0,1,0,116],
-"_ogre_particle_system_manager_8h.html":[8,0,1,0,117],
-"_ogre_particle_system_renderer_8h.html":[8,0,1,0,118],
-"_ogre_pass_8h.html":[8,0,1,0,119],
-"_ogre_patch_mesh_8h.html":[8,0,1,0,120],
 "_ogre_patch_surface_8h.html":[8,0,1,0,121],
 "_ogre_pixel_count_lod_strategy_8h.html":[8,0,1,0,122],
 "_ogre_pixel_format_8h.html":[8,0,1,0,123],
@@ -36,29 +9,21 @@ var NAVTREEINDEX2 =
 "_ogre_platform_8h.html#a03ad9692ca81e2302d7048c9d7695415":[8,0,1,0,126,15],
 "_ogre_platform_8h.html#a077f6bc75ffd397f81a56ec2cd2838c3":[8,0,1,0,126,11],
 "_ogre_platform_8h.html#a11162eebee0099930c48076229cc6f04":[8,0,1,0,126,24],
-"_ogre_platform_8h.html#a135bdde033ee93f327917c6ff578d46c":[8,0,1,0,126,40],
 "_ogre_platform_8h.html#a1e1b3451f5070fe036ad603e9f3c4fa9":[8,0,1,0,126,9],
-"_ogre_platform_8h.html#a2a820cf8746c0f12999d2416c767f55d":[8,0,1,0,126,39],
 "_ogre_platform_8h.html#a30f03b7a029b1b1303e8f816b68c3368":[8,0,1,0,126,29],
 "_ogre_platform_8h.html#a338389706b17fb84162ebfa9a4c2195a":[8,0,1,0,126,13],
-"_ogre_platform_8h.html#a355345c182bde9095610b63a9fd69376":[8,0,1,0,126,43],
 "_ogre_platform_8h.html#a37b62784316fecdf49524d6492b2f54e":[8,0,1,0,126,12],
-"_ogre_platform_8h.html#a400c2fa3db9a7c0c34de0635b01ab3b6":[8,0,1,0,126,45],
 "_ogre_platform_8h.html#a4499f0589d3e524e29fc9016a90f38d3":[8,0,1,0,126,3],
 "_ogre_platform_8h.html#a4de9497f1c50d8052061e4870d5cdb42":[8,0,1,0,126,27],
 "_ogre_platform_8h.html#a5e538aea93661c323e7c86a88514ee48":[8,0,1,0,126,5],
 "_ogre_platform_8h.html#a600c868168881add7117060af46eb666":[8,0,1,0,126,10],
-"_ogre_platform_8h.html#a60635457b0b97495b34737baa4fb3f64":[8,0,1,0,126,41],
-"_ogre_platform_8h.html#a6519f6582ca047f2c0ae0bb056bb9134":[8,0,1,0,126,44],
 "_ogre_platform_8h.html#a696b7f8c06236aa9ce8b16569fc13985":[8,0,1,0,126,4],
 "_ogre_platform_8h.html#a6a94af2b19015f8d92898251ba51b894":[8,0,1,0,126,7],
 "_ogre_platform_8h.html#a6cbacd9965b6b575077a96dbf96cb23c":[8,0,1,0,126,22],
-"_ogre_platform_8h.html#a6e6e978d04d35e4351576d3f6f3e2364":[8,0,1,0,126,42],
 "_ogre_platform_8h.html#a719f8e35fd54bc7946246292a772e5cc":[8,0,1,0,126,19],
 "_ogre_platform_8h.html#a813680a39abb8fa11722d6918aa73238":[8,0,1,0,126,6],
 "_ogre_platform_8h.html#a82944247fe1c48b106e3294d05dcb307":[8,0,1,0,126,21],
 "_ogre_platform_8h.html#a87dfb3e6fd0e097cfc22bcf1a936b609":[8,0,1,0,126,17],
-"_ogre_platform_8h.html#a8f2f90fa4c83c075e3fae75456ae5ded":[8,0,1,0,126,38],
 "_ogre_platform_8h.html#a9201035492049999bc82d4baa25ee090":[8,0,1,0,126,31],
 "_ogre_platform_8h.html#a922bb8a4073c0e5b0b48acf831b90a64":[8,0,1,0,126,36],
 "_ogre_platform_8h.html#a9841c02eaa22e4d4d5067cd6cfa9b38f":[8,0,1,0,126,35],
@@ -92,80 +57,13 @@ var NAVTREEINDEX2 =
 "_ogre_pose_8h.html":[8,0,1,0,130],
 "_ogre_predefined_controllers_8h.html":[8,0,1,0,131],
 "_ogre_prerequisites_8h.html":[8,0,1,0,132],
-"_ogre_prerequisites_8h.html#a07f1f7c1d84d58c9beae02e1ebb945e4":[8,0,1,0,132,8],
-"_ogre_prerequisites_8h.html#a092f626940ed7d6e92b95db25c0be892":[8,0,1,0,132,68],
-"_ogre_prerequisites_8h.html#a0cbbbb116f181c7ef9031b25ca3d2b92":[8,0,1,0,132,71],
-"_ogre_prerequisites_8h.html#a139829f6abc3581ec63563543ebfff15":[8,0,1,0,132,43],
-"_ogre_prerequisites_8h.html#a17ac50f71e23ddbc3bb8e34c6b4007da":[8,0,1,0,132,18],
-"_ogre_prerequisites_8h.html#a1c816d34e4e50e5b65e60ecc9451f94f":[8,0,1,0,132,26],
-"_ogre_prerequisites_8h.html#a2292a2b9e147e50617d24746070bbc9f":[8,0,1,0,132,30],
-"_ogre_prerequisites_8h.html#a23079674b2abb8481c373860bca2c22a":[8,0,1,0,132,36],
-"_ogre_prerequisites_8h.html#a272ffe59e216908cce70c5fd11eaa7ff":[8,0,1,0,132,24],
-"_ogre_prerequisites_8h.html#a29417692403e4e51f1c892c643ff4165":[8,0,1,0,132,34],
-"_ogre_prerequisites_8h.html#a2c452533979dfdf73a296288e94d920b":[8,0,1,0,132,28],
-"_ogre_prerequisites_8h.html#a31556cf3832442060ab4b33378d8f09d":[8,0,1,0,132,59],
-"_ogre_prerequisites_8h.html#a3287ad729460d74b51f1100612dd50b9":[8,0,1,0,132,64],
 "_ogre_prerequisites_8h.html#a3f631403da0a255c201870bfd068f8c5":[8,0,1,0,132,4],
-"_ogre_prerequisites_8h.html#a4304981347643708ee9a7ba8884e5758":[8,0,1,0,132,11],
-"_ogre_prerequisites_8h.html#a465b857a17d8ebbbbef49e4ecccd5505":[8,0,1,0,132,58],
-"_ogre_prerequisites_8h.html#a4697cc0c72aef3b488c7e058adf734ed":[8,0,1,0,132,42],
-"_ogre_prerequisites_8h.html#a4bbf05af668b0deefaf7b0c0f172d45b":[8,0,1,0,132,31],
-"_ogre_prerequisites_8h.html#a4ea60aa36ac918eee430bd614be9d018":[8,0,1,0,132,44],
-"_ogre_prerequisites_8h.html#a54481042551b3b7ca50133fb287ef89f":[8,0,1,0,132,47],
-"_ogre_prerequisites_8h.html#a57ef769e80226674c3971ce58b58c91d":[8,0,1,0,132,37],
-"_ogre_prerequisites_8h.html#a59d8863c4ce62021e0ec3aebda232422":[8,0,1,0,132,60],
-"_ogre_prerequisites_8h.html#a5ac5c5141120da7735f8f151b29a1d47":[8,0,1,0,132,14],
-"_ogre_prerequisites_8h.html#a5c4c0c56ea9f824c49e331f6fad33ddb":[8,0,1,0,132,39],
-"_ogre_prerequisites_8h.html#a5e0882c3b9f7ca32a795f98cf034e428":[8,0,1,0,132,25],
-"_ogre_prerequisites_8h.html#a6d84a8d0d69f1c49ad30637016bccc80":[8,0,1,0,132,66],
 "_ogre_prerequisites_8h.html#a6ffe9a4cd255c7d579297fb340439e7f":[8,0,1,0,132,0],
-"_ogre_prerequisites_8h.html#a70291a99caf16ec1ce14ce4d03ed4f07":[8,0,1,0,132,63],
-"_ogre_prerequisites_8h.html#a70fa907104459ee375cbc6e0f43eeb74":[8,0,1,0,132,62],
-"_ogre_prerequisites_8h.html#a72f7c7ed96713df7ed929bc19c8f2f1b":[8,0,1,0,132,70],
-"_ogre_prerequisites_8h.html#a739a289a4d5235f5f509a1795f5ffd5b":[8,0,1,0,132,23],
-"_ogre_prerequisites_8h.html#a793439fa964ffad99ec9ba1f2e4e9f91":[8,0,1,0,132,69],
-"_ogre_prerequisites_8h.html#a7e0bc377ed62eee5daa8987e28b2ce93":[8,0,1,0,132,46],
-"_ogre_prerequisites_8h.html#a8542e5da4c0e0bda0d0bf5745329ea88":[8,0,1,0,132,17],
-"_ogre_prerequisites_8h.html#a86f62030407fdeffab537ac7e98e6ec3":[8,0,1,0,132,40],
-"_ogre_prerequisites_8h.html#a8a2a961b4205aacff9c01e81e08d7781":[8,0,1,0,132,27],
-"_ogre_prerequisites_8h.html#a9140aec81d4c373ea427d72ca046d845":[8,0,1,0,132,33],
-"_ogre_prerequisites_8h.html#a9297e4ba862a7506f0c1a62b26b59a24":[8,0,1,0,132,61],
-"_ogre_prerequisites_8h.html#a95928aac7888704fcccc644317834fa3":[8,0,1,0,132,48],
-"_ogre_prerequisites_8h.html#a99fb0d12485f50c22c3a63a4e060fcd7":[8,0,1,0,132,73],
-"_ogre_prerequisites_8h.html#a9aac4c604e6e064ee7636c80ccfc99ed":[8,0,1,0,132,50],
-"_ogre_prerequisites_8h.html#a9c21c25fe94d377e08de68d4502c90fd":[8,0,1,0,132,72],
-"_ogre_prerequisites_8h.html#aa381890787803da43b614dee8d9c8994":[8,0,1,0,132,45],
-"_ogre_prerequisites_8h.html#aa3a7b6dfb905e6572d62f0dfa3d4274d":[8,0,1,0,132,7],
-"_ogre_prerequisites_8h.html#aa45059cb355996532a0ca37f0be9bc98":[8,0,1,0,132,19],
-"_ogre_prerequisites_8h.html#aaaaf710eea1e4365b2db4316b2fe133b":[8,0,1,0,132,52],
-"_ogre_prerequisites_8h.html#aab7b2d2585219692cd912d3b497802d5":[8,0,1,0,132,49],
-"_ogre_prerequisites_8h.html#aad08c34b6cdc67860f9443039c1df9f4":[8,0,1,0,132,41],
 "_ogre_prerequisites_8h.html#aadfaee1c10a53055c49ad591cbbb9e38":[8,0,1,0,132,3],
-"_ogre_prerequisites_8h.html#aaeea8e914de95954f4ccbc680e633ac4":[8,0,1,0,132,65],
-"_ogre_prerequisites_8h.html#aaf6cdc855bf9ae5edbf48a7e7dcb27f8":[8,0,1,0,132,54],
-"_ogre_prerequisites_8h.html#ab68581d765ec12b3eb68b9270c5113f5":[8,0,1,0,132,16],
-"_ogre_prerequisites_8h.html#ab6e842a18caf062ed73a5d3badd0dd4c":[8,0,1,0,132,10],
-"_ogre_prerequisites_8h.html#ab76650f27b9b671a6ad6ba0e466c65aa":[8,0,1,0,132,29],
 "_ogre_prerequisites_8h.html#ab8532905efe1d3a9da82938c2ccf3741":[8,0,1,0,132,1],
-"_ogre_prerequisites_8h.html#ab8bbcab42b67b21ae639dd3ef57c2932":[8,0,1,0,132,57],
-"_ogre_prerequisites_8h.html#abce10692dd9c7b0e2b8033a7476c2358":[8,0,1,0,132,15],
-"_ogre_prerequisites_8h.html#ac6dc520d867be5f194779cc09f54b64c":[8,0,1,0,132,12],
-"_ogre_prerequisites_8h.html#ac94fc4008c1165dea017263fee56b273":[8,0,1,0,132,20],
-"_ogre_prerequisites_8h.html#acaa9a8f223043079fdd7aae2f064efc7":[8,0,1,0,132,35],
-"_ogre_prerequisites_8h.html#ad301aa15d0d8e93db33c91b813a33dc0":[8,0,1,0,132,51],
-"_ogre_prerequisites_8h.html#ad77c78fa5a8b5e62550f970a8905c509":[8,0,1,0,132,13],
 "_ogre_prerequisites_8h.html#adacb0b9741bc9e705bc271031d379aa5":[8,0,1,0,132,5],
 "_ogre_prerequisites_8h.html#adad9237308cc716c4b11a8f7a6b5669f":[8,0,1,0,132,6],
-"_ogre_prerequisites_8h.html#ae2a8e4debf1ea6d6cc2b6795e3174f38":[8,0,1,0,132,32],
-"_ogre_prerequisites_8h.html#aec93725f3ea0bb47424b11e401550e4a":[8,0,1,0,132,56],
-"_ogre_prerequisites_8h.html#aecf82a286f08cdf003677d472d33989b":[8,0,1,0,132,22],
 "_ogre_prerequisites_8h.html#aedf23cd1e0d0cca2268388ba1d64ba3d":[8,0,1,0,132,2],
-"_ogre_prerequisites_8h.html#aee06b1224b6eb1303888d8241d5c16ec":[8,0,1,0,132,21],
-"_ogre_prerequisites_8h.html#af851e71354d841df7138f9877c6f5931":[8,0,1,0,132,9],
-"_ogre_prerequisites_8h.html#af8656a2c0ef06642f70c4b3745ee80a2":[8,0,1,0,132,38],
-"_ogre_prerequisites_8h.html#af9b3423b7c29049c4cfa637d4a41a28f":[8,0,1,0,132,55],
-"_ogre_prerequisites_8h.html#afbd510273476ae6d23a3339542c3c63d":[8,0,1,0,132,67],
-"_ogre_prerequisites_8h.html#aff0eec6634048fd4d65b785264243e6c":[8,0,1,0,132,53],
 "_ogre_profiler_8h.html":[8,0,1,0,133],
 "_ogre_profiler_8h.html#a1654899e6cfdec9f0972a45f3fa3fee7":[8,0,1,0,133,0],
 "_ogre_profiler_8h.html#a292ec22b5d851ef26fa9d7685c18b1f5":[8,0,1,0,133,2],
@@ -249,5 +147,107 @@ var NAVTREEINDEX2 =
 "_ogre_quake3_types_8h.html#aa8af328b38d654b454a308a6360ea650":[8,0,2,1,0,8,58],
 "_ogre_quake3_types_8h.html#aaf426e12cf540dd631826280da07c91a":[8,0,2,1,0,8,22],
 "_ogre_quake3_types_8h.html#ab1292b8580779e023357a037c3eb0fe1":[8,0,2,1,0,8,31],
-"_ogre_quake3_types_8h.html#ab13a5a0938c6d5f3a005ef3fdf461781":[8,0,2,1,0,8,64]
+"_ogre_quake3_types_8h.html#ab13a5a0938c6d5f3a005ef3fdf461781":[8,0,2,1,0,8,64],
+"_ogre_quake3_types_8h.html#ab5dbbb0f6a60af03e34dc0267ca03d7a":[8,0,2,1,0,8,39],
+"_ogre_quake3_types_8h.html#ab7e524cacc3a7727252f60a336b9b698":[8,0,2,1,0,8,75],
+"_ogre_quake3_types_8h.html#ab7e524cacc3a7727252f60a336b9b698a2ed730a9a637fad9c6cc760c8c96a301":[8,0,2,1,0,8,75,0],
+"_ogre_quake3_types_8h.html#ab7e524cacc3a7727252f60a336b9b698a40f4feee49ca95fab29f3430f95095bb":[8,0,2,1,0,8,75,2],
+"_ogre_quake3_types_8h.html#ab7e524cacc3a7727252f60a336b9b698a6ba8e3de748f73894bd29bcac634bd03":[8,0,2,1,0,8,75,1],
+"_ogre_quake3_types_8h.html#ab88f26adb1bcb93cbe1a6ab3201761d0":[8,0,2,1,0,8,23],
+"_ogre_quake3_types_8h.html#abb78544f8f85bde2bc66161df474b515":[8,0,2,1,0,8,60],
+"_ogre_quake3_types_8h.html#ac1437c4ffc959deb4c6d0ce6a0a2d290":[8,0,2,1,0,8,53],
+"_ogre_quake3_types_8h.html#ac22dddfabcab78fe79e258675f088a52":[8,0,2,1,0,8,41],
+"_ogre_quake3_types_8h.html#ac74aa6092339c35717e12dc058040a01":[8,0,2,1,0,8,34],
+"_ogre_quake3_types_8h.html#ade922e5f0b8f2b02147858c2b6d579cc":[8,0,2,1,0,8,35],
+"_ogre_quake3_types_8h.html#ae1c24fce15b80f0105aa1af131551924":[8,0,2,1,0,8,50],
+"_ogre_quake3_types_8h.html#ae4cc02d091eaf4c2d8d84ae8f09c0d37":[8,0,2,1,0,8,54],
+"_ogre_quake3_types_8h.html#af48c7f470ac558b368fce32c69cda326":[8,0,2,1,0,8,52],
+"_ogre_quake3_types_8h.html#af5ff11a5dcac369db7c9eacfb26158fa":[8,0,2,1,0,8,27],
+"_ogre_quake3_types_8h.html#af966799e3c68d3961682f6065aef3c23":[8,0,2,1,0,8,56],
+"_ogre_quaternion_8h.html":[8,0,1,0,134],
+"_ogre_r_t_shader_system_8h.html":[8,0,0,7,0,0],
+"_ogre_ray_8h.html":[8,0,1,0,135],
+"_ogre_rectangle2_d_8h.html":[8,0,1,0,136],
+"_ogre_render_object_listener_8h.html":[8,0,1,0,138],
+"_ogre_render_operation_8h.html":[8,0,1,0,139],
+"_ogre_render_queue_8h.html":[8,0,1,0,140],
+"_ogre_render_queue_listener_8h.html":[8,0,1,0,141],
+"_ogre_render_queue_sorting_grouping_8h.html":[8,0,1,0,142],
+"_ogre_render_system_8h.html":[8,0,1,0,143],
+"_ogre_render_system_capabilities_8h.html":[8,0,1,0,144],
+"_ogre_render_system_capabilities_8h.html#a1f2980065f3c74646d1c1710f55f3a22":[8,0,1,0,144,0],
+"_ogre_render_system_capabilities_8h.html#a758eb6cb9e283950039f2ef49b551151":[8,0,1,0,144,1],
+"_ogre_render_system_capabilities_8h.html#ab1061abcf1bf33c9f55c9d1dc80af110":[8,0,1,0,144,2],
+"_ogre_render_system_capabilities_8h.html#aed8646724df28fe574c22d9ac38d0743":[8,0,1,0,144,3],
+"_ogre_render_system_capabilities_manager_8h.html":[8,0,1,0,145],
+"_ogre_render_system_capabilities_serializer_8h.html":[8,0,1,0,146],
+"_ogre_render_target_8h.html":[8,0,1,0,147],
+"_ogre_render_target_8h.html#a867dc8bc833f9fff548c50dede22555d":[8,0,1,0,147,3],
+"_ogre_render_target_8h.html#af5bb0dae52b827634ede1f5aa3cb5638":[8,0,1,0,147,1],
+"_ogre_render_target_8h.html#afe22b8a3b08c5c1dfb03425997a043bc":[8,0,1,0,147,2],
+"_ogre_render_target_listener_8h.html":[8,0,1,0,148],
+"_ogre_render_texture_8h.html":[8,0,1,0,149],
+"_ogre_render_to_vertex_buffer_8h.html":[8,0,1,0,150],
+"_ogre_render_window_8h.html":[8,0,1,0,151],
+"_ogre_renderable_8h.html":[8,0,1,0,137],
+"_ogre_resource_8h.html":[8,0,1,0,152],
+"_ogre_resource_background_queue_8h.html":[8,0,1,0,153],
+"_ogre_resource_group_manager_8h.html":[8,0,1,0,154],
+"_ogre_resource_group_manager_8h.html#a7c22d2306a6f45d337466b9314f61a15":[8,0,1,0,154,2],
+"_ogre_resource_manager_8h.html":[8,0,1,0,155],
+"_ogre_ribbon_trail_8h.html":[8,0,1,0,156],
+"_ogre_ring_emitter_8h.html":[8,0,2,9,0,14],
+"_ogre_root_8h.html":[8,0,1,0,157],
+"_ogre_rotation_affector_8h.html":[8,0,2,9,0,15],
+"_ogre_rotational_spline_8h.html":[8,0,1,0,158],
+"_ogre_rs_image_codec_8h.html":[8,0,2,11,0,0],
+"_ogre_s_g_technique_resolver_listener_8h.html":[8,0,0,0,0,8],
+"_ogre_s_t_b_i_codec_8h.html":[8,0,2,12,0,0],
+"_ogre_scale_affector_8h.html":[8,0,2,9,0,16],
+"_ogre_scene_manager_8h.html":[8,0,1,0,159],
+"_ogre_scene_node_8h.html":[8,0,1,0,160],
+"_ogre_scene_query_8h.html":[8,0,1,0,161],
+"_ogre_script_compiler_8h.html":[8,0,1,0,162],
+"_ogre_script_loader_8h.html":[8,0,1,0,163],
+"_ogre_script_translator_8h.html":[8,0,1,0,164],
+"_ogre_segment_8h.html":[8,0,2,10,1,15],
+"_ogre_serializer_8h.html":[8,0,1,0,165],
+"_ogre_shader_ex_hardware_skinning_8h.html":[8,0,0,7,0,1],
+"_ogre_shader_ex_layered_blending_8h.html":[8,0,0,7,0,2],
+"_ogre_shader_f_f_p_render_state_8h.html":[8,0,0,7,0,3],
+"_ogre_shader_f_f_p_texturing_8h.html":[8,0,0,7,0,4],
+"_ogre_shader_function_8h.html":[8,0,0,7,0,5],
+"_ogre_shader_function_atom_8h.html":[8,0,0,7,0,6],
+"_ogre_shader_generator_8h.html":[8,0,0,7,0,7],
+"_ogre_shader_parameter_8h.html":[8,0,0,7,0,8],
+"_ogre_shader_prerequisites_8h.html":[8,0,0,7,0,9],
+"_ogre_shader_program_8h.html":[8,0,0,7,0,10],
+"_ogre_shader_program_manager_8h.html":[8,0,0,7,0,11],
+"_ogre_shader_program_set_8h.html":[8,0,0,7,0,12],
+"_ogre_shader_program_writer_8h.html":[8,0,0,7,0,13],
+"_ogre_shader_program_writer_manager_8h.html":[8,0,0,7,0,14],
+"_ogre_shader_render_state_8h.html":[8,0,0,7,0,15],
+"_ogre_shader_script_translator_8h.html":[8,0,0,7,0,16],
+"_ogre_shader_sub_render_state_8h.html":[8,0,0,7,0,17],
+"_ogre_shadow_camera_setup_8h.html":[8,0,1,0,166],
+"_ogre_shadow_camera_setup_focused_8h.html":[8,0,1,0,167],
+"_ogre_shadow_camera_setup_li_s_p_s_m_8h.html":[8,0,1,0,168],
+"_ogre_shadow_camera_setup_p_s_s_m_8h.html":[8,0,1,0,170],
+"_ogre_shadow_camera_setup_plane_optimal_8h.html":[8,0,1,0,169],
+"_ogre_shadow_caster_8h.html":[8,0,1,0,171],
+"_ogre_shared_ptr_8h.html":[8,0,1,0,172],
+"_ogre_simple_page_content_collection_8h.html":[8,0,0,4,0,15],
+"_ogre_simple_renderable_8h.html":[8,0,1,0,173],
+"_ogre_simple_spline_8h.html":[8,0,1,0,174],
+"_ogre_singleton_8h.html":[8,0,1,0,175],
+"_ogre_skeleton_8h.html":[8,0,1,0,176],
+"_ogre_skeleton_file_format_8h.html":[8,0,1,0,177],
+"_ogre_skeleton_instance_8h.html":[8,0,1,0,178],
+"_ogre_skeleton_manager_8h.html":[8,0,1,0,179],
+"_ogre_skeleton_serializer_8h.html":[8,0,1,0,180],
+"_ogre_small_vector_8h.html":[8,0,0,2,0,16],
+"_ogre_sphere_8h.html":[8,0,1,0,181],
+"_ogre_static_face_group_8h.html":[8,0,2,1,0,9],
+"_ogre_static_geometry_8h.html":[8,0,1,0,182],
+"_ogre_static_plugin_loader_8h.html":[8,0,0,0,0,9]
 };
