@@ -1,5 +1,29 @@
 var NAVTREEINDEX31 =
 {
+"class_ogre_1_1_property_def.html#ab66019ead72453626dde1c5529392e79":[5,1,5,2,11],
+"class_ogre_1_1_property_def.html#ac8d97b00ddd7991fd1c6d844fcea22b7":[5,1,5,2,7],
+"class_ogre_1_1_property_def.html#ad7e4b21a152c6f6657ce02a210b30b58":[5,1,5,2,10],
+"class_ogre_1_1_property_def.html#aec84b71d290c29cc9cfe7fdc614739a6":[5,1,5,2,2],
+"class_ogre_1_1_property_def.html#aee5018eebdb2bac0a74b16b983547fdb":[5,1,5,2,9],
+"class_ogre_1_1_property_def.html#af1f43d6fa9c867fbbac7c847c2331a4a":[5,1,5,2,5],
+"class_ogre_1_1_property_def.html#af6521053952a4e85d7a83fd1d8024b3d":[5,1,5,2,1],
+"class_ogre_1_1_property_set.html":[5,1,5,3],
+"class_ogre_1_1_property_set.html#a1802e0952c27d9acb3c3f25dfd4354e7":[5,1,5,3,8],
+"class_ogre_1_1_property_set.html#a1c51ce88cc61051d8dfa0457a0798d3f":[5,1,5,3,9],
+"class_ogre_1_1_property_set.html#a64e083b8ec8f2b3a3d765a19087c27a8":[5,1,5,3,6],
+"class_ogre_1_1_property_set.html#a6a96a84c9d133c98681f860c7d6565b0":[5,1,5,3,3],
+"class_ogre_1_1_property_set.html#a7784c0eb721ab2ef8a638af867826621":[5,1,5,3,0],
+"class_ogre_1_1_property_set.html#a7dd1b0cfb09db83e1c4841136ff7f908":[5,1,5,3,11],
+"class_ogre_1_1_property_set.html#a95cb8be54dee5698a4918dd26366b954":[5,1,5,3,1],
+"class_ogre_1_1_property_set.html#aa1890e8ea2cd4d2006bba05deb780d3d":[5,1,5,3,2],
+"class_ogre_1_1_property_set.html#abc8856372f44e367091ce920aabf35ae":[5,1,5,3,4],
+"class_ogre_1_1_property_set.html#ac5bbedd1543d61b98f23a102ddb3bc6a":[5,1,5,3,10],
+"class_ogre_1_1_property_set.html#ad79427f1e8b943f32becdc9530f84f81":[5,1,5,3,7],
+"class_ogre_1_1_property_set.html#ae7a113c3e91c7c8e33087f5c4d0e750e":[5,1,5,3,12],
+"class_ogre_1_1_property_set.html#af3ba7bf448b14fe4c1ef730546d37f7a":[5,1,5,3,5],
+"class_ogre_1_1_quake3_level.html":[5,2,1,7],
+"class_ogre_1_1_quake3_level.html#a058deee088e022627e5544116f9c92b0":[5,2,1,7,35],
+"class_ogre_1_1_quake3_level.html#a0dabe8022c92c8474c8bb09eb0731ad2":[5,2,1,7,24],
 "class_ogre_1_1_quake3_level.html#a14b772c2df273e7657ae96bc2f422671":[5,2,1,7,38],
 "class_ogre_1_1_quake3_level.html#a17f39ebd42aa55a73805b21b2a71436e":[5,2,1,7,31],
 "class_ogre_1_1_quake3_level.html#a2acfd1b5ad4a076b080f6992dc9c2f9d":[5,2,1,7,13],
@@ -131,25 +155,25 @@ var NAVTREEINDEX31 =
 "class_ogre_1_1_quaternion.html#af292a9ed18e3da0bda0fbe114f60cdec":[5,0,6,16,31],
 "class_ogre_1_1_quaternion.html#af3424f1e07092c0ffe293d18b277a04f":[5,0,6,16,57],
 "class_ogre_1_1_quaternion.html#af6725db29a7dbc5d6a9071b86ce43714":[5,0,6,16,29],
-"class_ogre_1_1_queued_renderable_collection.html":[5,0,7,17],
-"class_ogre_1_1_queued_renderable_collection.html#a1f30f771db3b5dd9f520a3e17ff9e1bb":[5,0,7,17,5],
-"class_ogre_1_1_queued_renderable_collection.html#a8fefa658106b7e61c4e779a93000485d":[5,0,7,17,9],
-"class_ogre_1_1_queued_renderable_collection.html#aa6dfdb7b4aefd87f8446651846d00e8c":[5,0,7,17,6],
-"class_ogre_1_1_queued_renderable_collection.html#ab44ba16fe8e8c0247234d4e6edfae844":[5,0,7,17,0],
-"class_ogre_1_1_queued_renderable_collection.html#ab44ba16fe8e8c0247234d4e6edfae844a2cb722796eba6d25f8f7e8d7a4738241":[5,0,7,17,0,2],
-"class_ogre_1_1_queued_renderable_collection.html#ab44ba16fe8e8c0247234d4e6edfae844a5cb7861265877a6f1f0a4b3508df7014":[5,0,7,17,0,0],
-"class_ogre_1_1_queued_renderable_collection.html#ab44ba16fe8e8c0247234d4e6edfae844aaec5c102c9894feda331832a82738d72":[5,0,7,17,0,1],
-"class_ogre_1_1_queued_renderable_collection.html#abc5558898bde744ffebf36421b7c9d9e":[5,0,7,17,3],
-"class_ogre_1_1_queued_renderable_collection.html#ae211c3c1661e84dc6c14c97c0ec26dc5":[5,0,7,17,2],
-"class_ogre_1_1_queued_renderable_collection.html#aec2e19f441301d4b629e17aae40e9dbd":[5,0,7,17,8],
-"class_ogre_1_1_queued_renderable_collection.html#aed4bb7796c9730f96dbd1197c97af40b":[5,0,7,17,7],
-"class_ogre_1_1_queued_renderable_collection.html#aef05cc3a16e4f6a83c2cbd8b4bec377b":[5,0,7,17,1],
-"class_ogre_1_1_queued_renderable_collection.html#afde7f8e139270c04158880ea90da71a0":[5,0,7,17,4],
-"class_ogre_1_1_queued_renderable_visitor.html":[5,0,7,18],
-"class_ogre_1_1_queued_renderable_visitor.html#a9e9fca8d2b7fd4c75a24b6c7f8b1b234":[5,0,7,18,1],
-"class_ogre_1_1_queued_renderable_visitor.html#a9fc6bc2185fad0be06562f49dd23003c":[5,0,7,18,2],
-"class_ogre_1_1_queued_renderable_visitor.html#aa639df153b7748f890d3d11d64e6a0e8":[5,0,7,18,0],
-"class_ogre_1_1_queued_renderable_visitor.html#ac3797655bbf69ff053d80e0f1beec28b":[5,0,7,18,3],
+"class_ogre_1_1_queued_renderable_collection.html":[5,0,7,18],
+"class_ogre_1_1_queued_renderable_collection.html#a1f30f771db3b5dd9f520a3e17ff9e1bb":[5,0,7,18,5],
+"class_ogre_1_1_queued_renderable_collection.html#a8fefa658106b7e61c4e779a93000485d":[5,0,7,18,9],
+"class_ogre_1_1_queued_renderable_collection.html#aa6dfdb7b4aefd87f8446651846d00e8c":[5,0,7,18,6],
+"class_ogre_1_1_queued_renderable_collection.html#ab44ba16fe8e8c0247234d4e6edfae844":[5,0,7,18,0],
+"class_ogre_1_1_queued_renderable_collection.html#ab44ba16fe8e8c0247234d4e6edfae844a2cb722796eba6d25f8f7e8d7a4738241":[5,0,7,18,0,2],
+"class_ogre_1_1_queued_renderable_collection.html#ab44ba16fe8e8c0247234d4e6edfae844a5cb7861265877a6f1f0a4b3508df7014":[5,0,7,18,0,0],
+"class_ogre_1_1_queued_renderable_collection.html#ab44ba16fe8e8c0247234d4e6edfae844aaec5c102c9894feda331832a82738d72":[5,0,7,18,0,1],
+"class_ogre_1_1_queued_renderable_collection.html#abc5558898bde744ffebf36421b7c9d9e":[5,0,7,18,3],
+"class_ogre_1_1_queued_renderable_collection.html#ae211c3c1661e84dc6c14c97c0ec26dc5":[5,0,7,18,2],
+"class_ogre_1_1_queued_renderable_collection.html#aec2e19f441301d4b629e17aae40e9dbd":[5,0,7,18,8],
+"class_ogre_1_1_queued_renderable_collection.html#aed4bb7796c9730f96dbd1197c97af40b":[5,0,7,18,7],
+"class_ogre_1_1_queued_renderable_collection.html#aef05cc3a16e4f6a83c2cbd8b4bec377b":[5,0,7,18,1],
+"class_ogre_1_1_queued_renderable_collection.html#afde7f8e139270c04158880ea90da71a0":[5,0,7,18,4],
+"class_ogre_1_1_queued_renderable_visitor.html":[5,0,7,19],
+"class_ogre_1_1_queued_renderable_visitor.html#a9e9fca8d2b7fd4c75a24b6c7f8b1b234":[5,0,7,19,1],
+"class_ogre_1_1_queued_renderable_visitor.html#a9fc6bc2185fad0be06562f49dd23003c":[5,0,7,19,2],
+"class_ogre_1_1_queued_renderable_visitor.html#aa639df153b7748f890d3d11d64e6a0e8":[5,0,7,19,0],
+"class_ogre_1_1_queued_renderable_visitor.html#ac3797655bbf69ff053d80e0f1beec28b":[5,0,7,19,3],
 "class_ogre_1_1_r_t_shader_1_1_assignment_atom.html":[5,1,7,0],
 "class_ogre_1_1_r_t_shader_1_1_assignment_atom.html#a1b210da4ee751a99331bea9b8df93759":[5,1,7,0,1],
 "class_ogre_1_1_r_t_shader_1_1_assignment_atom.html#a9fcaeaf8c992716d2313438ae76e3e13":[5,1,7,0,0],
@@ -178,29 +202,29 @@ var NAVTREEINDEX31 =
 "class_ogre_1_1_r_t_shader_1_1_function.html":[5,1,7,6],
 "class_ogre_1_1_r_t_shader_1_1_function.html#a011c1140d868a15fc0bb3d37b31d8ced":[5,1,7,6,14],
 "class_ogre_1_1_r_t_shader_1_1_function.html#a0432bf4ab621f4098afac914ccb5371e":[5,1,7,6,27],
+"class_ogre_1_1_r_t_shader_1_1_function.html#a04bbd46ad555743385156be23b2bc495":[5,1,7,6,7],
 "class_ogre_1_1_r_t_shader_1_1_function.html#a0a30617e11298455badbd3f246505310":[5,1,7,6,20],
+"class_ogre_1_1_r_t_shader_1_1_function.html#a0f98fa3f8efb5c913362bdbc76fe97ee":[5,1,7,6,5],
 "class_ogre_1_1_r_t_shader_1_1_function.html#a12894b02670ae32e4c54ab709ab08182":[5,1,7,6,0],
-"class_ogre_1_1_r_t_shader_1_1_function.html#a15c301954bb05ae0884608a0d22902bb":[5,1,7,6,4],
 "class_ogre_1_1_r_t_shader_1_1_function.html#a17604144d59f05e9e992ff96d2fce650":[5,1,7,6,19],
+"class_ogre_1_1_r_t_shader_1_1_function.html#a2d69afef17244d8b8f4f2b41b5c0d0a5":[5,1,7,6,1],
 "class_ogre_1_1_r_t_shader_1_1_function.html#a356adab474a23d9fe17e22df425bd7bc":[5,1,7,6,17],
-"class_ogre_1_1_r_t_shader_1_1_function.html#a4bad4a422742f2d73126303a6af9d229":[5,1,7,6,9],
+"class_ogre_1_1_r_t_shader_1_1_function.html#a41709ca7448d7c3cc25efa474535c752":[5,1,7,6,2],
 "class_ogre_1_1_r_t_shader_1_1_function.html#a67016b960f622a4292e37e7fa28c43b9":[5,1,7,6,8],
 "class_ogre_1_1_r_t_shader_1_1_function.html#a6c3bc19e310e10fb2ca1fa21320575d7":[5,1,7,6,3],
-"class_ogre_1_1_r_t_shader_1_1_function.html#a7137a85782731f56c8d1de98d2d6e6b9":[5,1,7,6,6],
-"class_ogre_1_1_r_t_shader_1_1_function.html#a86212e62d4b7bfd8c6dc084dcd1f607f":[5,1,7,6,11],
+"class_ogre_1_1_r_t_shader_1_1_function.html#a6f8e85c4f711f6739c00d723d0d8fbf9":[5,1,7,6,4],
 "class_ogre_1_1_r_t_shader_1_1_function.html#a8944db02b8db83b5fcf261c4648c1871":[5,1,7,6,22],
-"class_ogre_1_1_r_t_shader_1_1_function.html#a9452b0bbda2a8c1236f4eaafa061d4dc":[5,1,7,6,2],
 "class_ogre_1_1_r_t_shader_1_1_function.html#a9c5ccb838771da1140fc3260a52ee24c":[5,1,7,6,25],
 "class_ogre_1_1_r_t_shader_1_1_function.html#aa56555a10acf2f078a21c8f29eeb63ba":[5,1,7,6,24],
-"class_ogre_1_1_r_t_shader_1_1_function.html#aa7167d7341037ac16ce0555e08a80cef":[5,1,7,6,7],
 "class_ogre_1_1_r_t_shader_1_1_function.html#ab218b89ece9bab69a757c89f512d473c":[5,1,7,6,13],
 "class_ogre_1_1_r_t_shader_1_1_function.html#ab248d5d1bcd4412e7d38f55f6a0eab27":[5,1,7,6,23],
+"class_ogre_1_1_r_t_shader_1_1_function.html#ab29de02c856376cc68e0c2f0a4316a27":[5,1,7,6,9],
 "class_ogre_1_1_r_t_shader_1_1_function.html#ad0a608d7e18cc52b284798816ba9edc7":[5,1,7,6,18],
-"class_ogre_1_1_r_t_shader_1_1_function.html#ad112e1d948a65c3104b9cfde9eb0b939":[5,1,7,6,5],
-"class_ogre_1_1_r_t_shader_1_1_function.html#ad7edaafbe5157420d481902c54292cf2":[5,1,7,6,1],
 "class_ogre_1_1_r_t_shader_1_1_function.html#ae46e120edae3a1f22dc68ebde7fbcfca":[5,1,7,6,26],
 "class_ogre_1_1_r_t_shader_1_1_function.html#ae4a22b20ed6ef533b5b887f1b11bf5f5":[5,1,7,6,12],
+"class_ogre_1_1_r_t_shader_1_1_function.html#ae63fa9eb90cf351eaac310d83303c7d3":[5,1,7,6,6],
 "class_ogre_1_1_r_t_shader_1_1_function.html#aea82e56d0770bc8154c91271ba3e1b24":[5,1,7,6,15],
+"class_ogre_1_1_r_t_shader_1_1_function.html#aed18dcfe406442fea14c0ce18030901b":[5,1,7,6,11],
 "class_ogre_1_1_r_t_shader_1_1_function.html#af11bf51a167028e8d69982e3972d9a65":[5,1,7,6,16],
 "class_ogre_1_1_r_t_shader_1_1_function.html#af27ed65e06b2c713b4a41296bdd1e0b1":[5,1,7,6,21],
 "class_ogre_1_1_r_t_shader_1_1_function.html#af4c761e04ba4f6fa32bfe4589713b49e":[5,1,7,6,10],
@@ -225,29 +249,5 @@ var NAVTREEINDEX31 =
 "class_ogre_1_1_r_t_shader_1_1_function_stage_ref.html#a1f21c6e2292bb9c657eedb9a09ea5080":[5,1,7,9,16],
 "class_ogre_1_1_r_t_shader_1_1_function_stage_ref.html#a2f681e0a5c33bb8e2372176c65eca55e":[5,1,7,9,0],
 "class_ogre_1_1_r_t_shader_1_1_function_stage_ref.html#a409057b788ae2822974ae91a3ed1755f":[5,1,7,9,6],
-"class_ogre_1_1_r_t_shader_1_1_function_stage_ref.html#a4ff1aa2fb96377af672497f948ee22b4":[5,1,7,9,15],
-"class_ogre_1_1_r_t_shader_1_1_function_stage_ref.html#a5a4e33a9b2c25d51e8d790fb0f1b71eb":[5,1,7,9,11],
-"class_ogre_1_1_r_t_shader_1_1_function_stage_ref.html#a6988f5398d216cf42fc7207a85512fd9":[5,1,7,9,12],
-"class_ogre_1_1_r_t_shader_1_1_function_stage_ref.html#a6a64ead04eb725b491135b15ae707568":[5,1,7,9,9],
-"class_ogre_1_1_r_t_shader_1_1_function_stage_ref.html#a6e4ca5c4fa077624a37ce7cc3b6be319":[5,1,7,9,14],
-"class_ogre_1_1_r_t_shader_1_1_function_stage_ref.html#a7dc8e10093587753a1a35e54604e746d":[5,1,7,9,7],
-"class_ogre_1_1_r_t_shader_1_1_function_stage_ref.html#a8f9406da48b84bc745d00a9fff56966a":[5,1,7,9,5],
-"class_ogre_1_1_r_t_shader_1_1_function_stage_ref.html#aa271fbdafec9cedcbdd72598d7e494a1":[5,1,7,9,10],
-"class_ogre_1_1_r_t_shader_1_1_function_stage_ref.html#aa355f602a36d170510dbfe6fde344009":[5,1,7,9,8],
-"class_ogre_1_1_r_t_shader_1_1_function_stage_ref.html#aadecc4c7d6da540a2f448714214d8923":[5,1,7,9,2],
-"class_ogre_1_1_r_t_shader_1_1_function_stage_ref.html#ab7194606aa12931e96f8f5448d418ed0":[5,1,7,9,17],
-"class_ogre_1_1_r_t_shader_1_1_function_stage_ref.html#abd6ff355e3e153f2650ec3b5282c69da":[5,1,7,9,4],
-"class_ogre_1_1_r_t_shader_1_1_function_stage_ref.html#aead5ba36929862cb298eb46cdc597944":[5,1,7,9,3],
-"class_ogre_1_1_r_t_shader_1_1_function_stage_ref.html#af2d392cb3832ec923daa0aa3d7aeda5e":[5,1,7,9,13],
-"class_ogre_1_1_r_t_shader_1_1_function_stage_ref.html#afb7025cfc0eda498f12d9319395c6a9d":[5,1,7,9,1],
-"class_ogre_1_1_r_t_shader_1_1_hardware_skinning_factory.html":[5,1,7,10],
-"class_ogre_1_1_r_t_shader_1_1_hardware_skinning_factory.html#a140bb76f4286c39d14da72bf7a4581fe":[5,1,7,10,8],
-"class_ogre_1_1_r_t_shader_1_1_hardware_skinning_factory.html#a20305ee7256cc48745c8bd2c7354e84a":[5,1,7,10,11],
-"class_ogre_1_1_r_t_shader_1_1_hardware_skinning_factory.html#a3475a3c6970fa475a23df8fbeec8a295":[5,1,7,10,0],
-"class_ogre_1_1_r_t_shader_1_1_hardware_skinning_factory.html#a706dfbec2705d025b118a07edc996f66":[5,1,7,10,5],
-"class_ogre_1_1_r_t_shader_1_1_hardware_skinning_factory.html#a75d769e28e786ddd64405ece2c58edc6":[5,1,7,10,10],
-"class_ogre_1_1_r_t_shader_1_1_hardware_skinning_factory.html#a8e62c06065b1bab85530147845cdc988":[5,1,7,10,3],
-"class_ogre_1_1_r_t_shader_1_1_hardware_skinning_factory.html#aa5acff38037a1a059414e37bc8033d31":[5,1,7,10,7],
-"class_ogre_1_1_r_t_shader_1_1_hardware_skinning_factory.html#aa9bea1d58428c16f0dce7b3074937d43":[5,1,7,10,9],
-"class_ogre_1_1_r_t_shader_1_1_hardware_skinning_factory.html#ab7db0312e767acbd8954146133555eff":[5,1,7,10,4]
+"class_ogre_1_1_r_t_shader_1_1_function_stage_ref.html#a4ff1aa2fb96377af672497f948ee22b4":[5,1,7,9,15]
 };
