@@ -1,5 +1,29 @@
 var NAVTREEINDEX32 =
 {
+"class_ogre_1_1_r_t_shader_1_1_function_stage_ref.html#a5a4e33a9b2c25d51e8d790fb0f1b71eb":[5,1,7,9,11],
+"class_ogre_1_1_r_t_shader_1_1_function_stage_ref.html#a6988f5398d216cf42fc7207a85512fd9":[5,1,7,9,12],
+"class_ogre_1_1_r_t_shader_1_1_function_stage_ref.html#a6a64ead04eb725b491135b15ae707568":[5,1,7,9,9],
+"class_ogre_1_1_r_t_shader_1_1_function_stage_ref.html#a6e4ca5c4fa077624a37ce7cc3b6be319":[5,1,7,9,14],
+"class_ogre_1_1_r_t_shader_1_1_function_stage_ref.html#a7dc8e10093587753a1a35e54604e746d":[5,1,7,9,7],
+"class_ogre_1_1_r_t_shader_1_1_function_stage_ref.html#a8f9406da48b84bc745d00a9fff56966a":[5,1,7,9,5],
+"class_ogre_1_1_r_t_shader_1_1_function_stage_ref.html#aa271fbdafec9cedcbdd72598d7e494a1":[5,1,7,9,10],
+"class_ogre_1_1_r_t_shader_1_1_function_stage_ref.html#aa355f602a36d170510dbfe6fde344009":[5,1,7,9,8],
+"class_ogre_1_1_r_t_shader_1_1_function_stage_ref.html#aadecc4c7d6da540a2f448714214d8923":[5,1,7,9,2],
+"class_ogre_1_1_r_t_shader_1_1_function_stage_ref.html#ab7194606aa12931e96f8f5448d418ed0":[5,1,7,9,17],
+"class_ogre_1_1_r_t_shader_1_1_function_stage_ref.html#abd6ff355e3e153f2650ec3b5282c69da":[5,1,7,9,4],
+"class_ogre_1_1_r_t_shader_1_1_function_stage_ref.html#aead5ba36929862cb298eb46cdc597944":[5,1,7,9,3],
+"class_ogre_1_1_r_t_shader_1_1_function_stage_ref.html#af2d392cb3832ec923daa0aa3d7aeda5e":[5,1,7,9,13],
+"class_ogre_1_1_r_t_shader_1_1_function_stage_ref.html#afb7025cfc0eda498f12d9319395c6a9d":[5,1,7,9,1],
+"class_ogre_1_1_r_t_shader_1_1_hardware_skinning_factory.html":[5,1,7,10],
+"class_ogre_1_1_r_t_shader_1_1_hardware_skinning_factory.html#a0bd9f1363ffef103ea9364f425f91934":[5,1,7,10,3],
+"class_ogre_1_1_r_t_shader_1_1_hardware_skinning_factory.html#a140bb76f4286c39d14da72bf7a4581fe":[5,1,7,10,8],
+"class_ogre_1_1_r_t_shader_1_1_hardware_skinning_factory.html#a20305ee7256cc48745c8bd2c7354e84a":[5,1,7,10,11],
+"class_ogre_1_1_r_t_shader_1_1_hardware_skinning_factory.html#a3475a3c6970fa475a23df8fbeec8a295":[5,1,7,10,0],
+"class_ogre_1_1_r_t_shader_1_1_hardware_skinning_factory.html#a706dfbec2705d025b118a07edc996f66":[5,1,7,10,5],
+"class_ogre_1_1_r_t_shader_1_1_hardware_skinning_factory.html#a75d769e28e786ddd64405ece2c58edc6":[5,1,7,10,10],
+"class_ogre_1_1_r_t_shader_1_1_hardware_skinning_factory.html#aa5acff38037a1a059414e37bc8033d31":[5,1,7,10,7],
+"class_ogre_1_1_r_t_shader_1_1_hardware_skinning_factory.html#aa9bea1d58428c16f0dce7b3074937d43":[5,1,7,10,9],
+"class_ogre_1_1_r_t_shader_1_1_hardware_skinning_factory.html#ab7db0312e767acbd8954146133555eff":[5,1,7,10,4],
 "class_ogre_1_1_r_t_shader_1_1_hardware_skinning_factory.html#abd7502d8f9400edf9cd3cae2c3c17800":[5,1,7,10,12],
 "class_ogre_1_1_r_t_shader_1_1_hardware_skinning_factory.html#ac8f82af0f4fc7100bf5e17553387c2fd":[5,1,7,10,2],
 "class_ogre_1_1_r_t_shader_1_1_hardware_skinning_factory.html#ae24d9ebd4bd6801f9b4f0e13181bf205":[5,1,7,10,13],
@@ -67,6 +91,7 @@ var NAVTREEINDEX32 =
 "class_ogre_1_1_r_t_shader_1_1_operand.html#aed59a8b4f35f59a3bfc0e25fb886dc07":[5,1,7,13,9],
 "class_ogre_1_1_r_t_shader_1_1_parameter.html":[5,1,7,15],
 "class_ogre_1_1_r_t_shader_1_1_parameter.html#a05435ba326deda0d3a0254b24870ccff":[5,1,7,15,4],
+"class_ogre_1_1_r_t_shader_1_1_parameter.html#a1f70b4242ca1d97ca56649c09ae89e98":[5,1,7,15,3],
 "class_ogre_1_1_r_t_shader_1_1_parameter.html#a1f7b2b048c450c18bcf23a44732e565e":[5,1,7,15,15],
 "class_ogre_1_1_r_t_shader_1_1_parameter.html#a2ae8d72e80ee97ad348cb79c98b29b16":[5,1,7,15,19],
 "class_ogre_1_1_r_t_shader_1_1_parameter.html#a3210eee0554afecb57185a0ae938e2ee":[5,1,7,15,12],
@@ -79,7 +104,7 @@ var NAVTREEINDEX32 =
 "class_ogre_1_1_r_t_shader_1_1_parameter.html#a4fa6286f097d19e92a8ed91645fbfbe7a07c6d2515c90cb4cdf5322cfb317c35c":[5,1,7,15,1,29],
 "class_ogre_1_1_r_t_shader_1_1_parameter.html#a4fa6286f097d19e92a8ed91645fbfbe7a0b5f40702c829305a68cf6a665377783":[5,1,7,15,1,15],
 "class_ogre_1_1_r_t_shader_1_1_parameter.html#a4fa6286f097d19e92a8ed91645fbfbe7a0d4703c11953b9b6128a3d760f36ce1e":[5,1,7,15,1,39],
-"class_ogre_1_1_r_t_shader_1_1_parameter.html#a4fa6286f097d19e92a8ed91645fbfbe7a1a85a6dd6da63324f7028b042313145b":[5,1,7,15,1,43],
+"class_ogre_1_1_r_t_shader_1_1_parameter.html#a4fa6286f097d19e92a8ed91645fbfbe7a1a85a6dd6da63324f7028b042313145b":[5,1,7,15,1,44],
 "class_ogre_1_1_r_t_shader_1_1_parameter.html#a4fa6286f097d19e92a8ed91645fbfbe7a1f24519f8aa2e82670e74e9598083f84":[5,1,7,15,1,36],
 "class_ogre_1_1_r_t_shader_1_1_parameter.html#a4fa6286f097d19e92a8ed91645fbfbe7a246e52e0ca793558a3d6f3503796b901":[5,1,7,15,1,38],
 "class_ogre_1_1_r_t_shader_1_1_parameter.html#a4fa6286f097d19e92a8ed91645fbfbe7a24c5c1dbbd17e36bfa9fc0d6a0437b97":[5,1,7,15,1,20],
@@ -93,6 +118,7 @@ var NAVTREEINDEX32 =
 "class_ogre_1_1_r_t_shader_1_1_parameter.html#a4fa6286f097d19e92a8ed91645fbfbe7a44725e1adc4814b771ae535f5eac6634":[5,1,7,15,1,8],
 "class_ogre_1_1_r_t_shader_1_1_parameter.html#a4fa6286f097d19e92a8ed91645fbfbe7a48fb34fa5295c885a8c53ec005e852ef":[5,1,7,15,1,2],
 "class_ogre_1_1_r_t_shader_1_1_parameter.html#a4fa6286f097d19e92a8ed91645fbfbe7a4d6be8e5c18ecc447fcb9bdf50e0af08":[5,1,7,15,1,13],
+"class_ogre_1_1_r_t_shader_1_1_parameter.html#a4fa6286f097d19e92a8ed91645fbfbe7a5b8ae9b3c541bf88272efcdca0f92d42":[5,1,7,15,1,43],
 "class_ogre_1_1_r_t_shader_1_1_parameter.html#a4fa6286f097d19e92a8ed91645fbfbe7a5fc3476511cdfaf5c5a6bde5fa3f6eef":[5,1,7,15,1,41],
 "class_ogre_1_1_r_t_shader_1_1_parameter.html#a4fa6286f097d19e92a8ed91645fbfbe7a62638f6adfe78171c546db9589e1c14a":[5,1,7,15,1,22],
 "class_ogre_1_1_r_t_shader_1_1_parameter.html#a4fa6286f097d19e92a8ed91645fbfbe7a67965d66c1473e94245053fcf0dcd847":[5,1,7,15,1,12],
@@ -112,7 +138,7 @@ var NAVTREEINDEX32 =
 "class_ogre_1_1_r_t_shader_1_1_parameter.html#a4fa6286f097d19e92a8ed91645fbfbe7ac6838b1b65863881c6e9e8a8d1ad7e33":[5,1,7,15,1,21],
 "class_ogre_1_1_r_t_shader_1_1_parameter.html#a4fa6286f097d19e92a8ed91645fbfbe7acb539336ea212818823e81517b5e234a":[5,1,7,15,1,23],
 "class_ogre_1_1_r_t_shader_1_1_parameter.html#a4fa6286f097d19e92a8ed91645fbfbe7acec89a8756b61ced783955905f2c3f04":[5,1,7,15,1,14],
-"class_ogre_1_1_r_t_shader_1_1_parameter.html#a4fa6286f097d19e92a8ed91645fbfbe7ad2f7a789b2cf0c838b37d54bdb469467":[5,1,7,15,1,44],
+"class_ogre_1_1_r_t_shader_1_1_parameter.html#a4fa6286f097d19e92a8ed91645fbfbe7ad2f7a789b2cf0c838b37d54bdb469467":[5,1,7,15,1,45],
 "class_ogre_1_1_r_t_shader_1_1_parameter.html#a4fa6286f097d19e92a8ed91645fbfbe7ad4aabafb098c45325aee3dd3b03b6465":[5,1,7,15,1,37],
 "class_ogre_1_1_r_t_shader_1_1_parameter.html#a4fa6286f097d19e92a8ed91645fbfbe7ad99db23c6c3a4225d80c5bd96f5e7e31":[5,1,7,15,1,28],
 "class_ogre_1_1_r_t_shader_1_1_parameter.html#a4fa6286f097d19e92a8ed91645fbfbe7ae0c2e5cd793f1ecb1df066861ab6c752":[5,1,7,15,1,27],
@@ -127,23 +153,24 @@ var NAVTREEINDEX32 =
 "class_ogre_1_1_r_t_shader_1_1_parameter.html#a6c48a5ac72a1af0f25168c3d4a06b71b":[5,1,7,15,11],
 "class_ogre_1_1_r_t_shader_1_1_parameter.html#a731d5bfce5b8813f0588775ecae64259":[5,1,7,15,6],
 "class_ogre_1_1_r_t_shader_1_1_parameter.html#a83a641fd3be8b42222c1a5988c5c74fd":[5,1,7,15,7],
+"class_ogre_1_1_r_t_shader_1_1_parameter.html#a8feab0b136029256f616e2f38807bb76":[5,1,7,15,10],
 "class_ogre_1_1_r_t_shader_1_1_parameter.html#a91fc3614f191bebf0461676a03750312":[5,1,7,15,0],
 "class_ogre_1_1_r_t_shader_1_1_parameter.html#a91fc3614f191bebf0461676a03750312a1749fc49b1811bf3f129c722a6e8bd51":[5,1,7,15,0,4],
 "class_ogre_1_1_r_t_shader_1_1_parameter.html#a91fc3614f191bebf0461676a03750312a9b746851560ab52d22335755dd36a0ea":[5,1,7,15,0,2],
 "class_ogre_1_1_r_t_shader_1_1_parameter.html#a91fc3614f191bebf0461676a03750312aa27b75d58d2ae680d71d5eda917c5783":[5,1,7,15,0,8],
 "class_ogre_1_1_r_t_shader_1_1_parameter.html#a91fc3614f191bebf0461676a03750312aacb3f8c7623415a9398f1d0aeb0849d9":[5,1,7,15,0,6],
 "class_ogre_1_1_r_t_shader_1_1_parameter.html#a91fc3614f191bebf0461676a03750312abfddaa99b1d15933e549af52af916c86":[5,1,7,15,0,5],
+"class_ogre_1_1_r_t_shader_1_1_parameter.html#a91fc3614f191bebf0461676a03750312ac4c0468d5523a097db78aa5854aadc51":[5,1,7,15,0,10],
 "class_ogre_1_1_r_t_shader_1_1_parameter.html#a91fc3614f191bebf0461676a03750312ac887733af706c0769dcbb9215f7e8b50":[5,1,7,15,0,1],
 "class_ogre_1_1_r_t_shader_1_1_parameter.html#a91fc3614f191bebf0461676a03750312ace9a03298936fc08b7474848ca2ce7b3":[5,1,7,15,0,0],
 "class_ogre_1_1_r_t_shader_1_1_parameter.html#a91fc3614f191bebf0461676a03750312ad9ee9f8d6b6508f5e0402140afe2f655":[5,1,7,15,0,3],
 "class_ogre_1_1_r_t_shader_1_1_parameter.html#a91fc3614f191bebf0461676a03750312adea400d134099c950fbbed0a21dc3170":[5,1,7,15,0,9],
 "class_ogre_1_1_r_t_shader_1_1_parameter.html#a91fc3614f191bebf0461676a03750312af67c3c93adcb32edbb0b93fa6ac21ac0":[5,1,7,15,0,7],
-"class_ogre_1_1_r_t_shader_1_1_parameter.html#a9e0f11ec8780314d7dd0eb32e93798c9":[5,1,7,15,3],
 "class_ogre_1_1_r_t_shader_1_1_parameter.html#a9f241674489c5321d2741df6d928fc3d":[5,1,7,15,2],
-"class_ogre_1_1_r_t_shader_1_1_parameter.html#ab8ed4fa20a94d4dc3b964ee20d56769f":[5,1,7,15,10],
 "class_ogre_1_1_r_t_shader_1_1_parameter.html#ab91af159d722cbd7577208f7360af72a":[5,1,7,15,21],
 "class_ogre_1_1_r_t_shader_1_1_parameter.html#aefb06f44383244d59e3832f691d9f7b6":[5,1,7,15,14],
 "class_ogre_1_1_r_t_shader_1_1_parameter_factory.html":[5,1,7,16],
+"class_ogre_1_1_r_t_shader_1_1_parameter_factory.html#a011a272527b0dfec88b44aa130026449":[5,1,7,16,13],
 "class_ogre_1_1_r_t_shader_1_1_parameter_factory.html#a0339e1b0f5da7d6b7bd78dd005e6bdf8":[5,1,7,16,18],
 "class_ogre_1_1_r_t_shader_1_1_parameter_factory.html#a03888f5210bf17cc1350793c72e2a4ce":[5,1,7,16,10],
 "class_ogre_1_1_r_t_shader_1_1_parameter_factory.html#a09263364591be6dc45b9180d7d924017":[5,1,7,16,5],
@@ -157,18 +184,17 @@ var NAVTREEINDEX32 =
 "class_ogre_1_1_r_t_shader_1_1_parameter_factory.html#a5df4c21fa96cbc283fc585c38c953c96":[5,1,7,16,19],
 "class_ogre_1_1_r_t_shader_1_1_parameter_factory.html#a6b3a06ea5c900e44edb8e282c5c25b4d":[5,1,7,16,22],
 "class_ogre_1_1_r_t_shader_1_1_parameter_factory.html#a6d0c5060af9faf5645a08dc87723b170":[5,1,7,16,6],
+"class_ogre_1_1_r_t_shader_1_1_parameter_factory.html#a840d1f360b06954d3f134b0e83c37b01":[5,1,7,16,12],
 "class_ogre_1_1_r_t_shader_1_1_parameter_factory.html#a8de67119ab14a1f1df19893ddf37c5d0":[5,1,7,16,4],
 "class_ogre_1_1_r_t_shader_1_1_parameter_factory.html#a99b245c958ecaa99551d8ba2325e7aca":[5,1,7,16,15],
 "class_ogre_1_1_r_t_shader_1_1_parameter_factory.html#aac159df02f9d38f97074da632e33e5c7":[5,1,7,16,1],
 "class_ogre_1_1_r_t_shader_1_1_parameter_factory.html#ab0deb0f55ac91c3daa9d1c5e717b45cf":[5,1,7,16,17],
 "class_ogre_1_1_r_t_shader_1_1_parameter_factory.html#ab92a78b6e66962547a12c0f9845ce4e3":[5,1,7,16,14],
-"class_ogre_1_1_r_t_shader_1_1_parameter_factory.html#ac0a02aa9babb2203fbf0945888c1f906":[5,1,7,16,0],
+"class_ogre_1_1_r_t_shader_1_1_parameter_factory.html#abd7c7b70f307f5d47287b3f51b0c81ad":[5,1,7,16,0],
 "class_ogre_1_1_r_t_shader_1_1_parameter_factory.html#ac7866ca9ab974f86e829648c86d6315b":[5,1,7,16,23],
 "class_ogre_1_1_r_t_shader_1_1_parameter_factory.html#ad0461fc33fb6bbb8ebb1d732f2ccb17a":[5,1,7,16,9],
-"class_ogre_1_1_r_t_shader_1_1_parameter_factory.html#ad1bf68269aadb9f521d3168090e7bd11":[5,1,7,16,13],
 "class_ogre_1_1_r_t_shader_1_1_parameter_factory.html#ad7175b91afc6f9d5d4c3fbdf14f23a02":[5,1,7,16,7],
 "class_ogre_1_1_r_t_shader_1_1_parameter_factory.html#adc993ce92bf6f96b4010ce4ae3e4d7a0":[5,1,7,16,11],
-"class_ogre_1_1_r_t_shader_1_1_parameter_factory.html#ae1e6ad891b88b61a9f16c9f7fd15d993":[5,1,7,16,12],
 "class_ogre_1_1_r_t_shader_1_1_program.html":[5,1,7,17],
 "class_ogre_1_1_r_t_shader_1_1_program.html#a0ff6a70a8c8eeaa9dce1ceb0d4b496e4":[5,1,7,17,11],
 "class_ogre_1_1_r_t_shader_1_1_program.html#a1738228b71726715dea9c34bed1933df":[5,1,7,17,0],
@@ -223,31 +249,5 @@ var NAVTREEINDEX32 =
 "class_ogre_1_1_r_t_shader_1_1_program_writer_manager.html#a63350ccbb6834028260b2642c9509bb7":[5,1,7,21,5],
 "class_ogre_1_1_r_t_shader_1_1_program_writer_manager.html#a73b6e78fa3c138c4987b96aa2a7c3118":[5,1,7,21,2],
 "class_ogre_1_1_r_t_shader_1_1_program_writer_manager.html#a97fa340b976122ebe93939ea47580bc8":[5,1,7,21,1],
-"class_ogre_1_1_r_t_shader_1_1_program_writer_manager.html#aa7d6b319ff45bc9861dba292f9b2ff7a":[5,1,7,21,0],
-"class_ogre_1_1_r_t_shader_1_1_program_writer_manager.html#aab32a8bee0c51620b07d3e1b80eca028":[5,1,7,21,3],
-"class_ogre_1_1_r_t_shader_1_1_program_writer_manager.html#ad88f08e88099432ae43500912c885b3a":[5,1,7,21,6],
-"class_ogre_1_1_r_t_shader_1_1_render_state.html":[5,1,7,22],
-"class_ogre_1_1_r_t_shader_1_1_render_state.html#a2ca3685c43016a03c1e3b3d4ecc79bd1":[5,1,7,22,9],
-"class_ogre_1_1_r_t_shader_1_1_render_state.html#a81091492cc593d379a4255e6560995b4":[5,1,7,22,12],
-"class_ogre_1_1_r_t_shader_1_1_render_state.html#a9ad5c29c93f7e3852b2bf34ed7d71850":[5,1,7,22,0],
-"class_ogre_1_1_r_t_shader_1_1_render_state.html#a9bec985d391fa2546bf719925d6b40ef":[5,1,7,22,7],
-"class_ogre_1_1_r_t_shader_1_1_render_state.html#aafc13c2857e26c83732a6fe6e804cc32":[5,1,7,22,8],
-"class_ogre_1_1_r_t_shader_1_1_render_state.html#ab5dd862d79c794b95c1674950da01d65":[5,1,7,22,2],
-"class_ogre_1_1_r_t_shader_1_1_render_state.html#ac3f5c56a2ff4fd1728bfb22309285112":[5,1,7,22,13],
-"class_ogre_1_1_r_t_shader_1_1_render_state.html#acd05f1eaf224a41f89b4c94823b96877":[5,1,7,22,10],
-"class_ogre_1_1_r_t_shader_1_1_render_state.html#ad310453cbe3b946a38e156f824baf29a":[5,1,7,22,4],
-"class_ogre_1_1_r_t_shader_1_1_render_state.html#adbe4e95bc100df25fe3f860869ee53a1":[5,1,7,22,1],
-"class_ogre_1_1_r_t_shader_1_1_render_state.html#ae0a7511e041d89378c5369ba2f42c23d":[5,1,7,22,11],
-"class_ogre_1_1_r_t_shader_1_1_render_state.html#ae30c39077c175d303107089e8476f6b7":[5,1,7,22,5],
-"class_ogre_1_1_r_t_shader_1_1_render_state.html#ae46e120edae3a1f22dc68ebde7fbcfca":[5,1,7,22,14],
-"class_ogre_1_1_r_t_shader_1_1_render_state.html#ae5b37dfcaf7a7e7ddee5d2bb0b180fd2":[5,1,7,22,6],
-"class_ogre_1_1_r_t_shader_1_1_render_state.html#af66edaf33c654e03ef89f1eaec384a1f":[5,1,7,22,3],
-"class_ogre_1_1_r_t_shader_1_1_s_g_script_translator.html":[5,1,7,24],
-"class_ogre_1_1_r_t_shader_1_1_sample_texture_atom.html":[5,1,7,23],
-"class_ogre_1_1_r_t_shader_1_1_sample_texture_atom.html#a21705d4501deac8ac42dc447ee457f63":[5,1,7,23,0],
-"class_ogre_1_1_r_t_shader_1_1_sample_texture_atom.html#a81f0216ae542219fcb975408ca1aa6af":[5,1,7,23,2],
-"class_ogre_1_1_r_t_shader_1_1_sample_texture_atom.html#ac5b1093e3d9ffb1bb30d28cf22655597":[5,1,7,23,1],
-"class_ogre_1_1_r_t_shader_1_1_shader_generator.html":[5,1,7,25],
-"class_ogre_1_1_r_t_shader_1_1_shader_generator.html#a0300fe2daab3dbea762268383921dfc7":[5,1,7,25,24],
-"class_ogre_1_1_r_t_shader_1_1_shader_generator.html#a0483b3ec09f89d857909f5a7ea8e4da4":[5,1,7,25,60]
+"class_ogre_1_1_r_t_shader_1_1_program_writer_manager.html#aa7d6b319ff45bc9861dba292f9b2ff7a":[5,1,7,21,0]
 };
