@@ -1,5 +1,7 @@
 var NAVTREEINDEX4 =
 {
+"building-ogre.html#installing-sdk":[2,0,5],
+"building-ogre.html#running-cmake":[2,0,3],
 "citelist.html":[4],
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html":[5,0,8,0],
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html#a49d76c0adee87f3761b47ba3f9423a95":[5,0,8,0,1],
@@ -13,15 +15,15 @@ var NAVTREEINDEX4 =
 "class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a8c5503af3d0b705e1bf05849b68051a7":[5,0,4,0,4],
 "class_ogre_1_1_absolute_pixel_count_lod_strategy.html#ab89c1d47c5f906f91a5f1753db21070b":[5,0,4,0,2],
 "class_ogre_1_1_abstract_node.html":[5,0,10,0],
-"class_ogre_1_1_abstract_node.html#a25d905239cc4b086edcfe91bc51f7bfb":[5,0,10,0,8],
+"class_ogre_1_1_abstract_node.html#a25d905239cc4b086edcfe91bc51f7bfb":[5,0,10,0,9],
 "class_ogre_1_1_abstract_node.html#a62f3404d9d2d8213c06782781d9e2bcb":[5,0,10,0,3],
 "class_ogre_1_1_abstract_node.html#aa1e35720e58e667e13399107b63b3813":[5,0,10,0,2],
 "class_ogre_1_1_abstract_node.html#ab2cbfa72f106771005b1644a3f8b1b23":[5,0,10,0,1],
-"class_ogre_1_1_abstract_node.html#acf394c05aecb3cb258a28c19e1969ff2":[5,0,10,0,9],
-"class_ogre_1_1_abstract_node.html#ad12982998ed96d3b0b99a1b74ae1360b":[5,0,10,0,5],
-"class_ogre_1_1_abstract_node.html#ad2e2e1cc95ee64cd9632cc63e4ca3234":[5,0,10,0,6],
+"class_ogre_1_1_abstract_node.html#acf394c05aecb3cb258a28c19e1969ff2":[5,0,10,0,10],
+"class_ogre_1_1_abstract_node.html#ad12982998ed96d3b0b99a1b74ae1360b":[5,0,10,0,6],
+"class_ogre_1_1_abstract_node.html#ad2e2e1cc95ee64cd9632cc63e4ca3234":[5,0,10,0,7],
 "class_ogre_1_1_abstract_node.html#aea6ae47cf7842e94eb9a179381b9eb29":[5,0,10,0,0],
-"class_ogre_1_1_abstract_node.html#af05272e6472ec8283d7bdf304cd9ef14":[5,0,10,0,7],
+"class_ogre_1_1_abstract_node.html#af05272e6472ec8283d7bdf304cd9ef14":[5,0,10,0,8],
 "class_ogre_1_1_affine3.html":[5,0,6,0],
 "class_ogre_1_1_affine3.html#a0ea806400969075b54313aed739cdce6":[5,0,6,0,14],
 "class_ogre_1_1_affine3.html#a23c6bb6170cd619be269bec8ed434ef4":[5,0,6,0,4],
@@ -247,7 +249,5 @@ var NAVTREEINDEX4 =
 "class_ogre_1_1_animation_track.html#ad96281be1b189c69a1dbd2283d583503":[5,0,0,8,14],
 "class_ogre_1_1_animation_track.html#ae65e63b3f5b7dc7425d6071ce987ceaf":[5,0,0,8,6],
 "class_ogre_1_1_animation_track.html#aed855e8117300af01d646ff49b020916":[5,0,0,8,17],
-"class_ogre_1_1_animation_track.html#afcc48b8a78792024e88eb7ff3e1ffc3c":[5,0,0,8,7],
-"class_ogre_1_1_animation_track.html#afdb009bde206607a98cbb24a0b5be156":[5,0,0,8,19],
-"class_ogre_1_1_animation_track.html#afe26aa738aca34c07407b6566b5d9eeb":[5,0,0,8,18]
+"class_ogre_1_1_animation_track.html#afcc48b8a78792024e88eb7ff3e1ffc3c":[5,0,0,8,7]
 };
