@@ -1,5 +1,20 @@
 var NAVTREEINDEX41 =
 {
+"class_ogre_1_1_small_vector_template_common.html#ae40a8630bf739e9fadd1162ea95bb412":[7,0,0,480,20],
+"class_ogre_1_1_small_vector_template_common.html#af5c75e8908b1e44ae53d8c12d784ed96":[6,0,1,480,6],
+"class_ogre_1_1_small_vector_template_common.html#af5c75e8908b1e44ae53d8c12d784ed96":[7,0,0,480,6],
+"class_ogre_1_1_small_vector_template_common.html#af6adada5ede6dc97e6be23bc96b286da":[6,0,1,480,8],
+"class_ogre_1_1_small_vector_template_common.html#af6adada5ede6dc97e6be23bc96b286da":[7,0,0,480,8],
+"class_ogre_1_1_sphere.html":[5,0,6,21],
+"class_ogre_1_1_sphere.html#a01e832a0542bde80df107ab6b26b56f9":[5,0,6,21,6],
+"class_ogre_1_1_sphere.html#a4a30ba4b71475bf2da82c91dcc13e97a":[5,0,6,21,9],
+"class_ogre_1_1_sphere.html#a6306310d834dc7844c73dd24ec7a318d":[5,0,6,21,2],
+"class_ogre_1_1_sphere.html#a774730a3d40a4375144128b13afc39ef":[5,0,6,21,8],
+"class_ogre_1_1_sphere.html#a77798ca00493f6b1f9da7f3eff782642":[5,0,6,21,7],
+"class_ogre_1_1_sphere.html#a93cb05f8025668db930ef81a34dca47b":[5,0,6,21,0],
+"class_ogre_1_1_sphere.html#a9e9104e8e57c2fa2d30920989c725d1a":[5,0,6,21,10],
+"class_ogre_1_1_sphere.html#aafe80cad31edd668b09981a6f836c8b1":[5,0,6,21,3],
+"class_ogre_1_1_sphere.html#abd0dc8dd45b400a07d71115652d2dc20":[5,0,6,21,1],
 "class_ogre_1_1_sphere.html#af2cd29ca81e68cdeb65b91a2667d6fbc":[5,0,6,21,5],
 "class_ogre_1_1_sphere.html#afc27f8572366e37a150a45963c4dc247":[5,0,6,21,4],
 "class_ogre_1_1_sphere_scene_query.html":[5,0,9,52],
@@ -7,22 +22,22 @@ var NAVTREEINDEX41 =
 "class_ogre_1_1_sphere_scene_query.html#a5355b72d0d8fb12e4e35f8661652f190":[5,0,9,52,0],
 "class_ogre_1_1_sphere_scene_query.html#a6b8ac84df4b61cdd0abba7fcd43ae956":[5,0,9,52,2],
 "class_ogre_1_1_sphere_scene_query.html#ad0b1caec71e5feae87779d34351da924":[5,0,9,52,1],
-"class_ogre_1_1_static_cache.html":[6,0,1,483],
-"class_ogre_1_1_static_cache.html":[7,0,0,483],
-"class_ogre_1_1_static_cache.html#a0c5c50ba8dcb899f95414093f1085789":[6,0,1,483,4],
-"class_ogre_1_1_static_cache.html#a0c5c50ba8dcb899f95414093f1085789":[7,0,0,483,4],
-"class_ogre_1_1_static_cache.html#a391ccc42df8e159a6b5dd7da49ac1679":[6,0,1,483,3],
-"class_ogre_1_1_static_cache.html#a391ccc42df8e159a6b5dd7da49ac1679":[7,0,0,483,3],
-"class_ogre_1_1_static_cache.html#a3e71993f421220f6d20a42c6c7401302":[6,0,1,483,0],
-"class_ogre_1_1_static_cache.html#a3e71993f421220f6d20a42c6c7401302":[7,0,0,483,0],
-"class_ogre_1_1_static_cache.html#a5b61f6d3a1c376811aedbd7718890d99":[6,0,1,483,1],
-"class_ogre_1_1_static_cache.html#a5b61f6d3a1c376811aedbd7718890d99":[7,0,0,483,1],
-"class_ogre_1_1_static_cache.html#a98387ba5e5f61b22c0933ed2f3dfb303":[6,0,1,483,2],
-"class_ogre_1_1_static_cache.html#a98387ba5e5f61b22c0933ed2f3dfb303":[7,0,0,483,2],
-"class_ogre_1_1_static_cache.html#abf9d854f82e9e25fb410be84941890ee":[6,0,1,483,6],
-"class_ogre_1_1_static_cache.html#abf9d854f82e9e25fb410be84941890ee":[7,0,0,483,6],
-"class_ogre_1_1_static_cache.html#af58d3151d8bbfa0a07d6fefad4df0b99":[6,0,1,483,5],
-"class_ogre_1_1_static_cache.html#af58d3151d8bbfa0a07d6fefad4df0b99":[7,0,0,483,5],
+"class_ogre_1_1_static_cache.html":[6,0,1,485],
+"class_ogre_1_1_static_cache.html":[7,0,0,485],
+"class_ogre_1_1_static_cache.html#a0c5c50ba8dcb899f95414093f1085789":[6,0,1,485,4],
+"class_ogre_1_1_static_cache.html#a0c5c50ba8dcb899f95414093f1085789":[7,0,0,485,4],
+"class_ogre_1_1_static_cache.html#a391ccc42df8e159a6b5dd7da49ac1679":[6,0,1,485,3],
+"class_ogre_1_1_static_cache.html#a391ccc42df8e159a6b5dd7da49ac1679":[7,0,0,485,3],
+"class_ogre_1_1_static_cache.html#a3e71993f421220f6d20a42c6c7401302":[6,0,1,485,0],
+"class_ogre_1_1_static_cache.html#a3e71993f421220f6d20a42c6c7401302":[7,0,0,485,0],
+"class_ogre_1_1_static_cache.html#a5b61f6d3a1c376811aedbd7718890d99":[6,0,1,485,1],
+"class_ogre_1_1_static_cache.html#a5b61f6d3a1c376811aedbd7718890d99":[7,0,0,485,1],
+"class_ogre_1_1_static_cache.html#a98387ba5e5f61b22c0933ed2f3dfb303":[6,0,1,485,2],
+"class_ogre_1_1_static_cache.html#a98387ba5e5f61b22c0933ed2f3dfb303":[7,0,0,485,2],
+"class_ogre_1_1_static_cache.html#abf9d854f82e9e25fb410be84941890ee":[6,0,1,485,6],
+"class_ogre_1_1_static_cache.html#abf9d854f82e9e25fb410be84941890ee":[7,0,0,485,6],
+"class_ogre_1_1_static_cache.html#af58d3151d8bbfa0a07d6fefad4df0b99":[6,0,1,485,5],
+"class_ogre_1_1_static_cache.html#af58d3151d8bbfa0a07d6fefad4df0b99":[7,0,0,485,5],
 "class_ogre_1_1_static_geometry.html":[5,0,9,54],
 "class_ogre_1_1_static_geometry.html#a01a3f53c1970d60f1908cac9d1cc3b1d":[5,0,9,54,34],
 "class_ogre_1_1_static_geometry.html#a03c94e8a32918dba0fa4321e49f7135f":[5,0,9,54,20],
@@ -234,20 +249,5 @@ var NAVTREEINDEX41 =
 "class_ogre_1_1_string_converter.html#a66b762033aad3b0464dd116f983c7685":[5,0,2,46,41],
 "class_ogre_1_1_string_converter.html#a78755a56a6f07c545bdc7a73c035a96d":[5,0,2,46,37],
 "class_ogre_1_1_string_converter.html#a7ba002d36e0af0d63ead860659c21625":[5,0,2,46,34],
-"class_ogre_1_1_string_converter.html#a7dd1a2f936cced85559abb1f948bdecb":[5,0,2,46,48],
-"class_ogre_1_1_string_converter.html#a8056b62654f3285bea74f61807b78c7d":[5,0,2,46,4],
-"class_ogre_1_1_string_converter.html#a8f1d0fab67ac94cb5466812aea13dae0":[5,0,2,46,45],
-"class_ogre_1_1_string_converter.html#a95d05930b54167f5353733ec36668f65":[5,0,2,46,54],
-"class_ogre_1_1_string_converter.html#a9633e8a5b340ca0c3b36aa51efb4cc5d":[5,0,2,46,38],
-"class_ogre_1_1_string_converter.html#a9ceacfd6e4f13f89c1ec03f5ef754b58":[5,0,2,46,50],
-"class_ogre_1_1_string_converter.html#aa05c075b14b73fbdc82f477d6da359f8":[5,0,2,46,20],
-"class_ogre_1_1_string_converter.html#aa0a2d5fb724610a66f1949511e1fb478":[5,0,2,46,19],
-"class_ogre_1_1_string_converter.html#aa0d9e22b2cfa07df243920cedfb68563":[5,0,2,46,40],
-"class_ogre_1_1_string_converter.html#aa331e97f9c49e38ac4951c6643f02fbf":[5,0,2,46,7],
-"class_ogre_1_1_string_converter.html#aa671980d27b86d09a0f568b451ba677d":[5,0,2,46,14],
-"class_ogre_1_1_string_converter.html#aac72f36d80009ebb30da7d270c08d591":[5,0,2,46,29],
-"class_ogre_1_1_string_converter.html#ab5b342933cd843bd5ce91b1b9f1d108a":[5,0,2,46,13],
-"class_ogre_1_1_string_converter.html#ab6f7c4fb9bf4be031282c8ccf5b38727":[5,0,2,46,22],
-"class_ogre_1_1_string_converter.html#abca988b16577c3feab1317c3646a180e":[5,0,2,46,6],
-"class_ogre_1_1_string_converter.html#abe797dbd9215f9f649c339a8f7044e50":[5,0,2,46,23]
+"class_ogre_1_1_string_converter.html#a7dd1a2f936cced85559abb1f948bdecb":[5,0,2,46,48]
 };
