@@ -1,5 +1,20 @@
 var NAVTREEINDEX45 =
 {
+"class_ogre_1_1_terrain_quad_tree_node.html#a0116ccf6d9c0ded0c099210ca5024d0f":[5,1,8,13,15],
+"class_ogre_1_1_terrain_quad_tree_node.html#a08466f3ed294f0ff9fc74feea3a9fff2":[5,1,8,13,42],
+"class_ogre_1_1_terrain_quad_tree_node.html#a0eb56d7672b36b1403bc3eddc83bf786":[5,1,8,13,10],
+"class_ogre_1_1_terrain_quad_tree_node.html#a15a0aedbb91a7304d1802456f66ab6e5":[5,1,8,13,22],
+"class_ogre_1_1_terrain_quad_tree_node.html#a1a2433c6e02f4434a43be08c6c1b9fc9":[5,1,8,13,38],
+"class_ogre_1_1_terrain_quad_tree_node.html#a20aec2a5359be7a4621188e98c6fdd4e":[5,1,8,13,27],
+"class_ogre_1_1_terrain_quad_tree_node.html#a21057fc9dca730125457d9fb0e7d4588":[5,1,8,13,4],
+"class_ogre_1_1_terrain_quad_tree_node.html#a27b042a63b10b1eab460404b69054cf6":[5,1,8,13,24],
+"class_ogre_1_1_terrain_quad_tree_node.html#a38313e6b615d8df43e62ee721e576f22":[5,1,8,13,41],
+"class_ogre_1_1_terrain_quad_tree_node.html#a390b02c9923941792b4f9870f61be02d":[5,1,8,13,34],
+"class_ogre_1_1_terrain_quad_tree_node.html#a3a15c3342a52eccd843ef5710614bb73":[5,1,8,13,16],
+"class_ogre_1_1_terrain_quad_tree_node.html#a440a2d098b05930f9c041bcce1fc3a90":[5,1,8,13,12],
+"class_ogre_1_1_terrain_quad_tree_node.html#a4b0024e42e7eff99a65abf0c81a9939c":[5,1,8,13,36],
+"class_ogre_1_1_terrain_quad_tree_node.html#a525a7166daaa69292b2350de66784f58":[5,1,8,13,3],
+"class_ogre_1_1_terrain_quad_tree_node.html#a570b17be150e8de773197f801a6a2a2e":[5,1,8,13,47],
 "class_ogre_1_1_terrain_quad_tree_node.html#a619cb859cf6a6501ab3c60bf2674cc1b":[5,1,8,13,39],
 "class_ogre_1_1_terrain_quad_tree_node.html#a61cddd999eed248ede1e7015b17040e0":[5,1,8,13,43],
 "class_ogre_1_1_terrain_quad_tree_node.html#a640fe3ce61b4c3d342ef6df439c27595":[5,1,8,13,14],
@@ -68,54 +83,57 @@ var NAVTREEINDEX45 =
 "class_ogre_1_1_text_area_overlay_element.html#aeb5a40e72c6f7dc4c74217ecd390a6c6":[5,1,3,13,19],
 "class_ogre_1_1_text_area_overlay_element.html#af69d715288b94d320e4ed3ea99fd68a3":[5,1,3,13,9],
 "class_ogre_1_1_texture.html":[5,0,8,30],
-"class_ogre_1_1_texture.html#a017b0d0590ce4afc079f2f1f85a686b8":[5,0,8,30,26],
-"class_ogre_1_1_texture.html#a031474b97a9f2606cda91960b360aeb8":[5,0,8,30,37],
+"class_ogre_1_1_texture.html#a017b0d0590ce4afc079f2f1f85a686b8":[5,0,8,30,27],
+"class_ogre_1_1_texture.html#a031474b97a9f2606cda91960b360aeb8":[5,0,8,30,38],
 "class_ogre_1_1_texture.html#a0ba4cefce02a7afa769a28c85c892082":[5,0,8,30,2],
 "class_ogre_1_1_texture.html#a0d93452e4b051453ec368bc275fe339f":[5,0,8,30,1],
-"class_ogre_1_1_texture.html#a0ff2e6946c562128e059ebfcfc86d197":[5,0,8,30,5],
-"class_ogre_1_1_texture.html#a2403b6aa5526f15570d26f8903e83da6":[5,0,8,30,12],
+"class_ogre_1_1_texture.html#a0e27aa7d2f734ff39d706e7ff6577cf9":[5,0,8,30,45],
+"class_ogre_1_1_texture.html#a0ff2e6946c562128e059ebfcfc86d197":[5,0,8,30,6],
+"class_ogre_1_1_texture.html#a2403b6aa5526f15570d26f8903e83da6":[5,0,8,30,13],
 "class_ogre_1_1_texture.html#a2624f89d5e9e5d645380fce79836b54f":[5,0,8,30,0],
-"class_ogre_1_1_texture.html#a297b97d2c7253c1ca8c471b91edd4407":[5,0,8,30,14],
-"class_ogre_1_1_texture.html#a2dca57a4b5847bc89f43819b779c8c6a":[5,0,8,30,4],
-"class_ogre_1_1_texture.html#a353c91fed9eb4d4baada25f9519abc4a":[5,0,8,30,29],
-"class_ogre_1_1_texture.html#a38381942fa75cba53a03813047d5a2ee":[5,0,8,30,42],
-"class_ogre_1_1_texture.html#a464f514c90dde429bcba7afb4b34768f":[5,0,8,30,28],
-"class_ogre_1_1_texture.html#a4a4f09d971e96259593aac5ef0df873d":[5,0,8,30,11],
-"class_ogre_1_1_texture.html#a4b257658297582848fe47a027f75bb3a":[5,0,8,30,45],
-"class_ogre_1_1_texture.html#a4b9088dd0c1a9036e33dd64d56a3d902":[5,0,8,30,23],
+"class_ogre_1_1_texture.html#a297b97d2c7253c1ca8c471b91edd4407":[5,0,8,30,15],
+"class_ogre_1_1_texture.html#a2dca57a4b5847bc89f43819b779c8c6a":[5,0,8,30,5],
+"class_ogre_1_1_texture.html#a353c91fed9eb4d4baada25f9519abc4a":[5,0,8,30,30],
+"class_ogre_1_1_texture.html#a464f514c90dde429bcba7afb4b34768f":[5,0,8,30,29],
+"class_ogre_1_1_texture.html#a4a4f09d971e96259593aac5ef0df873d":[5,0,8,30,12],
+"class_ogre_1_1_texture.html#a4b257658297582848fe47a027f75bb3a":[5,0,8,30,48],
+"class_ogre_1_1_texture.html#a4b9088dd0c1a9036e33dd64d56a3d902":[5,0,8,30,24],
 "class_ogre_1_1_texture.html#a4d0ef43ff1e078b942e017f3dea6471d":[5,0,8,30,3],
-"class_ogre_1_1_texture.html#a5decc0244a000c5002935c32ac301f0c":[5,0,8,30,31],
-"class_ogre_1_1_texture.html#a622c64d1862fb3accb017989cd1f1481":[5,0,8,30,10],
-"class_ogre_1_1_texture.html#a66da73db6e7117be285c62160da62d5c":[5,0,8,30,39],
-"class_ogre_1_1_texture.html#a6c5c6be0ec434481a055ab6b03b644fd":[5,0,8,30,43],
-"class_ogre_1_1_texture.html#a6ed49ed8701feb087b04b730ce1d682f":[5,0,8,30,32],
-"class_ogre_1_1_texture.html#a6f186da4d9557d958779eba68bb769a9":[5,0,8,30,6],
-"class_ogre_1_1_texture.html#a6f1a52798479255a174b3c0ecba6a10c":[5,0,8,30,21],
-"class_ogre_1_1_texture.html#a743e5059501507cd858e90532e8263f9":[5,0,8,30,16],
-"class_ogre_1_1_texture.html#a7bb75d68800a258c0ccaa34b3c23e2f2":[5,0,8,30,27],
-"class_ogre_1_1_texture.html#a7bd0ddb623f9d7b01fb272db8296cc72":[5,0,8,30,34],
-"class_ogre_1_1_texture.html#a7c7b9de76ae4ffc29f4d75b6f9bf899a":[5,0,8,30,33],
-"class_ogre_1_1_texture.html#a7eded50cabb3e9dbeeee531c168016da":[5,0,8,30,24],
-"class_ogre_1_1_texture.html#a8ed6a95810f21f53aa8cbc780b680164":[5,0,8,30,30],
-"class_ogre_1_1_texture.html#a90ce19013c81301e656ba110fcc01728":[5,0,8,30,38],
-"class_ogre_1_1_texture.html#a963616fe631db2b5bef45234a15bff7f":[5,0,8,30,40],
-"class_ogre_1_1_texture.html#aa539a94d1bd9ea8f4e804093be538c3e":[5,0,8,30,47],
-"class_ogre_1_1_texture.html#aadcef30707e8e10fbac61d65e1e73e52":[5,0,8,30,18],
-"class_ogre_1_1_texture.html#ab81b8c120556a1edf4c42d92abc9baf4":[5,0,8,30,41],
-"class_ogre_1_1_texture.html#aba1e54055a50692510da87d5d3eb5de1":[5,0,8,30,35],
-"class_ogre_1_1_texture.html#ac7eab6fa3b2133384bf2d92b4f5a2a99":[5,0,8,30,19],
-"class_ogre_1_1_texture.html#ac93f17feff099035542be8b22f890417":[5,0,8,30,7],
-"class_ogre_1_1_texture.html#accfa5467ab8ccfc5920ec64101f8f532":[5,0,8,30,44],
-"class_ogre_1_1_texture.html#ad1c33ba2014eeb134c8ce932f2a43418":[5,0,8,30,15],
-"class_ogre_1_1_texture.html#ad233adde489a5b2129eb20fc93952839":[5,0,8,30,46],
-"class_ogre_1_1_texture.html#ad3c315f415bb89c7646795bcee44acb7":[5,0,8,30,25],
-"class_ogre_1_1_texture.html#ad8faaf7732b48e059f7d7dc15667f2af":[5,0,8,30,8],
-"class_ogre_1_1_texture.html#ae272c029efa4b04406a58e01cd8ea7e8":[5,0,8,30,20],
-"class_ogre_1_1_texture.html#ae32d1cfbbb44d87d698aae547ecda35f":[5,0,8,30,9],
-"class_ogre_1_1_texture.html#aec390502f63927ed9470ba423ea66f64":[5,0,8,30,22],
-"class_ogre_1_1_texture.html#aee3fd3170df592c3cc679cc38d3d9f60":[5,0,8,30,17],
-"class_ogre_1_1_texture.html#aee662e54343ef66ec2835de723908735":[5,0,8,30,36],
-"class_ogre_1_1_texture.html#aef9b4ae468fdabbd98af5371f870437a":[5,0,8,30,13],
+"class_ogre_1_1_texture.html#a5decc0244a000c5002935c32ac301f0c":[5,0,8,30,32],
+"class_ogre_1_1_texture.html#a622c64d1862fb3accb017989cd1f1481":[5,0,8,30,11],
+"class_ogre_1_1_texture.html#a66da73db6e7117be285c62160da62d5c":[5,0,8,30,40],
+"class_ogre_1_1_texture.html#a6bb2b36161be51be48cea882f6d4cfee":[5,0,8,30,43],
+"class_ogre_1_1_texture.html#a6c5c6be0ec434481a055ab6b03b644fd":[5,0,8,30,46],
+"class_ogre_1_1_texture.html#a6ed49ed8701feb087b04b730ce1d682f":[5,0,8,30,33],
+"class_ogre_1_1_texture.html#a6f186da4d9557d958779eba68bb769a9":[5,0,8,30,7],
+"class_ogre_1_1_texture.html#a6f1a52798479255a174b3c0ecba6a10c":[5,0,8,30,22],
+"class_ogre_1_1_texture.html#a743e5059501507cd858e90532e8263f9":[5,0,8,30,17],
+"class_ogre_1_1_texture.html#a7bb75d68800a258c0ccaa34b3c23e2f2":[5,0,8,30,28],
+"class_ogre_1_1_texture.html#a7bd0ddb623f9d7b01fb272db8296cc72":[5,0,8,30,35],
+"class_ogre_1_1_texture.html#a7c7b9de76ae4ffc29f4d75b6f9bf899a":[5,0,8,30,34],
+"class_ogre_1_1_texture.html#a7eded50cabb3e9dbeeee531c168016da":[5,0,8,30,25],
+"class_ogre_1_1_texture.html#a8ed6a95810f21f53aa8cbc780b680164":[5,0,8,30,31],
+"class_ogre_1_1_texture.html#a90ce19013c81301e656ba110fcc01728":[5,0,8,30,39],
+"class_ogre_1_1_texture.html#a963616fe631db2b5bef45234a15bff7f":[5,0,8,30,41],
+"class_ogre_1_1_texture.html#aa539a94d1bd9ea8f4e804093be538c3e":[5,0,8,30,50],
+"class_ogre_1_1_texture.html#aadcef30707e8e10fbac61d65e1e73e52":[5,0,8,30,19],
+"class_ogre_1_1_texture.html#ab81b8c120556a1edf4c42d92abc9baf4":[5,0,8,30,42],
+"class_ogre_1_1_texture.html#aba1e54055a50692510da87d5d3eb5de1":[5,0,8,30,36],
+"class_ogre_1_1_texture.html#ac7eab6fa3b2133384bf2d92b4f5a2a99":[5,0,8,30,20],
+"class_ogre_1_1_texture.html#ac93f17feff099035542be8b22f890417":[5,0,8,30,8],
+"class_ogre_1_1_texture.html#accfa5467ab8ccfc5920ec64101f8f532":[5,0,8,30,47],
+"class_ogre_1_1_texture.html#ad1c33ba2014eeb134c8ce932f2a43418":[5,0,8,30,16],
+"class_ogre_1_1_texture.html#ad233adde489a5b2129eb20fc93952839":[5,0,8,30,49],
+"class_ogre_1_1_texture.html#ad3c315f415bb89c7646795bcee44acb7":[5,0,8,30,26],
+"class_ogre_1_1_texture.html#ad512f6f88086986f58b36bf526ce4631":[5,0,8,30,44],
+"class_ogre_1_1_texture.html#ad8faaf7732b48e059f7d7dc15667f2af":[5,0,8,30,9],
+"class_ogre_1_1_texture.html#ae272c029efa4b04406a58e01cd8ea7e8":[5,0,8,30,21],
+"class_ogre_1_1_texture.html#ae32d1cfbbb44d87d698aae547ecda35f":[5,0,8,30,10],
+"class_ogre_1_1_texture.html#aec390502f63927ed9470ba423ea66f64":[5,0,8,30,23],
+"class_ogre_1_1_texture.html#aed5a7915c939adae12ed3313d4d1f9c0":[5,0,8,30,4],
+"class_ogre_1_1_texture.html#aee3fd3170df592c3cc679cc38d3d9f60":[5,0,8,30,18],
+"class_ogre_1_1_texture.html#aee662e54343ef66ec2835de723908735":[5,0,8,30,37],
+"class_ogre_1_1_texture.html#aef9b4ae468fdabbd98af5371f870437a":[5,0,8,30,14],
 "class_ogre_1_1_texture_animator_affector.html":[5,2,10,17],
 "class_ogre_1_1_texture_animator_affector.html#a2b76673b2141ce52caa88e84e831214f":[5,2,10,17,0],
 "class_ogre_1_1_texture_animator_affector.html#a4acccf7a108334a04777e9491b18a6f1":[5,2,10,17,5],
@@ -231,23 +249,5 @@ var NAVTREEINDEX45 =
 "class_ogre_1_1_texture_unit_state.html#a56edced19709cbda365eae03b590a5e1":[5,0,5,21,98],
 "class_ogre_1_1_texture_unit_state.html#a58f878d9806be4ce5d709d51a9e0155a":[5,0,5,21,121],
 "class_ogre_1_1_texture_unit_state.html#a5a54ece0b8cfb20f6dcddbd68813be43":[5,0,5,21,70],
-"class_ogre_1_1_texture_unit_state.html#a5b84e5d0d23e8f405a3365d7650f429f":[5,0,5,21,94],
-"class_ogre_1_1_texture_unit_state.html#a5bb9b54d2869c429591b36f64d4361c5":[5,0,5,21,108],
-"class_ogre_1_1_texture_unit_state.html#a5c9a53ddea4dbdd68c1c42579ddc7fe8":[5,0,5,21,84],
-"class_ogre_1_1_texture_unit_state.html#a5da15b05f88f28597b0eb6e400e6242a":[5,0,5,21,17],
-"class_ogre_1_1_texture_unit_state.html#a5f3994ce2f61c6c6fee6fe8f89c9e369":[5,0,5,21,85],
-"class_ogre_1_1_texture_unit_state.html#a618396457ab8e0f225fbed04f6405b7a":[5,0,5,21,57],
-"class_ogre_1_1_texture_unit_state.html#a6236e0e398c153980ff06f13e58a667b":[5,0,5,21,128],
-"class_ogre_1_1_texture_unit_state.html#a66a53409852d79a7f02a8c19dc405092":[5,0,5,21,27],
-"class_ogre_1_1_texture_unit_state.html#a68034fde4bd5f0251e96d62349a903ba":[5,0,5,21,23],
-"class_ogre_1_1_texture_unit_state.html#a69a867f544a08845a86acc421476c3e4":[5,0,5,21,124],
-"class_ogre_1_1_texture_unit_state.html#a6decf13e49ebeafb9556479fb2022286":[5,0,5,21,36],
-"class_ogre_1_1_texture_unit_state.html#a6f72591d73c9149b4c5a5286a4604002":[5,0,5,21,60],
-"class_ogre_1_1_texture_unit_state.html#a702d2aee57c42cff6f34be00dc175fbc":[5,0,5,21,37],
-"class_ogre_1_1_texture_unit_state.html#a70c763dde05e95d72de2da1811c521c3":[5,0,5,21,16],
-"class_ogre_1_1_texture_unit_state.html#a715a727d3d85afa4776d49d6a969d1f4":[5,0,5,21,99],
-"class_ogre_1_1_texture_unit_state.html#a717b14961a636b3a18b8ab3dcef61626":[5,0,5,21,4],
-"class_ogre_1_1_texture_unit_state.html#a717b14961a636b3a18b8ab3dcef61626a2f0676d96ba378e32c3087fff9b7e73e":[5,0,5,21,4,0],
-"class_ogre_1_1_texture_unit_state.html#a717b14961a636b3a18b8ab3dcef61626a97cd551c90f9f6000fe231f542815852":[5,0,5,21,4,6],
-"class_ogre_1_1_texture_unit_state.html#a717b14961a636b3a18b8ab3dcef61626a97f8687c21d13e08b89d22902919acaa":[5,0,5,21,4,4]
+"class_ogre_1_1_texture_unit_state.html#a5b84e5d0d23e8f405a3365d7650f429f":[5,0,5,21,94]
 };
