@@ -1,5 +1,44 @@
 var NAVTREEINDEX61 =
 {
+"struct_ogre_1_1_lod_data_1_1_line.html#a6c8c2f0378dfce136a5b6e79e49f14cc":[5,1,2,3,3,5],
+"struct_ogre_1_1_lod_data_1_1_line.html#a9d5d9481ebf1384d3b1e7ee066a3768e":[5,1,2,3,3,3],
+"struct_ogre_1_1_lod_data_1_1_line.html#aa3e7051195f159e7a4ad8cfccb7e2f5b":[5,1,2,3,3,4],
+"struct_ogre_1_1_lod_data_1_1_line.html#aab02955a79f8ffb4676372031882fe79":[5,1,2,3,3,2],
+"struct_ogre_1_1_lod_data_1_1_line.html#abb571b93d022eacae313686662ac79d7":[5,1,2,3,3,1],
+"struct_ogre_1_1_lod_data_1_1_line.html#afff2de53d66875fc01c9815971dab96d":[5,1,2,3,3,6],
+"struct_ogre_1_1_lod_data_1_1_line.html#afff4d1507e0433c6cec166f00538e29c":[5,1,2,3,3,0],
+"struct_ogre_1_1_lod_data_1_1_triangle.html":[5,1,2,3,4],
+"struct_ogre_1_1_lod_data_1_1_triangle.html#a4eecf20b323ee21ea4c31a09abe54cd0":[5,1,2,3,4,7],
+"struct_ogre_1_1_lod_data_1_1_triangle.html#a4fbb1fc10853e3adc0116c3f5660487e":[5,1,2,3,4,0],
+"struct_ogre_1_1_lod_data_1_1_triangle.html#a5987bfe02a3d1aa1eb732a8a019558a9":[5,1,2,3,4,2],
+"struct_ogre_1_1_lod_data_1_1_triangle.html#a7f2b4a5ba3690ab520e445918935e525":[5,1,2,3,4,1],
+"struct_ogre_1_1_lod_data_1_1_triangle.html#ab43218cda5bc70a6c6e5f084a1a5ec7b":[5,1,2,3,4,3],
+"struct_ogre_1_1_lod_data_1_1_triangle.html#ac177a86ec820bd4bdf9ab1578132885e":[5,1,2,3,4,5],
+"struct_ogre_1_1_lod_data_1_1_triangle.html#ad3d2f1e41bdf70e19007938074b2cf0e":[5,1,2,3,4,6],
+"struct_ogre_1_1_lod_data_1_1_triangle.html#af4011d8be274ea62d50b8f8ef5eb89a6":[5,1,2,3,4,4],
+"struct_ogre_1_1_lod_data_1_1_triangle.html#aff1395c324d8808f43dcc76b8a5cdb3b":[5,1,2,3,4,8],
+"struct_ogre_1_1_lod_data_1_1_vertex.html":[5,1,2,3,5],
+"struct_ogre_1_1_lod_data_1_1_vertex.html#a0f4e1115ab3949faaf58aff5b08b1cd9":[5,1,2,3,5,9],
+"struct_ogre_1_1_lod_data_1_1_vertex.html#a2dd4f26fe6707cac4b003f727271ff5e":[5,1,2,3,5,8],
+"struct_ogre_1_1_lod_data_1_1_vertex.html#a30e6002e8806af7c72eb4dc97d8806f2":[5,1,2,3,5,6],
+"struct_ogre_1_1_lod_data_1_1_vertex.html#a4df65828c129283e5430d3c5df18d33d":[5,1,2,3,5,2],
+"struct_ogre_1_1_lod_data_1_1_vertex.html#a54d42759d6ab25e25bd52d34a7e656c6":[5,1,2,3,5,5],
+"struct_ogre_1_1_lod_data_1_1_vertex.html#a613e76486834495df006789d8824210b":[5,1,2,3,5,7],
+"struct_ogre_1_1_lod_data_1_1_vertex.html#a6f356c0b5a1a3dcc5f999be8cc977fe0":[5,1,2,3,5,4],
+"struct_ogre_1_1_lod_data_1_1_vertex.html#a94742e7f49c5ffdfb8fca2b1bff798bb":[5,1,2,3,5,0],
+"struct_ogre_1_1_lod_data_1_1_vertex.html#aaa8e2eecfc5912d6958e65ecdf12d053":[5,1,2,3,5,1],
+"struct_ogre_1_1_lod_data_1_1_vertex.html#ae45e43886c93e953d78cda1d84501ad5":[5,1,2,3,5,3],
+"struct_ogre_1_1_lod_data_1_1_vertex_equal.html":[5,1,2,3,6],
+"struct_ogre_1_1_lod_data_1_1_vertex_equal.html#a3cdf3e47024745b729a4801e1c5a924a":[5,1,2,3,6,0],
+"struct_ogre_1_1_lod_data_1_1_vertex_hash.html":[5,1,2,3,7],
+"struct_ogre_1_1_lod_data_1_1_vertex_hash.html#a2a0bae6ff8fab851d848fb8c225673b8":[5,1,2,3,7,0],
+"struct_ogre_1_1_lod_data_1_1_vertex_hash.html#a855695516ff2d3f0f8547150e0230e08":[5,1,2,3,7,2],
+"struct_ogre_1_1_lod_data_1_1_vertex_hash.html#aa103133087a79ad877cfe4a50f12af22":[5,1,2,3,7,1],
+"struct_ogre_1_1_lod_data_1_1_vertex_hash.html#aae427738b413ac6e1b2e040cc49760d6":[5,1,2,3,7,3],
+"struct_ogre_1_1_lod_level.html":[5,1,2,4],
+"struct_ogre_1_1_lod_level.html#a10d85c3d0d1f9a03019a9abc76cf70d1":[5,1,2,4,3],
+"struct_ogre_1_1_lod_level.html#a39e40bdcbeea13357ace7e38e53446e3":[5,1,2,4,0],
+"struct_ogre_1_1_lod_level.html#a39e40bdcbeea13357ace7e38e53446e3a484813e3eee23b35e7377eb8f225c9c4":[5,1,2,4,0,2],
 "struct_ogre_1_1_lod_level.html#a39e40bdcbeea13357ace7e38e53446e3abb3bbdf3ae9b38c77e31e09e92e46b55":[5,1,2,4,0,1],
 "struct_ogre_1_1_lod_level.html#a39e40bdcbeea13357ace7e38e53446e3afe36984fdb5b516b5bc79f53d3e48699":[5,1,2,4,0,0],
 "struct_ogre_1_1_lod_level.html#a45b8fffff2bc5dc6d29967a7678421e2":[5,1,2,4,2],
@@ -98,30 +137,30 @@ var NAVTREEINDEX61 =
 "struct_ogre_1_1_ray_scene_query_result_entry.html#a58ba184768924a39ab195dcf96472f65":[5,0,9,35,2],
 "struct_ogre_1_1_ray_scene_query_result_entry.html#acc6655f373532d7b9d3017acab7535a9":[5,0,9,35,3],
 "struct_ogre_1_1_ray_scene_query_result_entry.html#af3e8eed523c4215c5733a9886db7ec29":[5,0,9,35,1],
-"struct_ogre_1_1_render_target_1_1_frame_stats.html":[5,0,7,29,0],
-"struct_ogre_1_1_render_target_1_1_frame_stats.html#a12556de54d8ea0ca7ccf064a07d25389":[5,0,7,29,0,0],
-"struct_ogre_1_1_render_target_1_1_frame_stats.html#a252574d63b453563ed4b22ff574fc10b":[5,0,7,29,0,8],
-"struct_ogre_1_1_render_target_1_1_frame_stats.html#a49f1dd55396299921e69e1d7ed66c0fc":[5,0,7,29,0,3],
-"struct_ogre_1_1_render_target_1_1_frame_stats.html#a4e2453ac395f96a11a966f18590610e0":[5,0,7,29,0,1],
-"struct_ogre_1_1_render_target_1_1_frame_stats.html#a6b4e063f6df89d63021022eb8f43d91c":[5,0,7,29,0,7],
-"struct_ogre_1_1_render_target_1_1_frame_stats.html#a720bee3828b5c2d2419e7afbeed0191e":[5,0,7,29,0,4],
-"struct_ogre_1_1_render_target_1_1_frame_stats.html#a7536670fa555a4f05c52ccdacc9c2194":[5,0,7,29,0,5],
-"struct_ogre_1_1_render_target_1_1_frame_stats.html#ab07828877ca7c352d1a8b1afaab1df08":[5,0,7,29,0,2],
-"struct_ogre_1_1_render_target_1_1_frame_stats.html#ab1bf6f713ee6774a371fdf74f2ffaf44":[5,0,7,29,0,6],
-"struct_ogre_1_1_render_target_event.html":[5,0,7,30],
-"struct_ogre_1_1_render_target_event.html#aceb69f7a9bbb3b126fea2bfded331a41":[5,0,7,30,0],
-"struct_ogre_1_1_render_target_viewport_event.html":[5,0,7,32],
-"struct_ogre_1_1_render_target_viewport_event.html#ad70a30225c318f3f6e3fc20b5edc34f6":[5,0,7,32,0],
+"struct_ogre_1_1_render_target_1_1_frame_stats.html":[5,0,7,30,0],
+"struct_ogre_1_1_render_target_1_1_frame_stats.html#a12556de54d8ea0ca7ccf064a07d25389":[5,0,7,30,0,0],
+"struct_ogre_1_1_render_target_1_1_frame_stats.html#a252574d63b453563ed4b22ff574fc10b":[5,0,7,30,0,8],
+"struct_ogre_1_1_render_target_1_1_frame_stats.html#a49f1dd55396299921e69e1d7ed66c0fc":[5,0,7,30,0,3],
+"struct_ogre_1_1_render_target_1_1_frame_stats.html#a4e2453ac395f96a11a966f18590610e0":[5,0,7,30,0,1],
+"struct_ogre_1_1_render_target_1_1_frame_stats.html#a6b4e063f6df89d63021022eb8f43d91c":[5,0,7,30,0,7],
+"struct_ogre_1_1_render_target_1_1_frame_stats.html#a720bee3828b5c2d2419e7afbeed0191e":[5,0,7,30,0,4],
+"struct_ogre_1_1_render_target_1_1_frame_stats.html#a7536670fa555a4f05c52ccdacc9c2194":[5,0,7,30,0,5],
+"struct_ogre_1_1_render_target_1_1_frame_stats.html#ab07828877ca7c352d1a8b1afaab1df08":[5,0,7,30,0,2],
+"struct_ogre_1_1_render_target_1_1_frame_stats.html#ab1bf6f713ee6774a371fdf74f2ffaf44":[5,0,7,30,0,6],
+"struct_ogre_1_1_render_target_event.html":[5,0,7,31],
+"struct_ogre_1_1_render_target_event.html#aceb69f7a9bbb3b126fea2bfded331a41":[5,0,7,31,0],
+"struct_ogre_1_1_render_target_viewport_event.html":[5,0,7,33],
+"struct_ogre_1_1_render_target_viewport_event.html#ad70a30225c318f3f6e3fc20b5edc34f6":[5,0,7,33,0],
 "struct_ogre_1_1_render_window_description.html":[5,0,2,38],
 "struct_ogre_1_1_render_window_description.html#a0dfc7a4ce6e13696ce64de821cd551b4":[5,0,2,38,1],
 "struct_ogre_1_1_render_window_description.html#a3608fbf0281bd14dd5ddb0a2d5753e7b":[5,0,2,38,0],
 "struct_ogre_1_1_render_window_description.html#a5809e1727a29bbc2737e090ab338c6a7":[5,0,2,38,3],
 "struct_ogre_1_1_render_window_description.html#a9d041f83279956a42785c6894bea178a":[5,0,2,38,4],
 "struct_ogre_1_1_render_window_description.html#aef01dea93700872d39d4a59bd91a436c":[5,0,2,38,2],
-"struct_ogre_1_1_renderable_pass.html":[5,0,7,19],
-"struct_ogre_1_1_renderable_pass.html#a88788b24efb00ee4d9cf8c4b75cf06ee":[5,0,7,19,1],
-"struct_ogre_1_1_renderable_pass.html#aced02c6752335dbd5bd4ff1681c35882":[5,0,7,19,0],
-"struct_ogre_1_1_renderable_pass.html#aec7289b1a870e7c39d83b5d422792990":[5,0,7,19,2],
+"struct_ogre_1_1_renderable_pass.html":[5,0,7,20],
+"struct_ogre_1_1_renderable_pass.html#a88788b24efb00ee4d9cf8c4b75cf06ee":[5,0,7,20,1],
+"struct_ogre_1_1_renderable_pass.html#aced02c6752335dbd5bd4ff1681c35882":[5,0,7,20,0],
+"struct_ogre_1_1_renderable_pass.html#aec7289b1a870e7c39d83b5d422792990":[5,0,7,20,2],
 "struct_ogre_1_1_resource_group_manager_1_1_resource_declaration.html":[5,0,8,25,0],
 "struct_ogre_1_1_resource_group_manager_1_1_resource_declaration.html#a9322aeaf8777145d9fb4d71d30d133f3":[5,0,8,25,0,2],
 "struct_ogre_1_1_resource_group_manager_1_1_resource_declaration.html#aae401b65d364881e950953a3a15e2977":[5,0,8,25,0,1],
@@ -161,13 +200,19 @@ var NAVTREEINDEX61 =
 "struct_ogre_1_1_scene_query_result.html":[5,0,9,44],
 "struct_ogre_1_1_scene_query_result.html#a2224618a99dc451317e56082697b1ffa":[5,0,9,44,0],
 "struct_ogre_1_1_scene_query_result.html#a8157783aec3ca4d9566a9a6bfe08fee0":[5,0,9,44,1],
+"struct_ogre_1_1_script_property.html":[5,0,10,18],
+"struct_ogre_1_1_script_property.html#aae91544dee17a2f8028732d1404719cc":[5,0,10,18,0],
+"struct_ogre_1_1_script_property.html#aba8d6c0d51dd2971db043539fd03cdd6":[5,0,10,18,1],
 "struct_ogre_1_1_shadow_texture_config.html":[5,0,9,48],
-"struct_ogre_1_1_shadow_texture_config.html#a0c27fe5c351d3697932ead1893ddf16d":[5,0,9,48,2],
+"struct_ogre_1_1_shadow_texture_config.html#a053023342eba93e143f0aa9123bf9321":[5,0,9,48,2],
+"struct_ogre_1_1_shadow_texture_config.html#a05f9256c78c82e4f36a451a3a638b7ac":[5,0,9,48,7],
 "struct_ogre_1_1_shadow_texture_config.html#a1572e06277a6253f88d16891a3a8aa25":[5,0,9,48,0],
-"struct_ogre_1_1_shadow_texture_config.html#a7babac3b47c252bb20167395eabaccad":[5,0,9,48,4],
-"struct_ogre_1_1_shadow_texture_config.html#a90f0b94c8b385c5df3cd1b39fd5b0e56":[5,0,9,48,1],
-"struct_ogre_1_1_shadow_texture_config.html#abeaa5079ee032be898755c74bdd6ec10":[5,0,9,48,3],
+"struct_ogre_1_1_shadow_texture_config.html#a57081abac8f1811af9cd08b597301880":[5,0,9,48,8],
+"struct_ogre_1_1_shadow_texture_config.html#aada271949132af7d1d42f0a095fe445b":[5,0,9,48,6],
+"struct_ogre_1_1_shadow_texture_config.html#abeaa5079ee032be898755c74bdd6ec10":[5,0,9,48,4],
 "struct_ogre_1_1_shadow_texture_config.html#adff6099049e80aea87663b51d7e3659b":[5,0,9,48,5],
+"struct_ogre_1_1_shadow_texture_config.html#af016c8aa25c2e69ad8c2ffef079b4fab":[5,0,9,48,3],
+"struct_ogre_1_1_shadow_texture_config.html#afcbaf606f670b67fedec29edc8fd6fa2":[5,0,9,48,1],
 "struct_ogre_1_1_shadow_texture_listener.html":[5,0,9,49],
 "struct_ogre_1_1_shadow_texture_listener.html#a2c3b422f5a41d7dcc96e34a28f0bb5a6":[5,0,9,49,3],
 "struct_ogre_1_1_shadow_texture_listener.html#ab6d58e66a561228441a4fad1221e9ee5":[5,0,9,49,2],
@@ -202,52 +247,7 @@ var NAVTREEINDEX61 =
 "struct_ogre_1_1_static_geometry_1_1_sub_mesh_lod_geometry_link.html":[5,0,9,54,7],
 "struct_ogre_1_1_static_geometry_1_1_sub_mesh_lod_geometry_link.html#a156a3afb790d7e13663cbd7ee45faac6":[5,0,9,54,7,0],
 "struct_ogre_1_1_static_geometry_1_1_sub_mesh_lod_geometry_link.html#ac387382c92a7e1c59757e86e289e589f":[5,0,9,54,7,1],
-"struct_ogre_1_1_stencil_state.html":[5,0,7,36],
-"struct_ogre_1_1_stencil_state.html#a178cb5765005a2a6a2399f4b5a67c2da":[5,0,7,36,7],
-"struct_ogre_1_1_stencil_state.html#a17b6487c48555618f75e682471efd345":[5,0,7,36,2],
-"struct_ogre_1_1_stencil_state.html#a5abe9dfb9146a8f88215d9a6e7b19a69":[5,0,7,36,6],
-"struct_ogre_1_1_stencil_state.html#a6c1af2c044e18c174ad1a4c276eac99d":[5,0,7,36,1],
-"struct_ogre_1_1_stencil_state.html#a7db76a23582f4500f328f22cb0112386":[5,0,7,36,4],
-"struct_ogre_1_1_stencil_state.html#a910a15c9871829f8f7e31d7e3ba60ee7":[5,0,7,36,9],
-"struct_ogre_1_1_stencil_state.html#aa544ef160e7d2b91ae05579a9e0da0d9":[5,0,7,36,8],
-"struct_ogre_1_1_stencil_state.html#ac734c4ab2c3919628af26b18d4533561":[5,0,7,36,3],
-"struct_ogre_1_1_stencil_state.html#ac7908e28db55fff8dcc932c3acb10fc0":[5,0,7,36,5],
-"struct_ogre_1_1_stencil_state.html#ad81c5c9f6a898190ba9b9dee096e0d5e":[5,0,7,36,0],
-"struct_ogre_1_1_stream_serialiser_1_1_chunk.html":[5,0,8,28,0],
-"struct_ogre_1_1_stream_serialiser_1_1_chunk.html#a53db274d39b9f3d328cdefb67bbc0f00":[5,0,8,28,0,4],
-"struct_ogre_1_1_stream_serialiser_1_1_chunk.html#a5b7d48d0df881bcc1b0b3035c355fbca":[5,0,8,28,0,2],
-"struct_ogre_1_1_stream_serialiser_1_1_chunk.html#a5ff82e35d66f9ae31a67612359f186f6":[5,0,8,28,0,1],
-"struct_ogre_1_1_stream_serialiser_1_1_chunk.html#aa96c50461348d92b92ff435612c0f5a7":[5,0,8,28,0,0],
-"struct_ogre_1_1_stream_serialiser_1_1_chunk.html#aee59026e7658bc15408b2f92ee1140cb":[5,0,8,28,0,3],
-"struct_ogre_1_1_t_rect.html":[5,0,2,49],
-"struct_ogre_1_1_t_rect.html#a007a629729ff41b80dee4f5536303a48":[5,0,2,49,4],
-"struct_ogre_1_1_t_rect.html#a36f08aa8d3949185a90a55372a1fb389":[5,0,2,49,15],
-"struct_ogre_1_1_t_rect.html#a3d4c7c687b7b2048d25f228decfda2ff":[5,0,2,49,5],
-"struct_ogre_1_1_t_rect.html#a4b857f788936dbeeb63ac64fc5e9fb99":[5,0,2,49,7],
-"struct_ogre_1_1_t_rect.html#a4ffdac43c6f8bf4cf11d99b0c8d373e9":[5,0,2,49,8],
-"struct_ogre_1_1_t_rect.html#a54b9de090a6cc533511d51d2bb9b0b82":[5,0,2,49,13],
-"struct_ogre_1_1_t_rect.html#a56b6ad37d298b66bc7366431f6f786b5":[5,0,2,49,14],
-"struct_ogre_1_1_t_rect.html#a79e390fbd62e5a819207d6aee0789ab5":[5,0,2,49,1],
-"struct_ogre_1_1_t_rect.html#a7c3608ca022c17746daba4bc2c9cc684":[5,0,2,49,9],
-"struct_ogre_1_1_t_rect.html#a7f8310e37638f8790a89f2dd64ff3fe1":[5,0,2,49,12],
-"struct_ogre_1_1_t_rect.html#a8eb31a62c22984e237d810c1eca91cfc":[5,0,2,49,3],
-"struct_ogre_1_1_t_rect.html#a91f3cea3b1851f9b4b9004df78822678":[5,0,2,49,0],
-"struct_ogre_1_1_t_rect.html#a98e85913ff205674c4fb04ae6ffb2149":[5,0,2,49,10],
-"struct_ogre_1_1_t_rect.html#aaf94532ce0aaa722ff067be346fa15b1":[5,0,2,49,2],
-"struct_ogre_1_1_t_rect.html#ae10811e4b63a67ad69fd72a577ed4326":[5,0,2,49,11],
-"struct_ogre_1_1_t_rect.html#aee06d09a12b3a5acba200976aa6386ea":[5,0,2,49,6],
-"struct_ogre_1_1_tangent_space_calc_1_1_index_remap.html":[5,0,6,22,0],
-"struct_ogre_1_1_tangent_space_calc_1_1_index_remap.html#a0b95b1be05110b59c87d44378f8f2d4b":[5,0,6,22,0,2],
-"struct_ogre_1_1_tangent_space_calc_1_1_index_remap.html#a28ce54b6e709aa61689b4565cd0acf68":[5,0,6,22,0,4],
-"struct_ogre_1_1_tangent_space_calc_1_1_index_remap.html#a477c9b282bb1275c79472224d890cab5":[5,0,6,22,0,3],
-"struct_ogre_1_1_tangent_space_calc_1_1_index_remap.html#a6d5e329458cea922c5d62eaf814b4883":[5,0,6,22,0,1],
-"struct_ogre_1_1_tangent_space_calc_1_1_index_remap.html#a77c5b41921797ecfc47252bd99f789aa":[5,0,6,22,0,0],
-"struct_ogre_1_1_tangent_space_calc_1_1_result.html":[5,0,6,22,1],
-"struct_ogre_1_1_tangent_space_calc_1_1_result.html#a0e5e34d6936c7a3e76ad6e4d03688df8":[5,0,6,22,1,1],
-"struct_ogre_1_1_tangent_space_calc_1_1_result.html#adc7a5f1543644476242dfad6552342b6":[5,0,6,22,1,0],
-"struct_ogre_1_1_technique_1_1_g_p_u_device_name_rule.html":[5,0,5,20,0],
-"struct_ogre_1_1_technique_1_1_g_p_u_device_name_rule.html#a3425c07d9ce84c5a7fa0c765b7dde8db":[5,0,5,20,0,2],
-"struct_ogre_1_1_technique_1_1_g_p_u_device_name_rule.html#a36e883f304b07d95ca55fea67f416d05":[5,0,5,20,0,4],
-"struct_ogre_1_1_technique_1_1_g_p_u_device_name_rule.html#a5f70092f87cc455575f83813afb0ce53":[5,0,5,20,0,1],
-"struct_ogre_1_1_technique_1_1_g_p_u_device_name_rule.html#ad912c591fde5ff1b38c2db11ae44d74c":[5,0,5,20,0,0]
+"struct_ogre_1_1_stencil_state.html":[5,0,7,37],
+"struct_ogre_1_1_stencil_state.html#a178cb5765005a2a6a2399f4b5a67c2da":[5,0,7,37,7],
+"struct_ogre_1_1_stencil_state.html#a17b6487c48555618f75e682471efd345":[5,0,7,37,2]
 };
