@@ -1,5 +1,50 @@
 var NAVTREEINDEX62 =
 {
+"struct_ogre_1_1_stencil_state.html#a5abe9dfb9146a8f88215d9a6e7b19a69":[5,0,7,37,6],
+"struct_ogre_1_1_stencil_state.html#a6c1af2c044e18c174ad1a4c276eac99d":[5,0,7,37,1],
+"struct_ogre_1_1_stencil_state.html#a7db76a23582f4500f328f22cb0112386":[5,0,7,37,4],
+"struct_ogre_1_1_stencil_state.html#a910a15c9871829f8f7e31d7e3ba60ee7":[5,0,7,37,9],
+"struct_ogre_1_1_stencil_state.html#aa544ef160e7d2b91ae05579a9e0da0d9":[5,0,7,37,8],
+"struct_ogre_1_1_stencil_state.html#ac734c4ab2c3919628af26b18d4533561":[5,0,7,37,3],
+"struct_ogre_1_1_stencil_state.html#ac7908e28db55fff8dcc932c3acb10fc0":[5,0,7,37,5],
+"struct_ogre_1_1_stencil_state.html#ad81c5c9f6a898190ba9b9dee096e0d5e":[5,0,7,37,0],
+"struct_ogre_1_1_stream_serialiser_1_1_chunk.html":[5,0,8,28,0],
+"struct_ogre_1_1_stream_serialiser_1_1_chunk.html#a53db274d39b9f3d328cdefb67bbc0f00":[5,0,8,28,0,4],
+"struct_ogre_1_1_stream_serialiser_1_1_chunk.html#a5b7d48d0df881bcc1b0b3035c355fbca":[5,0,8,28,0,2],
+"struct_ogre_1_1_stream_serialiser_1_1_chunk.html#a5ff82e35d66f9ae31a67612359f186f6":[5,0,8,28,0,1],
+"struct_ogre_1_1_stream_serialiser_1_1_chunk.html#aa96c50461348d92b92ff435612c0f5a7":[5,0,8,28,0,0],
+"struct_ogre_1_1_stream_serialiser_1_1_chunk.html#aee59026e7658bc15408b2f92ee1140cb":[5,0,8,28,0,3],
+"struct_ogre_1_1_t_rect.html":[5,0,2,49],
+"struct_ogre_1_1_t_rect.html#a007a629729ff41b80dee4f5536303a48":[5,0,2,49,4],
+"struct_ogre_1_1_t_rect.html#a36f08aa8d3949185a90a55372a1fb389":[5,0,2,49,15],
+"struct_ogre_1_1_t_rect.html#a3d4c7c687b7b2048d25f228decfda2ff":[5,0,2,49,5],
+"struct_ogre_1_1_t_rect.html#a4b857f788936dbeeb63ac64fc5e9fb99":[5,0,2,49,7],
+"struct_ogre_1_1_t_rect.html#a4ffdac43c6f8bf4cf11d99b0c8d373e9":[5,0,2,49,8],
+"struct_ogre_1_1_t_rect.html#a54b9de090a6cc533511d51d2bb9b0b82":[5,0,2,49,13],
+"struct_ogre_1_1_t_rect.html#a56b6ad37d298b66bc7366431f6f786b5":[5,0,2,49,14],
+"struct_ogre_1_1_t_rect.html#a79e390fbd62e5a819207d6aee0789ab5":[5,0,2,49,1],
+"struct_ogre_1_1_t_rect.html#a7c3608ca022c17746daba4bc2c9cc684":[5,0,2,49,9],
+"struct_ogre_1_1_t_rect.html#a7f8310e37638f8790a89f2dd64ff3fe1":[5,0,2,49,12],
+"struct_ogre_1_1_t_rect.html#a8eb31a62c22984e237d810c1eca91cfc":[5,0,2,49,3],
+"struct_ogre_1_1_t_rect.html#a91f3cea3b1851f9b4b9004df78822678":[5,0,2,49,0],
+"struct_ogre_1_1_t_rect.html#a98e85913ff205674c4fb04ae6ffb2149":[5,0,2,49,10],
+"struct_ogre_1_1_t_rect.html#aaf94532ce0aaa722ff067be346fa15b1":[5,0,2,49,2],
+"struct_ogre_1_1_t_rect.html#ae10811e4b63a67ad69fd72a577ed4326":[5,0,2,49,11],
+"struct_ogre_1_1_t_rect.html#aee06d09a12b3a5acba200976aa6386ea":[5,0,2,49,6],
+"struct_ogre_1_1_tangent_space_calc_1_1_index_remap.html":[5,0,6,22,0],
+"struct_ogre_1_1_tangent_space_calc_1_1_index_remap.html#a0b95b1be05110b59c87d44378f8f2d4b":[5,0,6,22,0,2],
+"struct_ogre_1_1_tangent_space_calc_1_1_index_remap.html#a28ce54b6e709aa61689b4565cd0acf68":[5,0,6,22,0,4],
+"struct_ogre_1_1_tangent_space_calc_1_1_index_remap.html#a477c9b282bb1275c79472224d890cab5":[5,0,6,22,0,3],
+"struct_ogre_1_1_tangent_space_calc_1_1_index_remap.html#a6d5e329458cea922c5d62eaf814b4883":[5,0,6,22,0,1],
+"struct_ogre_1_1_tangent_space_calc_1_1_index_remap.html#a77c5b41921797ecfc47252bd99f789aa":[5,0,6,22,0,0],
+"struct_ogre_1_1_tangent_space_calc_1_1_result.html":[5,0,6,22,1],
+"struct_ogre_1_1_tangent_space_calc_1_1_result.html#a0e5e34d6936c7a3e76ad6e4d03688df8":[5,0,6,22,1,1],
+"struct_ogre_1_1_tangent_space_calc_1_1_result.html#adc7a5f1543644476242dfad6552342b6":[5,0,6,22,1,0],
+"struct_ogre_1_1_technique_1_1_g_p_u_device_name_rule.html":[5,0,5,20,0],
+"struct_ogre_1_1_technique_1_1_g_p_u_device_name_rule.html#a3425c07d9ce84c5a7fa0c765b7dde8db":[5,0,5,20,0,2],
+"struct_ogre_1_1_technique_1_1_g_p_u_device_name_rule.html#a36e883f304b07d95ca55fea67f416d05":[5,0,5,20,0,4],
+"struct_ogre_1_1_technique_1_1_g_p_u_device_name_rule.html#a5f70092f87cc455575f83813afb0ce53":[5,0,5,20,0,1],
+"struct_ogre_1_1_technique_1_1_g_p_u_device_name_rule.html#ad912c591fde5ff1b38c2db11ae44d74c":[5,0,5,20,0,0],
 "struct_ogre_1_1_technique_1_1_g_p_u_device_name_rule.html#afa5cd604584285e1d9dfe42734461673":[5,0,5,20,0,3],
 "struct_ogre_1_1_technique_1_1_g_p_u_vendor_rule.html":[5,0,5,20,1],
 "struct_ogre_1_1_technique_1_1_g_p_u_vendor_rule.html#a60cb77ded55eb1fd08da385acf4ad903":[5,0,5,20,1,3],
@@ -104,103 +149,85 @@ var NAVTREEINDEX62 =
 "struct_ogre_1_1_transform_base_real.html#aef6aefde7236f81a2343af8a1d81da50":[5,0,6,24,7],
 "struct_ogre_1_1_vector_base.html":[5,0,6,26],
 "struct_ogre_1_1_vector_base.html#a1b21ec054398dd1389acf0be59e287a5":[5,0,6,26,6],
-"struct_ogre_1_1_vector_base.html#a1b21ec054398dd1389acf0be59e287a5":[5,0,6,27,23],
-"struct_ogre_1_1_vector_base.html#a1b21ec054398dd1389acf0be59e287a5":[5,0,6,28,30],
-"struct_ogre_1_1_vector_base.html#a1b21ec054398dd1389acf0be59e287a5":[5,0,6,29,15],
+"struct_ogre_1_1_vector_base.html#a1b21ec054398dd1389acf0be59e287a5":[5,0,6,27,17],
+"struct_ogre_1_1_vector_base.html#a1b21ec054398dd1389acf0be59e287a5":[5,0,6,28,24],
+"struct_ogre_1_1_vector_base.html#a1b21ec054398dd1389acf0be59e287a5":[5,0,6,29,9],
 "struct_ogre_1_1_vector_base.html#a3d840979e2f40a0c01c5bac850977da0":[5,0,6,26,0],
-"struct_ogre_1_1_vector_base.html#a3d840979e2f40a0c01c5bac850977da0":[5,0,6,27,2],
-"struct_ogre_1_1_vector_base.html#a3d840979e2f40a0c01c5bac850977da0":[5,0,6,28,2],
-"struct_ogre_1_1_vector_base.html#a3d840979e2f40a0c01c5bac850977da0":[5,0,6,29,2],
-"struct_ogre_1_1_vector_base.html#a4780e28e244b3fb69d259d161b01e9a1":[5,0,6,26,1],
-"struct_ogre_1_1_vector_base.html#a4780e28e244b3fb69d259d161b01e9a1":[5,0,6,27,3],
-"struct_ogre_1_1_vector_base.html#a4780e28e244b3fb69d259d161b01e9a1":[5,0,6,28,3],
-"struct_ogre_1_1_vector_base.html#a4780e28e244b3fb69d259d161b01e9a1":[5,0,6,29,3],
 "struct_ogre_1_1_vector_base.html#a68f9ad334839138f1bf767a517f6ba0b":[5,0,6,26,4],
-"struct_ogre_1_1_vector_base.html#a68f9ad334839138f1bf767a517f6ba0b":[5,0,6,27,13],
-"struct_ogre_1_1_vector_base.html#a68f9ad334839138f1bf767a517f6ba0b":[5,0,6,28,17],
-"struct_ogre_1_1_vector_base.html#a68f9ad334839138f1bf767a517f6ba0b":[5,0,6,29,8],
-"struct_ogre_1_1_vector_base.html#a9b095dcc7d2812780a6cbc1163568785":[5,0,6,26,2],
-"struct_ogre_1_1_vector_base.html#a9b095dcc7d2812780a6cbc1163568785":[5,0,6,27,4],
-"struct_ogre_1_1_vector_base.html#a9b095dcc7d2812780a6cbc1163568785":[5,0,6,28,4],
-"struct_ogre_1_1_vector_base.html#a9b095dcc7d2812780a6cbc1163568785":[5,0,6,29,4],
+"struct_ogre_1_1_vector_base.html#a770f1fd7df813537f69eca4cc61ce555":[5,0,6,26,2],
+"struct_ogre_1_1_vector_base.html#a8833fcb1880467e5797f3879bcd06aaa":[5,0,6,26,3],
 "struct_ogre_1_1_vector_base.html#a9caacd16230bd6ac7c00bcf40b05b055":[5,0,6,26,5],
-"struct_ogre_1_1_vector_base.html#a9caacd16230bd6ac7c00bcf40b05b055":[5,0,6,27,14],
-"struct_ogre_1_1_vector_base.html#a9caacd16230bd6ac7c00bcf40b05b055":[5,0,6,28,18],
-"struct_ogre_1_1_vector_base.html#a9caacd16230bd6ac7c00bcf40b05b055":[5,0,6,29,9],
-"struct_ogre_1_1_vector_base.html#af9ea7a5d9919e101efcca5e41b5d2705":[5,0,6,26,3],
-"struct_ogre_1_1_vector_base.html#af9ea7a5d9919e101efcca5e41b5d2705":[5,0,6,27,5],
-"struct_ogre_1_1_vector_base.html#af9ea7a5d9919e101efcca5e41b5d2705":[5,0,6,28,5],
-"struct_ogre_1_1_vector_base.html#af9ea7a5d9919e101efcca5e41b5d2705":[5,0,6,29,5],
+"struct_ogre_1_1_vector_base.html#ad48f47252d7d3ae236a833bc7697e26d":[5,0,6,26,1],
 "struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html":[5,0,6,27],
-"struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#a0c9cad7eaa9ffc11623f4bc6ae915ff2":[5,0,6,27,7],
-"struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#a1786bcda5c79f91d70d8d0789ed6ee66":[5,0,6,27,20],
-"struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#a4386098987c58adbe2dd4fedb0d19eed":[5,0,6,27,6],
-"struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#a5661dd38b03840383dc1a0cbea9199d9":[5,0,6,27,16],
-"struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#a5cf013c152017f5af5e3b4b0a93d726c":[5,0,6,27,21],
-"struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#a95a20cb8d244732ea5dadff4b8da7111":[5,0,6,27,15],
-"struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#a979837f10b7068528efc6802742f5509":[5,0,6,27,22],
-"struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#ab55e075045abe594d0b7d7b2d232ffe8":[5,0,6,27,9],
-"struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#ab771b243b99665aaff02505c273be9ee":[5,0,6,27,19],
+"struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#a0c9cad7eaa9ffc11623f4bc6ae915ff2":[5,0,6,27,3],
+"struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#a24347f74fc832748314c97d79ba27dd0":[5,0,6,27,15],
+"struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#a25af7d975810f608e06393996e3fcacd":[5,0,6,27,16],
+"struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#a4386098987c58adbe2dd4fedb0d19eed":[5,0,6,27,2],
+"struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#a45c5493f14897fd6b135472c3954fe44":[5,0,6,27,12],
+"struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#a5661dd38b03840383dc1a0cbea9199d9":[5,0,6,27,10],
+"struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#a8978a7c9582e993a9e9df67b3d567907":[5,0,6,27,11],
+"struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#a95a20cb8d244732ea5dadff4b8da7111":[5,0,6,27,9],
+"struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#aac109774d6f7e6888eb1b69df174f532":[5,0,6,27,1],
+"struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#ab55e075045abe594d0b7d7b2d232ffe8":[5,0,6,27,5],
 "struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#abdef156b8ae9ca99b2f6e63e545f93a3":[5,0,6,27,0],
-"struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#adeeb454e50949d89f71b52a38e52951e":[5,0,6,27,18],
-"struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#ae2f35d4cb19c32de559b6815badd425b":[5,0,6,27,1],
-"struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#af6df06c614a141cc90fb9fe28b0c34f9":[5,0,6,27,17],
+"struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#ad8f964d324fc0008eafc1dce1bf5e293":[5,0,6,27,13],
+"struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#ae52d6bca4f0de5abc8f5b9df2e14ae24":[5,0,6,27,14],
 "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html":[5,0,6,28],
-"struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a0a242b15c4c3a7181cc5a371b3f86fe3":[5,0,6,28,21],
-"struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a25a0d767f153bc408453ee85de866c87":[5,0,6,28,24],
-"struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a2e6b3a89e26268bde6f6347f363a6bd1":[5,0,6,28,19],
-"struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a2e8982298226fccf166445c68506f087":[5,0,6,28,10],
-"struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a2fe25096ba980b3569e44833ddf155e6":[5,0,6,28,23],
-"struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a42a88148edf0e38db8a1fb4ab5d5b499":[5,0,6,28,27],
-"struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a5c89e45e32e3cf01cc54dc05ad6704e5":[5,0,6,28,20],
-"struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a683a3ae0ddceb4a01a94c0727ca63362":[5,0,6,28,22],
-"struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a7f6ccde75703a0965eb4bce5f99eeac2":[5,0,6,28,6],
-"struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a89fbc371d11d0363db247d6ef1fa7afa":[5,0,6,28,29],
-"struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a9099515f00fb4c790492037a4816c1a9":[5,0,6,28,1],
-"struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#ab7cc41b4120afa20f7d74d918ea35dc3":[5,0,6,28,28],
-"struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#ab8448c3f1c0a210e465a1aa0e551a33a":[5,0,6,28,25],
-"struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#ad4f4f774fd3c8c2072e659ab36b12f93":[5,0,6,28,7],
+"struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a0a242b15c4c3a7181cc5a371b3f86fe3":[5,0,6,28,15],
+"struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a1ddb6accd017335cacce50accf324cd8":[5,0,6,28,20],
+"struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a2e6b3a89e26268bde6f6347f363a6bd1":[5,0,6,28,13],
+"struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a2e8982298226fccf166445c68506f087":[5,0,6,28,6],
+"struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a3353094e7989fcd4774b9147750990bc":[5,0,6,28,16],
+"struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a41d03f5e7c111278153bd602669392e2":[5,0,6,28,18],
+"struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a51c08bbc222d2824f6702922c57df32a":[5,0,6,28,1],
+"struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a5c89e45e32e3cf01cc54dc05ad6704e5":[5,0,6,28,14],
+"struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a7f6ccde75703a0965eb4bce5f99eeac2":[5,0,6,28,2],
+"struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a859c38f8eede388a0db21746c799104c":[5,0,6,28,23],
+"struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a99ee71477fc5b425ec71ba30d3263cf3":[5,0,6,28,21],
+"struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#aab20ca80afddb8f7a0122f462b15ecc1":[5,0,6,28,19],
+"struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#ad21d38181cff1eb60b26fc50cc282936":[5,0,6,28,22],
+"struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#ad4f4f774fd3c8c2072e659ab36b12f93":[5,0,6,28,3],
+"struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#ad61dc4d19b88cf30e60074cb7552eedb":[5,0,6,28,17],
 "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#afcd99d9db1e0e25bab9f7bea0d4a190a":[5,0,6,28,0],
-"struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#aff2d9ac3a0f7653fc9e5dcef71e80397":[5,0,6,28,26],
 "struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html":[5,0,6,29],
-"struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html#a363e2d1a068e15325d2f36251c194415":[5,0,6,29,7],
+"struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html#a363e2d1a068e15325d2f36251c194415":[5,0,6,29,3],
 "struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html#a50e16e1f758092ba72398d1f71d0bc60":[5,0,6,29,0],
-"struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html#a522a1880968a4814d3fca4eeb2a24e29":[5,0,6,29,12],
-"struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html#a6816f6bd970974e2fa9e1b0289a7994d":[5,0,6,29,13],
-"struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html#a687504a38534d7a9cf95fcc56a0ec048":[5,0,6,29,6],
-"struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html#a91aaf7e577df85ef9bb8ec991e85475d":[5,0,6,29,11],
-"struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html#ab251c7a2d54e44ad406b99f94fb7bcfd":[5,0,6,29,10],
-"struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html#ac3d942ae568cc586e83f0ea4415bad64":[5,0,6,29,14],
-"struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html#ad1269630b80565f80da462630bd7d5ad":[5,0,6,29,1],
-"struct_ogre_1_1_vector_set.html":[6,0,1,537],
-"struct_ogre_1_1_vector_set.html":[7,0,0,537],
-"struct_ogre_1_1_vector_set.html#a08824b7e26c3523829deba7da659b7dc":[6,0,1,537,9],
-"struct_ogre_1_1_vector_set.html#a08824b7e26c3523829deba7da659b7dc":[7,0,0,537,9],
-"struct_ogre_1_1_vector_set.html#a47551a30a8aa43cc51650f69e7eb35bf":[6,0,1,537,2],
-"struct_ogre_1_1_vector_set.html#a47551a30a8aa43cc51650f69e7eb35bf":[7,0,0,537,2],
-"struct_ogre_1_1_vector_set.html#a4b9389769eb5d2244297e13bea92205f":[6,0,1,537,1],
-"struct_ogre_1_1_vector_set.html#a4b9389769eb5d2244297e13bea92205f":[7,0,0,537,1],
-"struct_ogre_1_1_vector_set.html#a54ecab062478a2bbf5688744685acbeb":[6,0,1,537,0],
-"struct_ogre_1_1_vector_set.html#a54ecab062478a2bbf5688744685acbeb":[7,0,0,537,0],
-"struct_ogre_1_1_vector_set.html#a615a2a0b15043d64f5ccd8aeb938b021":[6,0,1,537,7],
-"struct_ogre_1_1_vector_set.html#a615a2a0b15043d64f5ccd8aeb938b021":[7,0,0,537,7],
-"struct_ogre_1_1_vector_set.html#a69fe902553d7da5e96a8b74df3714e22":[6,0,1,537,4],
-"struct_ogre_1_1_vector_set.html#a69fe902553d7da5e96a8b74df3714e22":[7,0,0,537,4],
-"struct_ogre_1_1_vector_set.html#a7049c5387498c49d046222cf2ce9e16c":[6,0,1,537,3],
-"struct_ogre_1_1_vector_set.html#a7049c5387498c49d046222cf2ce9e16c":[7,0,0,537,3],
-"struct_ogre_1_1_vector_set.html#a7f0236907f0642a16747cdbd9a5418c0":[6,0,1,537,5],
-"struct_ogre_1_1_vector_set.html#a7f0236907f0642a16747cdbd9a5418c0":[7,0,0,537,5],
-"struct_ogre_1_1_vector_set.html#a93908576e26866c616eea337800ceb9d":[6,0,1,537,6],
-"struct_ogre_1_1_vector_set.html#a93908576e26866c616eea337800ceb9d":[7,0,0,537,6],
-"struct_ogre_1_1_vector_set.html#aac9c6920e1af6843420f3897a2fe1cbb":[6,0,1,537,8],
-"struct_ogre_1_1_vector_set.html#aac9c6920e1af6843420f3897a2fe1cbb":[7,0,0,537,8],
+"struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html#a522a1880968a4814d3fca4eeb2a24e29":[5,0,6,29,6],
+"struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html#a6816f6bd970974e2fa9e1b0289a7994d":[5,0,6,29,7],
+"struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html#a687504a38534d7a9cf95fcc56a0ec048":[5,0,6,29,2],
+"struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html#a91aaf7e577df85ef9bb8ec991e85475d":[5,0,6,29,5],
+"struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html#ab251c7a2d54e44ad406b99f94fb7bcfd":[5,0,6,29,4],
+"struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html#ae3bcc4e26cb5b067e5cd295591cbd920":[5,0,6,29,8],
+"struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html#af845fd6db88eccdf2a5b155f3eb26d81":[5,0,6,29,1],
+"struct_ogre_1_1_vector_set.html":[6,0,1,539],
+"struct_ogre_1_1_vector_set.html":[7,0,0,539],
+"struct_ogre_1_1_vector_set.html#a08824b7e26c3523829deba7da659b7dc":[6,0,1,539,9],
+"struct_ogre_1_1_vector_set.html#a08824b7e26c3523829deba7da659b7dc":[7,0,0,539,9],
+"struct_ogre_1_1_vector_set.html#a47551a30a8aa43cc51650f69e7eb35bf":[6,0,1,539,2],
+"struct_ogre_1_1_vector_set.html#a47551a30a8aa43cc51650f69e7eb35bf":[7,0,0,539,2],
+"struct_ogre_1_1_vector_set.html#a4b9389769eb5d2244297e13bea92205f":[6,0,1,539,1],
+"struct_ogre_1_1_vector_set.html#a4b9389769eb5d2244297e13bea92205f":[7,0,0,539,1],
+"struct_ogre_1_1_vector_set.html#a54ecab062478a2bbf5688744685acbeb":[6,0,1,539,0],
+"struct_ogre_1_1_vector_set.html#a54ecab062478a2bbf5688744685acbeb":[7,0,0,539,0],
+"struct_ogre_1_1_vector_set.html#a615a2a0b15043d64f5ccd8aeb938b021":[6,0,1,539,7],
+"struct_ogre_1_1_vector_set.html#a615a2a0b15043d64f5ccd8aeb938b021":[7,0,0,539,7],
+"struct_ogre_1_1_vector_set.html#a69fe902553d7da5e96a8b74df3714e22":[6,0,1,539,4],
+"struct_ogre_1_1_vector_set.html#a69fe902553d7da5e96a8b74df3714e22":[7,0,0,539,4],
+"struct_ogre_1_1_vector_set.html#a7049c5387498c49d046222cf2ce9e16c":[6,0,1,539,3],
+"struct_ogre_1_1_vector_set.html#a7049c5387498c49d046222cf2ce9e16c":[7,0,0,539,3],
+"struct_ogre_1_1_vector_set.html#a7f0236907f0642a16747cdbd9a5418c0":[6,0,1,539,5],
+"struct_ogre_1_1_vector_set.html#a7f0236907f0642a16747cdbd9a5418c0":[7,0,0,539,5],
+"struct_ogre_1_1_vector_set.html#a93908576e26866c616eea337800ceb9d":[6,0,1,539,6],
+"struct_ogre_1_1_vector_set.html#a93908576e26866c616eea337800ceb9d":[7,0,0,539,6],
+"struct_ogre_1_1_vector_set.html#aac9c6920e1af6843420f3897a2fe1cbb":[6,0,1,539,8],
+"struct_ogre_1_1_vector_set.html#aac9c6920e1af6843420f3897a2fe1cbb":[7,0,0,539,8],
 "struct_ogre_1_1_vertex_bone_assignment.html":[5,0,0,34],
 "struct_ogre_1_1_vertex_bone_assignment.html#a9329a872bd7a4e3adff08eb95d6bc584":[5,0,0,34,0],
 "struct_ogre_1_1_vertex_bone_assignment.html#a941d92d84d2920751e62a84cf68a7209":[5,0,0,34,2],
 "struct_ogre_1_1_vertex_bone_assignment.html#aa3928595e373d5b072b2927cac841d71":[5,0,0,34,1],
-"struct_ogre_1_1_vertex_data_1_1_hardware_animation_data.html":[5,0,7,39,0],
-"struct_ogre_1_1_vertex_data_1_1_hardware_animation_data.html#a0662d8e6ede8a7cdbb387db40e77c989":[5,0,7,39,0,0],
-"struct_ogre_1_1_vertex_data_1_1_hardware_animation_data.html#afb5a1e2fb60698c421bb419be6f41026":[5,0,7,39,0,1],
+"struct_ogre_1_1_vertex_data_1_1_hardware_animation_data.html":[5,0,7,40,0],
+"struct_ogre_1_1_vertex_data_1_1_hardware_animation_data.html#a0662d8e6ede8a7cdbb387db40e77c989":[5,0,7,40,0,0],
+"struct_ogre_1_1_vertex_data_1_1_hardware_animation_data.html#afb5a1e2fb60698c421bb419be6f41026":[5,0,7,40,0,1],
 "struct_ogre_1_1_vertex_pose_key_frame_1_1_pose_ref.html":[5,0,0,36,0],
 "struct_ogre_1_1_vertex_pose_key_frame_1_1_pose_ref.html#a049f2fa04d1bd43409beb863f72738cb":[5,0,0,36,0,0],
 "struct_ogre_1_1_vertex_pose_key_frame_1_1_pose_ref.html#a172a06f5c2697f3e20bc2cf8556708ab":[5,0,0,36,0,1],
@@ -222,32 +249,5 @@ var NAVTREEINDEX62 =
 "struct_ogre_1_1_volume_1_1_chunk_parameters.html":[5,1,9,2],
 "struct_ogre_1_1_volume_1_1_chunk_parameters.html#a066adb42505bd30a78f1553a1913d273":[5,1,9,2,5],
 "struct_ogre_1_1_volume_1_1_chunk_parameters.html#a111c9e9333e7ae3497fc818190a03fd8":[5,1,9,2,2],
-"struct_ogre_1_1_volume_1_1_chunk_parameters.html#a3e154a179b8c824f79b1b426608743ad":[5,1,9,2,1],
-"struct_ogre_1_1_volume_1_1_chunk_parameters.html#a4444eac27c71e02886615dcf7fbfed27":[5,1,9,2,3],
-"struct_ogre_1_1_volume_1_1_chunk_parameters.html#a61d33b21a20c4fe9645545bdfe3029c3":[5,1,9,2,6],
-"struct_ogre_1_1_volume_1_1_chunk_parameters.html#a6403e2875cc7b81aefd43ba9f22c2b31":[5,1,9,2,8],
-"struct_ogre_1_1_volume_1_1_chunk_parameters.html#a68abf70466535d03dcbe3ac79db16ba6":[5,1,9,2,11],
-"struct_ogre_1_1_volume_1_1_chunk_parameters.html#a6a296a1c6f91b7e50033d12bac67cb10":[5,1,9,2,14],
-"struct_ogre_1_1_volume_1_1_chunk_parameters.html#a986b4a97b153d50f65603ab507bb4614":[5,1,9,2,7],
-"struct_ogre_1_1_volume_1_1_chunk_parameters.html#aa6186649b7323f937b83828eb86711fa":[5,1,9,2,4],
-"struct_ogre_1_1_volume_1_1_chunk_parameters.html#ad5118612e35d91011e06b9a97270e60f":[5,1,9,2,0],
-"struct_ogre_1_1_volume_1_1_chunk_parameters.html#ae125003c00de0d6c0a1a4bd6b99c4ebf":[5,1,9,2,10],
-"struct_ogre_1_1_volume_1_1_chunk_parameters.html#aeefacd1d618206fcb432ed947b58e06e":[5,1,9,2,12],
-"struct_ogre_1_1_volume_1_1_chunk_parameters.html#af6ed62b76c67d04eb98424414fb1dc72":[5,1,9,2,9],
-"struct_ogre_1_1_volume_1_1_chunk_parameters.html#afe30999e8cc71a1f48d87d68bf43059d":[5,1,9,2,13],
-"struct_ogre_1_1_volume_1_1_chunk_tree_shared_data.html":[5,1,9,3],
-"struct_ogre_1_1_volume_1_1_chunk_tree_shared_data.html#a09866f322d09f054994dcf8c13eac63e":[5,1,9,3,5],
-"struct_ogre_1_1_volume_1_1_chunk_tree_shared_data.html#a2469f72a70b68b236d10171f124dd39f":[5,1,9,3,4],
-"struct_ogre_1_1_volume_1_1_chunk_tree_shared_data.html#a5945276049999e1e44dc07e200ddc162":[5,1,9,3,3],
-"struct_ogre_1_1_volume_1_1_chunk_tree_shared_data.html#a64aba683df2575afa57a24c039d3298b":[5,1,9,3,2],
-"struct_ogre_1_1_volume_1_1_chunk_tree_shared_data.html#abf3e0545802da294d9e24825b5c1413f":[5,1,9,3,0],
-"struct_ogre_1_1_volume_1_1_chunk_tree_shared_data.html#acf6fc07b8818eddc9299e4186bebce89":[5,1,9,3,1],
-"struct_ogre_1_1_volume_1_1_chunk_tree_shared_data.html#af672339162b49888584d20403decfc13":[5,1,9,3,6],
-"struct_ogre_1_1_volume_1_1_dual_cell.html":[5,1,9,15],
-"struct_ogre_1_1_volume_1_1_dual_cell.html#a03a18e2bf6aae3679c0946bce94ac77c":[5,1,9,15,4],
-"struct_ogre_1_1_volume_1_1_dual_cell.html#a0ad4661acc2db15251656a1fdf8e8bc1":[5,1,9,15,1],
-"struct_ogre_1_1_volume_1_1_dual_cell.html#a3da89c366371d8f8f24c95307a897caf":[5,1,9,15,0],
-"struct_ogre_1_1_volume_1_1_dual_cell.html#a642d4feb93754697f48624019986f51d":[5,1,9,15,8],
-"struct_ogre_1_1_volume_1_1_dual_cell.html#a6d0eb6368fc82ec8a43c69ddd7daa124":[5,1,9,15,7],
-"struct_ogre_1_1_volume_1_1_dual_cell.html#aab46860b422720787b8aa59940958c72":[5,1,9,15,5]
+"struct_ogre_1_1_volume_1_1_chunk_parameters.html#a3e154a179b8c824f79b1b426608743ad":[5,1,9,2,1]
 };
