@@ -1,5 +1,23 @@
 var NAVTREEINDEX8 =
 {
+"class_ogre_1_1_camera.html#a438a713ce67e915836d7952bf5b572f9":[5,0,9,2,62],
+"class_ogre_1_1_camera.html#a4808eec2a7c9b8d56ad1961b6a46a2b8":[5,0,9,2,87],
+"class_ogre_1_1_camera.html#a49b7b8fe85de280b70c012f8416fab6e":[5,0,9,2,40],
+"class_ogre_1_1_camera.html#a4d5b3cac0c09c3cc37e36a957dcc7797":[5,0,9,2,19],
+"class_ogre_1_1_camera.html#a4fe3e4231262486405e531f58ed96866":[5,0,9,2,38],
+"class_ogre_1_1_camera.html#a544d92ca3b916325f63b460e4de5b752":[5,0,9,2,12],
+"class_ogre_1_1_camera.html#a54542bfe56c8a09949d35d6c75a5045c":[5,0,9,2,18],
+"class_ogre_1_1_camera.html#a550660c6cd22da59d8e3dc772bd93906":[5,0,9,2,37],
+"class_ogre_1_1_camera.html#a58676c042726c8a2b89678daa8f8860e":[5,0,9,2,86],
+"class_ogre_1_1_camera.html#a5a7e5830d24c096b30e208d3df1349b8":[5,0,9,2,1],
+"class_ogre_1_1_camera.html#a5f2e84b77278df598d20990e691745fd":[5,0,9,2,22],
+"class_ogre_1_1_camera.html#a5f44fa3f0930559eb6dd5ac2384bda88":[5,0,9,2,20],
+"class_ogre_1_1_camera.html#a6260eefc06a0bb2946a5c58d79750f3d":[5,0,9,2,70],
+"class_ogre_1_1_camera.html#a62d47145eb99e07af3de0915645be07c":[5,0,9,2,85],
+"class_ogre_1_1_camera.html#a6329537489c539e8be6508c666bc9fb8":[5,0,9,2,35],
+"class_ogre_1_1_camera.html#a65b42920567de7259aa5ff8481a67ec6":[5,0,9,2,8],
+"class_ogre_1_1_camera.html#a6bdbeb10e0feb22e3fa24a3a5d070874":[5,0,9,2,59],
+"class_ogre_1_1_camera.html#a6d2e00ca393cb8998c89832f5a2a1204":[5,0,9,2,79],
 "class_ogre_1_1_camera.html#a6fc2cf5ece7f9466a05066c2162e43d6":[5,0,9,2,69],
 "class_ogre_1_1_camera.html#a711a9fe25dcc9b5079774c4ab37bc1c3":[5,0,9,2,42],
 "class_ogre_1_1_camera.html#a75d99079b5c05d9d29cbb744a16f488e":[5,0,9,2,7],
@@ -12,7 +30,6 @@ var NAVTREEINDEX8 =
 "class_ogre_1_1_camera.html#a7c9dda3421876161115dce5f72334d25":[5,0,9,2,75],
 "class_ogre_1_1_camera.html#a7d20c29bed9f63ea78ec43c8ae53669d":[5,0,9,2,6],
 "class_ogre_1_1_camera.html#a7d7d770f2cab977be0dae849d3244b3b":[5,0,9,2,15],
-"class_ogre_1_1_camera.html#a80979fa21757e1e142b3aac77592fff9":[5,0,9,2,60],
 "class_ogre_1_1_camera.html#a891066e82092d315699f7963268a5c16":[5,0,9,2,24],
 "class_ogre_1_1_camera.html#a93430aa0ec356bf75a0e2a8a0326f517":[5,0,9,2,33],
 "class_ogre_1_1_camera.html#a98881a30eb353a94e7bbb5e153c58fc5":[5,0,9,2,68],
@@ -28,6 +45,7 @@ var NAVTREEINDEX8 =
 "class_ogre_1_1_camera.html#aba89daf9e8a8682547f35ac774a7e1f3":[5,0,9,2,26],
 "class_ogre_1_1_camera.html#abb5bad7918a07b1e7408f183b177d1a0":[5,0,9,2,9],
 "class_ogre_1_1_camera.html#abb719d4eb036a88cef5e23f7a5579b9c":[5,0,9,2,23],
+"class_ogre_1_1_camera.html#abbd08175324b9675c8b42657457f2ac7":[5,0,9,2,61],
 "class_ogre_1_1_camera.html#ac161a4022d817bf6e595a91cdca84848":[5,0,9,2,66],
 "class_ogre_1_1_camera.html#ac3ce1b1ee9db4e52dcaae80d89648168":[5,0,9,2,4],
 "class_ogre_1_1_camera.html#acb9dad823c5edb23a14341b0bd3855eb":[5,0,9,2,90],
@@ -36,6 +54,7 @@ var NAVTREEINDEX8 =
 "class_ogre_1_1_camera.html#ade9a67cb126367dd48883bf0df695679":[5,0,9,2,30],
 "class_ogre_1_1_camera.html#ae0ad15da476fdcbf67bc6e8a4378fc8f":[5,0,9,2,29],
 "class_ogre_1_1_camera.html#ae167537dd3f080dcbbaf31e7028de571":[5,0,9,2,54],
+"class_ogre_1_1_camera.html#ae4a80f117dc56ba8949c3e5f4de9eb0e":[5,0,9,2,60],
 "class_ogre_1_1_camera.html#ae7a14b95d7133f70a6c005095299bd72":[5,0,9,2,39],
 "class_ogre_1_1_camera.html#aea10ac162479ea92dfe24875ba9c6b13":[5,0,9,2,31],
 "class_ogre_1_1_camera.html#aea839ea1fe27ff60ed13096dcb7cc118":[5,0,9,2,63],
@@ -45,7 +64,6 @@ var NAVTREEINDEX8 =
 "class_ogre_1_1_camera.html#af3c79df85771d892413739d2aeac379c":[5,0,9,2,58],
 "class_ogre_1_1_camera.html#af47a93c963e7e90d20cd20cc39d73025":[5,0,9,2,81],
 "class_ogre_1_1_camera.html#afde9e80354228a484b102727bc4c48af":[5,0,9,2,13],
-"class_ogre_1_1_camera.html#afdef5a2d632790d7c72f14ff672d4f54":[5,0,9,2,61],
 "class_ogre_1_1_camera.html#afff2f8ad1ed1a1750f9daf4a96e3b23f":[5,0,9,2,88],
 "class_ogre_1_1_camera_1_1_listener.html":[5,0,9,2,0],
 "class_ogre_1_1_camera_1_1_listener.html#a118a99ab616bd2e1648c335afda174c9":[5,0,9,2,0,2],
@@ -123,6 +141,7 @@ var NAVTREEINDEX8 =
 "class_ogre_1_1_cg_program_factory.html#ac4caec857d18b553b9ab050ae57ea8c6":[5,2,2,2,3],
 "class_ogre_1_1_codec.html":[5,0,2,4],
 "class_ogre_1_1_codec.html#a2e3a2fbc93450efac141578d33c4bbc0":[5,0,2,4,11],
+"class_ogre_1_1_codec.html#a464e7b1ef3fae566425b2d7f4ed982db":[5,0,2,4,13],
 "class_ogre_1_1_codec.html#a5e7ecc1371add6ffa98d807dda1c8da3":[5,0,2,4,8],
 "class_ogre_1_1_codec.html#a6092324fd74dd0221f7c63ca8bec4fc1":[5,0,2,4,4],
 "class_ogre_1_1_codec.html#a60f445cc6919df56af6611fd14eec47d":[5,0,2,4,1],
@@ -230,24 +249,5 @@ var NAVTREEINDEX8 =
 "class_ogre_1_1_colour_image_affector.html#a2fb5b54b08efe8a456d4e57dfa7860d4":[7,0,0,62,4],
 "class_ogre_1_1_colour_image_affector.html#a52df9990e8c3cdeda702bcefc77f67d6":[6,0,1,62,5],
 "class_ogre_1_1_colour_image_affector.html#a52df9990e8c3cdeda702bcefc77f67d6":[7,0,0,62,5],
-"class_ogre_1_1_colour_image_affector.html#a7118e0cf5c7cefcbbf004580add48ae5":[6,0,1,62,1],
-"class_ogre_1_1_colour_image_affector.html#a7118e0cf5c7cefcbbf004580add48ae5":[7,0,0,62,1],
-"class_ogre_1_1_colour_image_affector.html#a712aea5134dc25d81d92a0f8d217859f":[6,0,1,62,2],
-"class_ogre_1_1_colour_image_affector.html#a712aea5134dc25d81d92a0f8d217859f":[7,0,0,62,2],
-"class_ogre_1_1_colour_image_affector.html#abd1161e46d005429f64883cfe0bdaea3":[6,0,1,62,3],
-"class_ogre_1_1_colour_image_affector.html#abd1161e46d005429f64883cfe0bdaea3":[7,0,0,62,3],
-"class_ogre_1_1_colour_image_affector_1_1_cmd_image_adjust.html":[6,0,1,62,0],
-"class_ogre_1_1_colour_image_affector_1_1_cmd_image_adjust.html":[7,0,0,62,0],
-"class_ogre_1_1_colour_image_affector_1_1_cmd_image_adjust.html#aa6baf8872837f8c1bf0145e2ee433c02":[6,0,1,62,0,0],
-"class_ogre_1_1_colour_image_affector_1_1_cmd_image_adjust.html#aa6baf8872837f8c1bf0145e2ee433c02":[7,0,0,62,0,0],
-"class_ogre_1_1_colour_image_affector_1_1_cmd_image_adjust.html#acbfa224b7d10bd20b83002856c07a9f0":[6,0,1,62,0,1],
-"class_ogre_1_1_colour_image_affector_1_1_cmd_image_adjust.html#acbfa224b7d10bd20b83002856c07a9f0":[7,0,0,62,0,1],
-"class_ogre_1_1_colour_interpolator_affector.html":[6,0,1,63],
-"class_ogre_1_1_colour_interpolator_affector.html":[7,0,0,63],
-"class_ogre_1_1_colour_interpolator_affector.html#a055f5f5bbe49e66d40c84c257e78b340":[6,0,1,63,9],
-"class_ogre_1_1_colour_interpolator_affector.html#a055f5f5bbe49e66d40c84c257e78b340":[7,0,0,63,9],
-"class_ogre_1_1_colour_interpolator_affector.html#a23342275feed700c10a601e5edb17152":[6,0,1,63,2],
-"class_ogre_1_1_colour_interpolator_affector.html#a23342275feed700c10a601e5edb17152":[7,0,0,63,2],
-"class_ogre_1_1_colour_interpolator_affector.html#a3534e0793f6d1aa89477c58e16a822a9":[6,0,1,63,4],
-"class_ogre_1_1_colour_interpolator_affector.html#a3534e0793f6d1aa89477c58e16a822a9":[7,0,0,63,4]
+"class_ogre_1_1_colour_image_affector.html#a7118e0cf5c7cefcbbf004580add48ae5":[6,0,1,62,1]
 };
