@@ -4,6 +4,5 @@ var searchData=
   ['gl_1',['GL',['../group___g_l.html',1,'']]],
   ['gl3plus_2',['GL3Plus',['../group___g_l3_plus.html',1,'']]],
   ['gles2_3',['GLES2',['../group___g_l_e_s2.html',1,'']]],
-  ['glslangprogrammanager_4',['GLSLangProgramManager',['../group___g_l_s_lang_program_manager.html',1,'']]],
-  ['glsupport_5',['GLSupport',['../group___g_l_support.html',1,'']]]
+  ['glslangprogrammanager_4',['GLSLangProgramManager',['../group___g_l_s_lang_program_manager.html',1,'']]]
 ];
